@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2017, OFFIS e.V.
+ *  Copyright (C) 2003-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -205,7 +205,7 @@ static OFCondition createNewElement(xmlNodePtr current,
         }
         if (result.bad())
         {
-            /* delete new element if an error occured */
+            /* delete new element if an error occurred */
             delete newElem;
             newElem = NULL;
         }
@@ -243,7 +243,7 @@ static OFCondition putElementContent(xmlNodePtr current,
                     /* Base64 decoder produces big endian output data, convert to local byte order */
                     swapIfNecessary(gLocalByteOrder, EBO_BigEndian, data, OFstatic_cast(Uint32, length), sizeof(Uint16));
                 }
-                result = element->putUint8Array(data, length);
+                result = element->putUint8Array(data, OFstatic_cast(Uint32, length));
                 /* delete buffer since data is copied into the element */
                 delete[] data;
             }
@@ -260,7 +260,7 @@ static OFCondition putElementContent(xmlNodePtr current,
                 {
                     /* determine filesize */
                     const size_t fileSize = OFStandard::getFileSize(filename);
-                    unsigned long buflen = fileSize;
+                    size_t buflen = fileSize;
                     /* if odd then make even (DICOM requires even length values) */
                     if (buflen & 1)
                         buflen++;
