@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,6 +27,9 @@
 
 #include "dcmtk/dcmdata/dcelem.h"
 
+// forward declarations
+class DcmJsonFormat;
+
 
 /** a class representing the DICOM value representation 'Attribute Tag' (AT)
  */
@@ -36,13 +39,16 @@ class DCMTK_DCMDATA_EXPORT DcmAttributeTag
 
   public:
 
+    // Make friend with DcmItem which requires access to protected
+    // constructor allowing construction using an explicit value length.
+    friend class DcmItem;
+
     /** constructor.
-     *  Create new element from given tag and length.
+     *  Create new element from given tag.
      *  @param tag DICOM tag for the new element
      *  @param len value length for the new element
      */
-    DcmAttributeTag(const DcmTag &tag,
-                    const Uint32 len = 0);
+    DcmAttributeTag(const DcmTag &tag);
 
     /** copy constructor
      *  @param old element to be copied
@@ -59,6 +65,27 @@ class DCMTK_DCMDATA_EXPORT DcmAttributeTag
      */
     DcmAttributeTag &operator=(const DcmAttributeTag &obj);
 
+    /** comparison operator that compares the normalized value of this object
+     *  with a given object of the same type. The tag of the element is also
+     *  considered as the first component that is compared, followed by the
+     *  object types (VR, i.e. DCMTK'S EVR) and the comparison of all value
+     *  components of the object, preferably in the order declared in the
+     *  object (if applicable).
+     *  @param  rhs the right hand side of the comparison
+     *  @return 0 if the object values are equal.
+     *    -1 if this element has fewer components than the rhs element.
+     *    Also -1 if the value of the first component that does not match
+     *    is lower in this object than in rhs. Also returned if rhs
+     *    cannot be casted to this object type or both objects are of
+     *    different VR (i.e. the DcmEVR returned by the element's ident()
+     *    call are different).
+     *    1 if either this element has more components than the rhs element, or
+     *    the first component that does not match is greater in this object than
+     *    in rhs object.
+     */
+    virtual int compare(const DcmElement& rhs) const;
+
+
     /** clone method
      *  @return deep copy of this object
      */
@@ -100,6 +127,11 @@ class DCMTK_DCMDATA_EXPORT DcmAttributeTag
      */
     virtual unsigned long getVM();
 
+    /** get number of values stored in this element
+     *  @return number of values in this element
+     */
+    virtual unsigned long getNumberOfValues();
+
     /** print element to a stream.
      *  The output format of the value is a backslash separated sequence of group and
      *  element value pairs, e.g. "(0008,0020)\(0008,0030)"
@@ -123,10 +155,18 @@ class DCMTK_DCMDATA_EXPORT DcmAttributeTag
     OFCondition writeXML(STD_NAMESPACE ostream &out,
                          const size_t flags = 0);
 
+    /** write object in JSON format
+     *  @param out output stream to which the JSON document is written
+     *  @param format used to format and customize the output
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    OFCondition writeJson(STD_NAMESPACE ostream &out,
+                          DcmJsonFormat &format);
+
     /** get particular tag value
      *  @param tagVal reference to result variable (cleared in case of error)
      *  @param pos index of the value to be retrieved (0..vm-1)
-     *  @return status status, EC_Normal if successful, an error code otherwise
+     *  @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition getTagVal(DcmTagKey &tagVal,
                                   const unsigned long pos = 0);
@@ -201,6 +241,10 @@ class DCMTK_DCMDATA_EXPORT DcmAttributeTag
      */
     virtual OFCondition verify(const OFBool autocorrect = OFFalse);
 
+    /// @copydoc DcmElement::isUniversalMatch()
+    virtual OFBool isUniversalMatch(const OFBool normalize = OFTrue,
+                                    const OFBool enableWildCardMatching = OFTrue);
+
     /* --- static helper functions --- */
 
     /** check whether given string value conforms to the VR "AT" (Attribute Tag)
@@ -212,6 +256,22 @@ class DCMTK_DCMDATA_EXPORT DcmAttributeTag
      */
     static OFCondition checkStringValue(const OFString &value,
                                         const OFString &vm = "1-n");
+
+protected:
+
+    /** constructor. Create new element from given tag and length.
+     *  Only reachable from friend classes since construction with
+     *  length different from 0 leads to a state with length being set but
+     *  the element's value still being uninitialized. This can lead to crashes
+     *  when the value is read or written. Thus the method calling this
+     *  constructor with length > 0 must ensure that the element's value is
+     *  explicitly initialized, too.
+     *  Create new element from given tag and length.
+     *  @param tag DICOM tag for the new element
+     *  @param len value length for the new element
+     */
+    DcmAttributeTag(const DcmTag &tag,
+                    const Uint32 len);
 };
 
 
