@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -36,13 +36,15 @@ class DCMTK_DCMDATA_EXPORT DcmUnsignedLong
 
  public:
 
+    // Make friend with DcmItem which requires access to protected
+    // constructor allowing construction using an explicit value length.
+    friend class DcmItem;
+
     /** constructor.
-     *  Create new element from given tag and length.
+     *  Create new element from given tag.
      *  @param tag DICOM tag for the new element
-     *  @param len value length for the new element
      */
-    DcmUnsignedLong(const DcmTag &tag,
-                    const Uint32 len = 0);
+    DcmUnsignedLong(const DcmTag &tag);
 
     /** copy constructor
      *  @param old element to be copied
@@ -59,6 +61,26 @@ class DCMTK_DCMDATA_EXPORT DcmUnsignedLong
      */
     DcmUnsignedLong &operator=(const DcmUnsignedLong &obj);
 
+    /** comparison operator that compares the normalized value of this object
+     *  with a given object of the same type. The tag of the element is also
+     *  considered as the first component that is compared, followed by the
+     *  object types (VR, i.e. DCMTK'S EVR) and the comparison of all value
+     *  components of the object, preferably in the order declared in the
+     *  object (if applicable).
+     *  @param  rhs the right hand side of the comparison
+     *  @return 0 if the object values are equal.
+     *    -1 if this element has fewer components than the rhs element.
+     *    Also -1 if the value of the first component that does not match
+     *    is lower in this object than in rhs. Also returned if rhs
+     *    cannot be casted to this object type or both objects are of
+     *    different VR (i.e. the DcmEVR returned by the element's ident()
+     *    call are different).
+     *    1 if either this element has more components than the rhs element, or
+     *    if the first component that does not match is greater in this object
+     *    than in rhs object.
+     */
+    virtual int compare(const DcmElement& rhs) const;
+
     /** clone method
      *  @return deep copy of this object
      */
@@ -96,10 +118,15 @@ class DCMTK_DCMDATA_EXPORT DcmUnsignedLong
                                    const OFBool oldFormat = OFFalse);
 
     /** get value multiplicity
-     *  @return number of currently stored values
+     *  @return number of values in this element
      */
     virtual unsigned long getVM();
 
+    /** get number of values stored in this element
+     *  @return number of values in this element
+     */
+    virtual unsigned long getNumberOfValues();
+
     /** print element to a stream.
      *  The output format of the value is a backslash separated sequence of numbers.
      *  @param out output stream
@@ -117,7 +144,7 @@ class DCMTK_DCMDATA_EXPORT DcmUnsignedLong
     /** get particular integer value
      *  @param uintVal reference to result variable (cleared in case of error)
      *  @param pos index of the value to be retrieved (0..vm-1)
-     *  @return status status, EC_Normal if successful, an error code otherwise
+     *  @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition getUint32(Uint32 &uintVal,
                                   const unsigned long pos = 0);
@@ -181,6 +208,26 @@ class DCMTK_DCMDATA_EXPORT DcmUnsignedLong
      *  @return status, EC_Normal if value length is correct, an error code otherwise
      */
     virtual OFCondition verify(const OFBool autocorrect = OFFalse);
+
+    /// @copydoc DcmElement::matches()
+    virtual OFBool matches(const DcmElement& candidate,
+                           const OFBool enableWildCardMatching = OFTrue) const;
+
+  protected:
+
+    /** constructor. Create new element from given tag and length.
+     *  Only reachable from friend classes since construction with
+     *  length different from 0 leads to a state with length being set but
+     *  the element's value still being uninitialized. This can lead to crashes
+     *  when the value is read or written. Thus the method calling this
+     *  constructor with length > 0 must ensure that the element's value is
+     *  explicitly initialized, too.
+     *  @param tag DICOM tag for the new element
+     *  @param len value length for the new element
+     */
+    DcmUnsignedLong(const DcmTag &tag,
+                    const Uint32 len);
+
 };
 
 
