@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2014-2017, OFFIS e.V.
+ *  Copyright (C) 2014-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -60,6 +60,26 @@ class DCMTK_DCMDATA_EXPORT DcmUniversalResourceIdentifierOrLocator
      */
     DcmUniversalResourceIdentifierOrLocator &operator=(const DcmUniversalResourceIdentifierOrLocator &obj);
 
+    /** comparison operator that compares the normalized value of this object
+     *  with a given object of the same type. The tag of the element is also
+     *  considered as the first component that is compared, followed by the
+     *  object types (VR, i.e. DCMTK'S EVR) and the comparison of all value
+     *  components of the object, preferably in the order declared in the
+     *  object (if applicable).
+     *  @param  rhs the right hand side of the comparison
+     *  @return 0 if the object values are equal.
+     *    -1 if this element has fewer components than the rhs element.
+     *    Also -1 if the value of the first component that does not match
+     *    is lower in this object than in rhs. Also returned if rhs
+     *    cannot be casted to this object type or both objects are of
+     *    different VR (i.e. the DcmEVR returned by the element's ident()
+     *    call are different).
+     *    1 if either this element has more components than the rhs element, or
+     *    if the first component that does not match is greater in this object
+     *    than in rhs object.
+     */
+    virtual int compare(const DcmElement& rhs) const;
+
     /** clone method
      *  @return deep copy of this object
      */
@@ -128,6 +148,10 @@ class DCMTK_DCMDATA_EXPORT DcmUniversalResourceIdentifierOrLocator
                            const OFString& candidate,
                            const OFBool enableWildCardMatching = OFTrue) const;
 
+    /// @copydoc DcmElement::isUniversalMatch()
+    virtual OFBool isUniversalMatch(const OFBool normalize = OFTrue,
+                                    const OFBool enableWildCardMatching = OFTrue);
+
     /* --- static helper functions --- */
 
     /** check whether given string value conforms to the VR "UR" (Universal Resource Identifier
