@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,6 +27,7 @@
 #include "dcmtk/ofstd/ofdefine.h"
 #include "dcmtk/dcmdata/dcdicent.h"
 #include "dcmtk/dcmdata/dctypes.h"
+#include "dcmtk/ofstd/ofstd.h"
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
@@ -114,6 +115,15 @@ DcmDataDictionary::DcmDataDictionary(OFBool loadBuiltin, OFBool loadExternal)
     skeletonCount(0),
     dictionaryLoaded(OFFalse)
 {
+    /* Make sure any DCMDICTPATH dictionary is loaded even if loading
+     * of external (default) dictionary is not enabled.
+     */
+    if (!loadExternal)
+    {
+        const char* env = getenv(DCM_DICT_ENVIRONMENT_VARIABLE);
+        if ((env != NULL) && (strlen(env) != 0))
+            loadExternal = OFTrue;
+    }
     reloadDictionaries(loadBuiltin, loadExternal);
 }
 
@@ -360,8 +370,9 @@ parseWholeTagField(char* s, DcmTagKey& key,
     if (pi > 0)
     {
       // copy private creator name
-      privCreator = new char[strlen(pc) + 1]; // deleted by caller
-      if (privCreator) strcpy(privCreator,pc);
+      size_t buflen = strlen(pc) + 1;
+      privCreator = new char[buflen]; // deleted by caller
+      if (privCreator) OFStandard::strlcpy(privCreator, pc, buflen);
     }
 
     key.set(OFstatic_cast(unsigned short, gl), OFstatic_cast(unsigned short, el));
@@ -820,7 +831,7 @@ void GlobalDcmDataDictionary::createDataDict()
   if (!dataDict)
     dataDict = new DcmDataDictionary(OFTrue /*loadBuiltin*/, loadExternal);
 #ifdef WITH_THREADS
-  dataDictLock.unlock();
+  dataDictLock.wrunlock();
 #endif
 }
 
@@ -833,7 +844,7 @@ const DcmDataDictionary& GlobalDcmDataDictionary::rdlock()
   {
     /* dataDictLock must not be locked during createDataDict() */
 #ifdef WITH_THREADS
-    dataDictLock.unlock();
+    dataDictLock.rdunlock();
 #endif
     createDataDict();
 #ifdef WITH_THREADS
@@ -852,7 +863,7 @@ DcmDataDictionary& GlobalDcmDataDictionary::wrlock()
   {
     /* dataDictLock must not be locked during createDataDict() */
 #ifdef WITH_THREADS
-    dataDictLock.unlock();
+    dataDictLock.wrunlock();
 #endif
     createDataDict();
 #ifdef WITH_THREADS
@@ -862,22 +873,29 @@ DcmDataDictionary& GlobalDcmDataDictionary::wrlock()
   return *dataDict;
 }
 
-void GlobalDcmDataDictionary::unlock()
+void GlobalDcmDataDictionary::rdunlock()
 {
 #ifdef WITH_THREADS
-  dataDictLock.unlock();
+  dataDictLock.rdunlock();
+#endif
+}
+
+void GlobalDcmDataDictionary::wrunlock()
+{
+#ifdef WITH_THREADS
+  dataDictLock.wrunlock();
 #endif
 }
 
 OFBool GlobalDcmDataDictionary::isDictionaryLoaded()
 {
   OFBool result = rdlock().isDictionaryLoaded();
-  unlock();
+  rdunlock();
   return result;
 }
 
 void GlobalDcmDataDictionary::clear()
 {
   wrlock().clear();
-  unlock();
+  wrunlock();
 }
