@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1997-2017, OFFIS e.V.
+ *  Copyright (C) 1997-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -187,8 +187,7 @@ DcmPixelData::calcElementLength(
     if (xferSyn.isEncapsulated() && (! writeUnencapsulated(xfer)))
     {
         DcmRepresentationListIterator found;
-        errorFlag =
-            findConformingEncapsulatedRepresentation(xfer, NULL, found);
+        errorFlag = findConformingEncapsulatedRepresentation(xfer, NULL, found);
         if (errorFlag == EC_Normal)
             elementLength = (*found)->pixSeq->calcElementLength(xfer, enctype);
     }
@@ -212,7 +211,7 @@ DcmPixelData::canChooseRepresentation(
     const DcmRepresentationEntry findEntry(repType, repParam, NULL);
     DcmRepresentationListIterator resultIt(repListEnd);
     // find out whether we have the desired target representation available. Three possibilities:
-    // 1. we have uncompressed data, and target is uncompressed (conversion betweeen uncompressed always possible)
+    // 1. we have uncompressed data, and target is uncompressed (conversion between uncompressed always possible)
     // 2. we have uncompressed and want compressed, but we are forced to write uncompressed anyway
     // 3. we want to go to compressed, and already have the desired representation available
     if ((!toType.isEncapsulated() && existUnencapsulated) ||
@@ -374,7 +373,7 @@ int DcmPixelData::compare(const DcmElement& rhs) const
         if (myPix->getItem(myPixItem, n).good() && rhsPix->getItem(rhsPixItem, n).good())
         {
           // compare them value by value, using DcmOtherByteOtherWord::compare() method
-          int result = myPixItem->compare(*rhsPixItem);
+          result = myPixItem->compare(*rhsPixItem);
           if (result != 0)
           {
             return result;
@@ -1214,7 +1213,7 @@ OFCondition DcmPixelData::getDecompressedColorModel(
     DcmItem *dataset,
     OFString &decompressedColorModel)
 {
-    OFCondition result = EC_IllegalCall;
+    OFCondition result = EC_IllegalParameter;
     if (dataset != NULL)
     {
       if (existUnencapsulated)
@@ -1222,7 +1221,21 @@ OFCondition DcmPixelData::getDecompressedColorModel(
         // we already have an uncompressed version of the pixel data either in memory or in file,
         // so just retrieve the color model from the given dataset
         result = dataset->findAndGetOFString(DCM_PhotometricInterpretation, decompressedColorModel);
-      } else {
+        if (result == EC_TagNotFound)
+        {
+          DCMDATA_WARN("DcmPixelData: Mandatory element PhotometricInterpretation " << DCM_PhotometricInterpretation << " is missing");
+          result = EC_MissingAttribute;
+        }
+        else if (result.bad())
+        {
+          DCMDATA_WARN("DcmPixelData: Cannot retrieve value of element PhotometricInterpretation " << DCM_PhotometricInterpretation << ": " << result.text());
+        }
+        else if (decompressedColorModel.empty())
+        {
+          DCMDATA_WARN("DcmPixelData: No value for mandatory element PhotometricInterpretation " << DCM_PhotometricInterpretation);
+          result = EC_MissingValue;
+        }
+    } else {
         // we only have a compressed version of the pixel data.
         // Identify a codec for determining the color model.
         result = DcmCodecList::determineDecompressedColorModel(
