@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -40,6 +40,15 @@
 // ********************************
 
 
+DcmPixelSequence::DcmPixelSequence(const DcmTag &tag)
+  : DcmSequenceOfItems(tag, 0),
+    Xfer(EXS_Unknown)
+{
+    setTagVR(EVR_OB);
+    setLengthField(DCM_UndefinedLength); // pixel sequences always use undefined length
+}
+
+
 DcmPixelSequence::DcmPixelSequence(const DcmTag &tag,
                                    const Uint32 len)
   : DcmSequenceOfItems(tag, len),
@@ -129,7 +138,7 @@ void DcmPixelSequence::print(STD_NAMESPACE ostream &out,
             } while (itemList->seek(ELP_next));
         }
         /* print pixel sequence end line */
-        DcmTag delimItemTag(DCM_SequenceDelimitationItem);
+        DcmTag delimItemTag(DCM_SequenceDelimitationItemTag);
         if (getLengthField() == DCM_UndefinedLength)
             printInfoLine(out, flags, level, "(SequenceDelimitationItem)", &delimItemTag);
         else
@@ -405,7 +414,7 @@ OFCondition DcmPixelSequence::storeCompressedFrame(DcmOffsetList &offsetList,
 
     while ((offset < compressedLen) && (result.good()))
     {
-        fragment = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
+        fragment = new DcmPixelItem(DCM_PixelItemTag);
         if (fragment == NULL)
             result = EC_MemoryExhausted;
         else
