@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -54,6 +54,13 @@ DcmPixelItem::DcmPixelItem(const DcmPixelItem &old)
 }
 
 
+DcmPixelItem &DcmPixelItem::operator=(const DcmPixelItem &obj)
+{
+  DcmOtherByteOtherWord::operator=(obj);
+  return *this;
+}
+
+
 OFCondition DcmPixelItem::copyFrom(const DcmObject &rhs)
 {
   if (this != &rhs)
