@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2016, OFFIS e.V.
+ *  Copyright (C) 2002-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -182,6 +182,7 @@ OFCondition DcmRLECodecDecoder::decode(
               Uint32 byteOffset = 0;
 
               OFBool lastStripe = OFFalse;
+              OFBool lastStripeOfColor = OFFalse;
               Uint32 inputBytes = 0;
 
               // pointers for buffer copy operations
@@ -225,6 +226,9 @@ OFCondition DcmRLECodecDecoder::decode(
                   }
                 }
 
+                // something went wrong; most likely the byte offset in the RLE header is incorrect.
+                if (result.bad()) return EC_CannotChangeRepresentation;
+
                 // byteOffset now points to the first byte of the new RLE stripe
                 // check if the current stripe is the last one for this frame
                 if (i+1 == numberOfStripes) lastStripe = OFTrue; else lastStripe = OFFalse;
@@ -309,8 +313,17 @@ OFCondition DcmRLECodecDecoder::decode(
                   }
                 }
 
+                // copy the decoded stuff over to the buffer here...
                 // make sure the RLE decoder has produced the right amount of data
-                if (result.good() && (rledecoder.size() != bytesPerStripe))
+                lastStripeOfColor = lastStripe || ((imagePlanarConfiguration == 1) && ((i+1) % imageBytesAllocated == 0));
+
+                if (lastStripeOfColor && (rledecoder.size() < bytesPerStripe))
+                {
+                    // stripe ended prematurely? report a warning and continue
+                    DCMDATA_WARN("RLE decoder is finished but has produced insufficient data for this stripe, filling remaining pixels");
+                    result = EC_Normal;
+                }
+                else if (rledecoder.size() != bytesPerStripe)
                 {
                     DCMDATA_ERROR("RLE decoder is finished but has produced insufficient data for this stripe");
                     result = EC_CannotChangeRepresentation;
@@ -503,6 +516,7 @@ OFCondition DcmRLECodecDecoder::decodeFrame(
     Uint32 byteOffset = 0;
 
     OFBool lastStripe = OFFalse;
+    OFBool lastStripeOfColor = OFFalse;
     Uint32 inputBytes = 0;
 
     // pointers for buffer copy operations
@@ -569,14 +583,12 @@ OFCondition DcmRLECodecDecoder::decodeFrame(
 
         // copy the decoded stuff over to the buffer here...
         // make sure the RLE decoder has produced the right amount of data
-        if (lastStripe && (rledecoder.size() < bytesPerStripe))
+        lastStripeOfColor = lastStripe || ((imagePlanarConfiguration == 1) && ((i+1) % imageBytesAllocated == 0));
+        if (lastStripeOfColor && (rledecoder.size() < bytesPerStripe))
         {
-            // stream ended premature? report a warning and continue
-            if (result == EC_StreamNotifyClient)
-            {
-                DCMDATA_WARN("RLE decoder is finished but has produced insufficient data for this stripe, filling remaining pixels");
-                result = EC_Normal;
-            }
+            // stripe ended prematurely? report a warning and continue
+            DCMDATA_WARN("RLE decoder is finished but has produced insufficient data for this stripe, filling remaining pixels");
+            result = EC_Normal;
         }
         else if (rledecoder.size() != bytesPerStripe)
         {
@@ -682,11 +694,29 @@ OFCondition DcmRLECodecDecoder::determineDecompressedColorModel(
     DcmItem *dataset,
     OFString &decompressedColorModel) const
 {
-    OFCondition result = EC_InvalidTag;
-    if ((dataset != NULL ) && ((dataset->ident() == EVR_dataset) || (dataset->ident() == EVR_item)))
+    OFCondition result = EC_IllegalParameter;
+    if (dataset != NULL )
     {
-        // retrieve color model from given dataset
-        result = dataset->findAndGetOFString(DCM_PhotometricInterpretation, decompressedColorModel);
+        if ((dataset->ident() == EVR_dataset) || (dataset->ident() == EVR_item))
+        {
+            // retrieve color model from given dataset
+            result = dataset->findAndGetOFString(DCM_PhotometricInterpretation, decompressedColorModel);
+            if (result == EC_TagNotFound)
+            {
+                DCMDATA_WARN("DcmRLECodecDecoder: Mandatory element PhotometricInterpretation " << DCM_PhotometricInterpretation << " is missing");
+                result = EC_MissingAttribute;
+            }
+            else if (result.bad())
+            {
+                DCMDATA_WARN("DcmRLECodecDecoder: Cannot retrieve value of element PhotometricInterpretation " << DCM_PhotometricInterpretation << ": " << result.text());
+            }
+            else if (decompressedColorModel.empty())
+            {
+                DCMDATA_WARN("DcmRLECodecDecoder: No value for mandatory element PhotometricInterpretation " << DCM_PhotometricInterpretation);
+                result = EC_MissingValue;
+            }
+        } else
+            result = EC_CorruptedData;
     }
     return result;
 }
