@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -69,6 +69,10 @@ BEGIN_EXTERN_C
 #endif
 #endif
 
+#ifdef __MINGW32__
+#include <winerror.h> /* needed for NO_ERROR constant on MinGW */
+#endif
+
 END_EXTERN_C
 
 #include "dcmtk/ofstd/ofstream.h"
@@ -175,6 +179,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_DigitalXRayImageStorageForProcessing,                "DigitalXRayImageStorageForProcessing" },
     { UID_EncapsulatedCDAStorage,                              "EncapsulatedCDAStorage" },
     { UID_EncapsulatedPDFStorage,                              "EncapsulatedPDFStorage" },
+    { UID_EncapsulatedSTLStorage,                              "EncapsulatedSTLStorage" },
     { UID_EnhancedCTImageStorage,                              "EnhancedCTImageStorage" },
     { UID_EnhancedMRColorImageStorage,                         "EnhancedMRColorImageStorage" },
     { UID_EnhancedMRImageStorage,                              "EnhancedMRImageStorage" },
@@ -290,7 +295,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_RETIRED_UltrasoundImageStorage,                      "RETIRED_UltrasoundImageStorage" },
     { UID_RETIRED_UltrasoundMultiframeImageStorage,            "RETIRED_UltrasoundMultiframeImageStorage" },
     { UID_RETIRED_VLImageStorage,                              "RETIRED_VLImageStorage" },
-    { UID_RETIRED_VLMultiFrameImageStorage,                    "RETIRED_VLMultiFrameImageStorage" },
+    { UID_RETIRED_VLMultiframeImageStorage,                    "RETIRED_VLMultiframeImageStorage" },
     { UID_RETIRED_XRayAngiographicBiPlaneImageStorage,         "RETIRED_XRayAngiographicBiPlaneImageStorage" },
     // Storage (DICOS)
     { UID_DICOS_CTImageStorage,                                "DICOS_CTImageStorage" },
@@ -601,6 +606,7 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_DigitalXRayImageStorageForProcessing,
     UID_EncapsulatedCDAStorage,
     UID_EncapsulatedPDFStorage,
+    UID_EncapsulatedSTLStorage,
     UID_EnhancedCTImageStorage,
     UID_EnhancedMRColorImageStorage,
     UID_EnhancedMRImageStorage,
@@ -712,7 +718,7 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_RETIRED_UltrasoundImageStorage,
     UID_RETIRED_UltrasoundMultiframeImageStorage,
     UID_RETIRED_VLImageStorage,
-    UID_RETIRED_VLMultiFrameImageStorage,
+    UID_RETIRED_VLMultiframeImageStorage,
     UID_RETIRED_XRayAngiographicBiPlaneImageStorage,
     // draft
     UID_DRAFT_SRAudioStorage,
@@ -879,6 +885,7 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
 //  UID_ContentAssessmentResultsStorage,
 //  UID_CornealTopographyMapStorage,
 //  UID_CTPerformedProcedureProtocolStorage,
+//  UID_EncapsulatedSTLStorage,
 //  UID_ExtensibleSRStorage,
 //  UID_GrayscalePlanarMPRVolumetricPresentationStateStorage
 //  UID_MultipleVolumeRenderingVolumetricPresentationStateStorage,
@@ -915,7 +922,7 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
     UID_RETIRED_UltrasoundImageStorage,
     UID_RETIRED_UltrasoundMultiframeImageStorage,
     UID_RETIRED_VLImageStorage,
-    UID_RETIRED_VLMultiFrameImageStorage,
+    UID_RETIRED_VLMultiframeImageStorage,
     UID_RETIRED_XRayAngiographicBiPlaneImageStorage,
     // draft
 //  UID_DRAFT_RTBeamsDeliveryInstructionStorage,
@@ -1104,7 +1111,7 @@ const char* dcmImageSOPClassUIDs[] = {
     UID_RETIRED_UltrasoundImageStorage,
     UID_RETIRED_UltrasoundMultiframeImageStorage,
     UID_RETIRED_VLImageStorage,
-    UID_RETIRED_VLMultiFrameImageStorage,
+    UID_RETIRED_VLMultiframeImageStorage,
     UID_RETIRED_XRayAngiographicBiPlaneImageStorage,
     // DICOS
     UID_DICOS_CTImageStorage,
@@ -1169,6 +1176,7 @@ static const DcmModalityTable modalities[] = {
     { UID_DigitalXRayImageStorageForProcessing,                    "DP",  2048 * 2048 * 2 },
     { UID_EncapsulatedCDAStorage,                                  "CDA", 4096 },
     { UID_EncapsulatedPDFStorage,                                  "PDF", 1024 * 1024 },
+    { UID_EncapsulatedSTLStorage,                                  "STL", 4096 },
     { UID_EnhancedCTImageStorage,                                  "CTe", 256 * 512 * 512 },
     { UID_EnhancedMRColorImageStorage,                             "MRc", 256 * 512 * 512 * 3 },
     { UID_EnhancedMRImageStorage,                                  "MRe", 256 * 512 * 512 },
@@ -1283,7 +1291,7 @@ static const DcmModalityTable modalities[] = {
     { UID_RETIRED_UltrasoundImageStorage,                          "USr", 512 * 512 },
     { UID_RETIRED_UltrasoundMultiframeImageStorage,                "USf", 512 * 512 },
     { UID_RETIRED_VLImageStorage,                                  "VLr", 768 * 576 * 3 },
-    { UID_RETIRED_VLMultiFrameImageStorage,                        "VMr", 768 * 576 * 3 },
+    { UID_RETIRED_VLMultiframeImageStorage,                        "VMr", 768 * 576 * 3 },
     { UID_RETIRED_XRayAngiographicBiPlaneImageStorage,             "XB",  512 * 512 * 2 },
     // draft
     { UID_DRAFT_RTBeamsDeliveryInstructionStorage,                 "RBd", 4096 },
