@@ -77,20 +77,20 @@ int DcmFloatingPointDouble::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmFloatingPointDouble*, this);
     myRhs = OFstatic_cast(DcmFloatingPointDouble*, OFconst_cast(DcmElement*, &rhs));
 
-    /* check whether VMs are equal */
-    unsigned long thisVM = myThis->getVM();
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
+    /* compare number of values */
+    unsigned long thisNumValues = myThis->getNumberOfValues();
+    unsigned long rhsNumValues = myRhs->getNumberOfValues();
+    if (thisNumValues < rhsNumValues)
     {
         return -1;
     }
-    else if (thisVM > rhsVM)
+    else if (thisNumValues > rhsNumValues)
     {
         return 1;
     }
 
     /* iterate over all components and test equality */
-    for (unsigned long count = 0; count < thisVM; count++)
+    for (unsigned long count = 0; count < thisNumValues; count++)
     {
         Float64 val = 0;
         if (myThis->getFloat64(val, count).good())
@@ -145,7 +145,13 @@ OFCondition DcmFloatingPointDouble::checkValue(const OFString &vm,
 
 unsigned long DcmFloatingPointDouble::getVM()
 {
-    return getLengthField() / OFstatic_cast(unsigned long, sizeof(Float64));
+    return getNumberOfValues();
+}
+
+
+unsigned long DcmFloatingPointDouble::getNumberOfValues()
+{
+    return OFstatic_cast(unsigned long, getLengthField() / sizeof(Float64));
 }
 
 
@@ -165,8 +171,8 @@ void DcmFloatingPointDouble::print(STD_NAMESPACE ostream&out,
         errorFlag = getFloat64Array(doubleVals);
         if (doubleVals != NULL)
         {
-            /* do not simply use getVM() because derived classes might always return 1 */
-            const unsigned long count = getLengthField() / OFstatic_cast(unsigned long, sizeof(Float64));
+            /* do not use getVM() because derived classes might always return 1 */
+            const unsigned long count = getNumberOfValues();
             /* double-check length field for valid value */
             if (count > 0)
             {
@@ -231,8 +237,8 @@ OFCondition DcmFloatingPointDouble::getFloat64(Float64 &doubleVal,
     {
         if (doubleValues == NULL)
             errorFlag = EC_IllegalCall;
-        /* do not simply use getVM() because derived classes might always return 1 */
-        else if (pos >= getLengthField() / sizeof(Float64))
+        /* do not use getVM() because derived classes might always return 1 */
+        else if (pos >= getNumberOfValues())
             errorFlag = EC_IllegalParameter;
         else
             doubleVal = doubleValues[pos];
