@@ -78,20 +78,20 @@ int DcmFloatingPointSingle::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmFloatingPointSingle*, this);
     myRhs = OFstatic_cast(DcmFloatingPointSingle*, OFconst_cast(DcmElement*, &rhs));
 
-    /* check whether VMs are equal */
-    unsigned long thisVM = myThis->getVM();
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
+    /* compare number of values */
+    unsigned long thisNumValues = myThis->getNumberOfValues();
+    unsigned long rhsNumValues = myRhs->getNumberOfValues();
+    if (thisNumValues < rhsNumValues)
     {
         return -1;
     }
-    else if (thisVM > rhsVM)
+    else if (thisNumValues > rhsNumValues)
     {
         return 1;
     }
 
     // iterate over all components and test equality */
-    for (unsigned long count = 0; count < thisVM; count++)
+    for (unsigned long count = 0; count < thisNumValues; count++)
     {
         Float32 val = 0;
         if (myThis->getFloat32(val, count).good())
@@ -147,7 +147,13 @@ OFCondition DcmFloatingPointSingle::checkValue(const OFString &vm,
 
 unsigned long DcmFloatingPointSingle::getVM()
 {
-    return getLengthField() / OFstatic_cast(unsigned long, sizeof(Float32));
+    return getNumberOfValues();
+}
+
+
+unsigned long DcmFloatingPointSingle::getNumberOfValues()
+{
+    return OFstatic_cast(unsigned long, getLengthField() / sizeof(Float32));
 }
 
 
@@ -167,8 +173,8 @@ void DcmFloatingPointSingle::print(STD_NAMESPACE ostream&out,
         errorFlag = getFloat32Array(floatVals);
         if (floatVals != NULL)
         {
-            /* do not simply use getVM() because derived classes might always return 1 */
-            const unsigned long count = getLengthField() / OFstatic_cast(unsigned long, sizeof(Float32));
+            /* do not use getVM() because derived classes might always return 1 */
+            const unsigned long count = getNumberOfValues();
             /* double-check length field for valid value */
             if (count > 0)
             {
@@ -233,8 +239,8 @@ OFCondition DcmFloatingPointSingle::getFloat32(Float32 &floatVal,
     {
         if (floatValues == NULL)
             errorFlag = EC_IllegalCall;
-        /* do not simply use getVM() because derived classes might always return 1 */
-        else if (pos >= getLengthField() / sizeof(Float32))
+        /* do not use getVM() because derived classes might always return 1 */
+        else if (pos >= getNumberOfValues())
             errorFlag = EC_IllegalParameter;
         else
             floatVal = floatValues[pos];
