@@ -90,7 +90,7 @@ int DcmOtherByteOtherWord::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmOtherByteOtherWord*, this);
     myRhs =  OFstatic_cast(DcmOtherByteOtherWord*, OFconst_cast(DcmElement*, &rhs));
 
-    /* check equality of length */
+    /* compare length */
     unsigned long thisLength = myThis->getLength();
     unsigned long rhsLength= myRhs->getLength();
     if (thisLength < rhsLength)
@@ -144,6 +144,17 @@ unsigned long DcmOtherByteOtherWord::getVM()
 }
 
 
+unsigned long DcmOtherByteOtherWord::getNumberOfValues()
+{
+    const DcmEVR evr = getTag().getEVR();
+    unsigned long result = OFstatic_cast(unsigned long, getLengthField());
+    /* check whether values are stored as 16 bit */
+    if ((evr == EVR_OW) || (evr == EVR_lt))
+        result /= 2;
+    return result;
+}
+
+
 OFCondition DcmOtherByteOtherWord::setVR(DcmEVR vr)
 {
     setTagVR(vr);
@@ -173,7 +184,7 @@ void DcmOtherByteOtherWord::print(STD_NAMESPACE ostream&out,
         /* check data */
         if ((wordValues != NULL) || (byteValues != NULL))
         {
-            const unsigned long count = (evr == EVR_OW || evr == EVR_lt) ? (getLengthField() / 2) : getLengthField();
+            const unsigned long count = getNumberOfValues();
             /* double-check length field for valid value */
             if (count > 0)
             {
@@ -224,7 +235,7 @@ void DcmOtherByteOtherWord::print(STD_NAMESPACE ostream&out,
 }
 
 
-void DcmOtherByteOtherWord::printPixel(STD_NAMESPACE ostream&out,
+void DcmOtherByteOtherWord::printPixel(STD_NAMESPACE ostream &out,
                                        const size_t flags,
                                        const int level,
                                        const char *pixelFileName,
@@ -262,13 +273,19 @@ void DcmOtherByteOtherWord::printPixel(STD_NAMESPACE ostream&out,
                     {
                         swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, data, getLengthField(), sizeof(Uint16));
                         setByteOrder(EBO_LittleEndian);
-                        fwrite(data, sizeof(Uint16), OFstatic_cast(size_t, getLengthField() / sizeof(Uint16)), file);
+                        const size_t count = OFstatic_cast(size_t, getLengthField() / sizeof(Uint16));
+                        if (fwrite(data, sizeof(Uint16), count, file) != count)
+                            DCMDATA_WARN("DcmOtherByteOtherWord: Can't write pixel data to output file: " << fname);
                     }
                 } else {
                     Uint8 *data = NULL;
                     getUint8Array(data);
                     if (data != NULL)
-                        fwrite(data, sizeof(Uint8), OFstatic_cast(size_t, getLengthField()), file);
+                    {
+                        const size_t count = OFstatic_cast(size_t, getLengthField());
+                        if (fwrite(data, sizeof(Uint8), count, file) != count)
+                            DCMDATA_WARN("DcmOtherByteOtherWord: Can't write pixel data to output file: " << fname);
+                    }
                 }
                 fclose(file);
             } else {
