@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -22,19 +22,22 @@
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
+#include "dcmtk/dcmdata/dcjson.h"
 #include "dcmtk/dcmdata/dcvrpn.h"
 
 
 // ********************************
 
 
+const char* const DcmPersonName::componentGroupNames[3] = { "Alphabetic", "Ideographic", "Phonetic" };
+
+
 DcmPersonName::DcmPersonName(const DcmTag &tag,
                              const Uint32 len)
   : DcmCharString(tag, len)
 {
     setMaxLength(64);     // not correct: max length of PN is 3*64+2 = 194 characters (not bytes!)
     setNonSignificantChars(" \\^=");
-    setDelimiterChars("\\^=");
 }
 
 
@@ -86,7 +89,8 @@ OFCondition DcmPersonName::checkValue(const OFString &vm,
     {
         OFString charset;
         /* try to determine the value of the SpecificCharacterSet element */
-        getSpecificCharacterSet(charset);
+        if (getSpecificCharacterSet(charset) == EC_CorruptedData)
+            charset = "UNKNOWN";
         l_error = DcmPersonName::checkStringValue(strVal, vm, charset);
     }
     return l_error;
@@ -125,7 +129,6 @@ OFCondition DcmPersonName::writeXML(STD_NAMESPACE ostream &out,
             /* strings to hold family, first, and middle name as well as prefix and suffix component */
             OFString components[5];
             /* arrays in order to permit looping while creating the output */
-            const char* compGroupNames[3] = { "Alphabetic", "Ideographic", "Phonetic" };
             const char* compNames[5] = { "FamilyName", "GivenName", "MiddleName", "NamePrefix", "NameSuffix" };
             for (unsigned int it = 0; it < vm; it++)
             {
@@ -149,7 +152,7 @@ OFCondition DcmPersonName::writeXML(STD_NAMESPACE ostream &out,
                         /* output one component group, e.g. <SingleByte> <FamilyName>Onken</FamilyName> </SingleByte> */
                         if (result.good())
                         {
-                            out << "<" << compGroupNames[cg] << ">" << OFendl; // e.g. <SingleByte>
+                            out << "<" << componentGroupNames[cg] << ">" << OFendl; // e.g. <SingleByte>
                             /* go through components (last name, first name, ...) */
                             for (unsigned short c = 0; c < 5; c++)
                             {
@@ -159,7 +162,7 @@ OFCondition DcmPersonName::writeXML(STD_NAMESPACE ostream &out,
                                     out << "<" << compNames[c] << ">" << components[c] << "</" << compNames[c] << ">" << OFendl;
                                 }
                             }
-                            out << "</" << compGroupNames[cg] << ">" << OFendl; // e.g. </SingleByte>
+                            out << "</" << componentGroupNames[cg] << ">" << OFendl; // e.g. </SingleByte>
                         }
                     }
                 }
@@ -177,6 +180,250 @@ OFCondition DcmPersonName::writeXML(STD_NAMESPACE ostream &out,
 }
 
 
+// ********************************
+
+
+OFCondition DcmPersonName::writeJson(STD_NAMESPACE ostream &out,
+                                     DcmJsonFormat &format)
+{
+    // helper struct to operate on the value pointers
+    struct Lexer
+    {
+        // initializes everything with foolproof defaults
+        Lexer()
+        : it(OFnullptr)
+        , end(OFnullptr)
+        , componentGroupName(componentGroupNames)
+        , currentComponent(0)
+        , hasTrailingNull(OFFalse)
+        {
+
+        }
+
+        // resets component groups and components for the new value and
+        // remembers that there was a value separator, so that trailing
+        // 'null' values can be printed.
+        void handleValue()
+        {
+            currentComponent = 0;
+            componentGroupName = componentGroupNames;
+            hasTrailingNull = OFTrue;
+        }
+
+        // check component group validity and set members
+        // appropriately
+        // emit warnings for invalid component groups
+        void handleComponentGroup()
+        {
+            if (componentGroupName != componentGroupNames + 2)
+            {
+                currentComponent = 0;
+                ++componentGroupName;
+            }
+            else
+            {
+                DCMDATA_ERROR("DcmPersonName::writeJson(): omitting invalid "
+                    "component group (more than three component groups present)");
+                // seek to the end of the current component group - 1, since
+                // the iterator will be incremented in the calling code
+                while (++it != end && *it != '\\' && *it != '=');
+                --it;
+            }
+        }
+
+        // searches for the next significant character
+        // (no delimiter or padding character).
+        // keeps track of the component group name and component
+        // number.
+        // returns OFFalse if no more significant characters exist.
+        OFBool nextValue()
+        {
+            for (; it != end; ++it) switch (*it)
+            {
+            case '\\':
+                handleValue();
+                return OFTrue;
+            case '=':
+                handleComponentGroup();
+                break;
+            case '^':
+                ++currentComponent;
+                break;
+            case ' ':
+                break;
+            default:
+                return OFTrue;
+            }
+            // this ends the output, unless we have to write
+            // a trailing 'null'
+            return hasTrailingNull;
+        }
+
+        // searches for the next significant character
+        // (no delimiter or padding character)
+        // within the current value.
+        // keeps track of the current component group and component
+        // number.
+        // returns OFFalse if no more significant characters exist
+        // within the current value.
+        OFBool nextComponentGroup()
+        {
+            for (; it != end; ++it) switch(*it)
+            {
+            case '\\':
+                // skip over any value separator
+                ++it;
+                handleValue();
+                return OFFalse;
+            case '=':
+                handleComponentGroup();
+                break;
+            case '^':
+                ++currentComponent;
+                break;
+            case ' ':
+                break;
+            default:
+                return OFTrue;
+            }
+            return OFFalse;
+        }
+
+        // searches for the next significant character
+        // (no delimiter or padding character)
+        // within the current component group.
+        // keeps track of the current component number.
+        // returns OFFalse if no more significant characters exist
+        // within the current component group.
+        OFBool nextComponent()
+        {
+            for (; it != end; ++it) switch(*it)
+            {
+            case '\\':
+            case '=':
+                return OFFalse;
+            case '^':
+                ++currentComponent;
+                break;
+            case ' ':
+                break;
+            default:
+                return OFTrue;
+            }
+            return OFFalse;
+        }
+
+        // writes all significant characters of the current component,
+        // prepending '^' characters as required by the current component
+        // number.
+        void writeComponent(STD_NAMESPACE ostream &out)
+        {
+            for (; currentComponent; --currentComponent)
+                out << '^';
+            const char* const begin = it;
+            while (++it != end && *it != '\\' && *it != '=' && *it != '^');
+            const char* componentEnd = it - 1;
+            while (*componentEnd == ' ')
+                --componentEnd;
+            out.write(begin, componentEnd - begin + 1);
+        }
+
+        // writes the name of the current component group and all components
+        // within the current component group that contain at least one significant
+        // character.
+        // All others are replaced by a single '^' character each, except for the
+        // trailing ones (that are omitted).
+        void writeComponentGroup(STD_NAMESPACE ostream &out, DcmJsonFormat &format)
+        {
+            out << format.indent() << '"' << *componentGroupName << "\":"
+                << format.space() << '"';
+            writeComponent(out);
+            while (nextComponent())
+                writeComponent(out);
+            out << '"';
+        }
+
+        // writes all component groups of the current value that contain at least
+        // a single significant character, separated by ',' characters.
+        // all other component groups are omitted entirely.
+        // writes 'null' if all component groups are empty.
+        void writeCurrentValue(STD_NAMESPACE ostream &out, DcmJsonFormat &format)
+        {
+            hasTrailingNull = OFFalse;
+            if (nextComponentGroup())
+            {
+                out << '{' << format.newline();
+                ++format.indent();
+                writeComponentGroup(out, format);
+                while (nextComponentGroup())
+                {
+                    out << ',' << format.newline();
+                    writeComponentGroup(out, format);
+                }
+                out << format.newline() << --format.indent() << '}';
+            }
+            else out << "null";
+        }
+
+        // points to the character that is currently being processed
+        const char* it;
+
+        // points to the end of the entire attribute's data, including
+        // all values
+        const char* const end;
+
+        // points to the respective entry of the componentGroupNames
+        // array that contains the name of the component group that
+        // is currently being processed
+        const char* const * componentGroupName;
+
+        // denotes the number of empty components within the current
+        // component group since the last component that contained
+        // at least one significant character.
+        unsigned currentComponent;
+
+        // will be OFTrue if the last value is empty, so that a
+        // trailing 'null' will be written
+        OFBool hasTrailingNull;
+    } lexer;
+
+    // initialize the lexer, return an error if the data
+    // of the current attribute can't be accessed for whatever
+    // reason
+    OFCondition result = DcmCharString::getString(OFconst_cast(char*&, lexer.it));
+    if (result.bad())
+        return result;
+    OFconst_cast(const char*&, lexer.end) = lexer.it + DcmCharString::getLength();
+
+    // write attribute name etc., even if the attribute is empty
+    DcmElement::writeJsonOpener(out, format);
+
+    // search for the first significant character within the
+    // entire data or the first value separator '\'
+    if (lexer.nextValue())
+    {
+        // write the fist value or 'null'
+        format.printValuePrefix(out);
+        lexer.writeCurrentValue(out, format);
+        // search for the first significant character within
+        // the next value or the next '\'
+        while (lexer.nextValue())
+        {
+            // write array element separator and the next
+            // value or 'null'
+            format.printNextArrayElementPrefix(out);
+            lexer.writeCurrentValue(out, format);
+        }
+        // close the array after the last value
+        format.printValueSuffix(out);
+    }
+
+    // close the current attribute
+    DcmElement::writeJsonCloser(out, format);
+
+    return EC_Normal;
+}
+
 
 // ********************************
 
@@ -483,3 +730,12 @@ OFCondition DcmPersonName::checkStringValue(const OFString &value,
     }
     return result;
 }
+
+
+// ********************************
+
+
+const OFString& DcmPersonName::getDelimiterChars() const
+{
+    return DcmVR(EVR_PN).getDelimiterChars();
+}
