@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1997-2017, OFFIS e.V.
+ *  Copyright (C) 1997-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -60,40 +60,40 @@ DcmPolymorphOBOW &DcmPolymorphOBOW::operator=(const DcmPolymorphOBOW & obj)
 
 int DcmPolymorphOBOW::compare(const DcmElement& rhs) const
 {
-  /* check tag and VR */
-  int result = DcmElement::compare(rhs);
-  if (result != 0)
-  {
-    return result;
-  }
+    /* check tag and VR */
+    int result = DcmElement::compare(rhs);
+    if (result != 0)
+    {
+        return result;
+    }
 
-  /* cast away constness (dcmdata is not const correct...) */
-  DcmPolymorphOBOW* myThis = NULL;
-  DcmPolymorphOBOW* myRhs = NULL;
-  myThis = OFconst_cast(DcmPolymorphOBOW*, this);
-  myRhs =  OFstatic_cast(DcmPolymorphOBOW*, OFconst_cast(DcmElement*, &rhs));
+    /* cast away constness (dcmdata is not const correct...) */
+    DcmPolymorphOBOW* myThis = NULL;
+    DcmPolymorphOBOW* myRhs = NULL;
+    myThis = OFconst_cast(DcmPolymorphOBOW*, this);
+    myRhs =  OFstatic_cast(DcmPolymorphOBOW*, OFconst_cast(DcmElement*, &rhs));
 
-  /* check whether length is the same */
-  Uint32 myLength = myThis->getLength();
-  Uint32 rhsLength = myRhs->getLength();
-  if (myLength < rhsLength)
-    return -1;
-  else if (myLength > rhsLength)
-    return 1;
-  /* finally check whether values are the same */
-  else
-  {
-    // Get values, always compare in Little Endian byte order (only relevant for OW)
-    void* myValue = myThis->getValue(EBO_LittleEndian);
-    void* rhsValue = myRhs->getValue(EBO_LittleEndian);
-    int result = memcmp(myValue, rhsValue, myLength);
-    if (result < 0)
-      return -1;
-    else if (result > 0)
-      return 1;
+    /* compare length */
+    Uint32 myLength = myThis->getLength();
+    Uint32 rhsLength = myRhs->getLength();
+    if (myLength < rhsLength)
+        return -1;
+    else if (myLength > rhsLength)
+        return 1;
+      /* finally check whether values are the same */
     else
-      return 0;
-  }
+    {
+        // Get values, always compare in Little Endian byte order (only relevant for OW)
+        void* myValue = myThis->getValue(EBO_LittleEndian);
+        void* rhsValue = myRhs->getValue(EBO_LittleEndian);
+        result = memcmp(myValue, rhsValue, myLength);
+        if (result < 0)
+            return -1;
+        else if (result > 0)
+            return 1;
+        else
+            return 0;
+    }
   /* we never get here */
 }
 
@@ -180,6 +180,15 @@ DcmPolymorphOBOW::createUint16Array(
     const Uint32 numWords,
     Uint16 * & words)
 {
+    // Check whether input would lead to a buffer allocation of more than
+    // 4 GB for a value, which is not possible in DICOM. The biggest input
+    // parameter value permitted is 2147483647, since 2147483647*2 is still
+    // < 2^32-1 (4 GB).
+    if (numWords > 2147483647)
+    {
+        errorFlag = EC_TooManyBytesRequested;
+        return errorFlag;
+    }
     currentVR = EVR_OW;
     setTagVR(EVR_OW);
     errorFlag = createEmptyValue(OFstatic_cast(Uint32, sizeof(Uint16) * OFstatic_cast(size_t, numWords)));
@@ -203,6 +212,15 @@ DcmPolymorphOBOW::putUint8Array(
     {
         if (byteValue)
         {
+            // Check if more than 4 GB is requested, which is the maximum
+            // length DICOM can handle. Take into account that the alignValue()
+            // call adds a byte if an odd length is provided, thus, 4294967295
+            // would not work.
+            if (numBytes > 4294967294UL)
+            {
+                errorFlag = EC_TooManyBytesRequested;
+                return errorFlag;
+            }
             errorFlag = putValue(byteValue, OFstatic_cast(Uint32, sizeof(Uint8) * OFstatic_cast(size_t, numBytes)));
             if (errorFlag == EC_Normal)
             {
@@ -233,6 +251,15 @@ DcmPolymorphOBOW::putUint16Array(
     {
         if (wordValue)
         {
+            // Check whether input would lead to a buffer allocation of more than
+            // 4 GB for a value, which is not possible in DICOM. The biggest input
+            // parameter value permitted is 2147483647, since 2147483647*2 is still
+            // < 2^32-1 (4 GB).
+            if (numWords > 2147483647)
+            {
+                errorFlag = EC_TooManyBytesRequested;
+                return EC_TooManyBytesRequested;
+            }
             errorFlag = putValue(wordValue, OFstatic_cast(Uint32, sizeof(Uint16) * OFstatic_cast(size_t, numWords)));
             if (errorFlag == EC_Normal &&
                 getTag().getEVR() == EVR_OB && getByteOrder() == EBO_BigEndian)
