@@ -78,20 +78,20 @@ int DcmSignedShort::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmSignedShort*, this);
     myRhs =  OFstatic_cast(DcmSignedShort*, OFconst_cast(DcmElement*, &rhs));
 
-    /* check whether VMs are equal */
-    unsigned long thisVM = myThis->getVM();
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
+    /* compare number of values */
+    unsigned long rhisNumValues = myThis->getNumberOfValues();
+    unsigned long rhsNumValues = myRhs->getNumberOfValues();
+    if (rhisNumValues < rhsNumValues)
     {
         return -1;
     }
-    else if (thisVM > rhsVM)
+    else if (rhisNumValues > rhsNumValues)
     {
         return 1;
     }
 
     /* iterate over all components and test equality */
-    for (unsigned long count = 0; count < thisVM; count++)
+    for (unsigned long count = 0; count < rhisNumValues; count++)
     {
         Sint16 val = 0;
         if (myThis->getSint16(val, count).good())
@@ -147,7 +147,13 @@ OFCondition DcmSignedShort::checkValue(const OFString &vm,
 
 unsigned long DcmSignedShort::getVM()
 {
-    return getLengthField() / OFstatic_cast(unsigned long, sizeof(Sint16));
+    return getNumberOfValues();
+}
+
+
+unsigned long DcmSignedShort::getNumberOfValues()
+{
+    return OFstatic_cast(unsigned long, getLengthField() / sizeof(Sint16));
 }
 
 
@@ -167,7 +173,7 @@ void DcmSignedShort::print(STD_NAMESPACE ostream&out,
         errorFlag = getSint16Array(sintVals);
         if (sintVals != NULL)
         {
-            const unsigned long count = getVM();
+            const unsigned long count = getNumberOfValues();
             /* double-check length field for valid value */
             if (count > 0)
             {
