@@ -20,12 +20,14 @@
  */
 
 
-#include "dcmtk/config/osconfig.h"
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
+
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/dcmdata/dcvrul.h"
 
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSTRING
+#define INCLUDE_CINTTYPES
 #include "dcmtk/ofstd/ofstdinc.h"
 
 
@@ -77,20 +79,20 @@ int DcmUnsignedLong::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmUnsignedLong*, this);
     myRhs =  OFstatic_cast(DcmUnsignedLong*, OFconst_cast(DcmElement*, &rhs));
 
-    /* check whether VMs are equal */
-    unsigned long thisVM = myThis->getVM();
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
+    /* compare number of values */
+    unsigned long thisNumValues = myThis->getNumberOfValues();
+    unsigned long rhsNumValues = myRhs->getNumberOfValues();
+    if (thisNumValues < rhsNumValues)
     {
         return -1;
     }
-    else if (thisVM > rhsVM)
+    else if (thisNumValues > rhsNumValues)
     {
         return 1;
     }
 
     /* iterate over all components and test equality */
-    for (unsigned long count = 0; count < thisVM; count++)
+    for (unsigned long count = 0; count < thisNumValues; count++)
     {
         Uint32 val = 0;
         if (myThis->getUint32(val, count).good())
@@ -144,6 +146,12 @@ OFCondition DcmUnsignedLong::checkValue(const OFString &vm,
 
 
 unsigned long DcmUnsignedLong::getVM()
+{
+    return getNumberOfValues();
+}
+
+
+unsigned long DcmUnsignedLong::getNumberOfValues()
 {
     return OFstatic_cast(unsigned long, getLengthField() / sizeof(Uint32));
 }
@@ -165,8 +173,8 @@ void DcmUnsignedLong::print(STD_NAMESPACE ostream&out,
         errorFlag = getUint32Array(uintVals);
         if (uintVals != NULL)
         {
-            /* do not simply use getVM() because derived classes might always return 1 */
-            const unsigned long count = getLengthField() / OFstatic_cast(unsigned long, sizeof(Uint32));
+            /* do not use getVM() because derived classes might always return 1 */
+            const unsigned long count = getNumberOfValues();
             /* double-check length field for valid value */
             if (count > 0)
             {
@@ -182,7 +190,11 @@ void DcmUnsignedLong::print(STD_NAMESPACE ostream&out,
                 {
                     /* check whether first value is printed (omit delimiter) */
                     if (i == 0)
-#if SIZEOF_LONG == 8
+#ifdef PRIu32
+                        sprintf(buffer, "%" PRIu32, *uintVals);
+                    else
+                        sprintf(buffer, "\\%" PRIu32, *uintVals);
+#elif SIZEOF_LONG == 8
                         sprintf(buffer, "%u", *uintVals);
                     else
                         sprintf(buffer, "\\%u", *uintVals);
@@ -234,8 +246,8 @@ OFCondition DcmUnsignedLong::getUint32(Uint32 &uintVal,
     {
         if (uintValues == NULL)
             errorFlag = EC_IllegalCall;
-        /* do not simply use getVM() because derived classes might always return 1 */
-        else if (pos >= getLengthField() / sizeof(Uint32))
+        /* do not use getVM() because derived classes might always return 1 */
+        else if (pos >= getNumberOfValues())
             errorFlag = EC_IllegalParameter;
         else
             uintVal = uintValues[pos];
@@ -334,7 +346,9 @@ OFCondition DcmUnsignedLong::putString(const char *stringVal,
             /* get specified value from multi-valued string */
             pos = DcmElement::getValueFromString(stringVal, pos, stringLen, value);
             if (value.empty() ||
-#if SIZEOF_LONG == 8
+#ifdef SCNu32
+                (sscanf(value.c_str(), "%" SCNu32, &field[i]) != 1)
+#elif SIZEOF_LONG == 8
                 (sscanf(value.c_str(), "%u", &field[i]) != 1)
 #else
                 (sscanf(value.c_str(), "%lu", &field[i]) != 1)
