@@ -76,20 +76,20 @@ int DcmUnsignedShort::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmUnsignedShort*, this);
     myRhs =  OFstatic_cast(DcmUnsignedShort*, OFconst_cast(DcmElement*, &rhs));
 
-    /* check whether VMs are equal */
-    unsigned long thisVM = myThis->getVM();
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
+    /* compare number of values */
+    unsigned long thisNumValues = myThis->getNumberOfValues();
+    unsigned long rhsNumValues = myRhs->getNumberOfValues();
+    if (thisNumValues < rhsNumValues)
     {
         return -1;
     }
-    else if (thisVM > rhsVM)
+    else if (thisNumValues > rhsNumValues)
     {
         return 1;
     }
 
     /* iterate over all components and test equality */
-    for (unsigned long count = 0; count < thisVM; count++)
+    for (unsigned long count = 0; count < thisNumValues; count++)
     {
         Uint16 val = 0;
         if (myThis->getUint16(val, count).good())
@@ -143,6 +143,12 @@ OFCondition DcmUnsignedShort::checkValue(const OFString &vm,
 
 
 unsigned long DcmUnsignedShort::getVM()
+{
+    return getNumberOfValues();
+}
+
+
+unsigned long DcmUnsignedShort::getNumberOfValues()
 {
     return OFstatic_cast(unsigned long, getLengthField() / sizeof(Uint16));
 }
@@ -164,7 +170,7 @@ void DcmUnsignedShort::print(STD_NAMESPACE ostream&out,
         errorFlag = getUint16Array(uintVals);
         if (uintVals != NULL)
         {
-            const unsigned long count = getVM();
+            const unsigned long count = getNumberOfValues();
             /* double-check length field for valid value */
             if (count > 0)
             {
