@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2008-2011, OFFIS e.V.
+ *  Copyright (C) 2008-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -152,11 +152,6 @@ static OFCondition testPathInsertionsWithWildcard(const OFString& path,
 
 OFTEST(dcmdata_pathAccess)
 {
-  // TODO TODO TODO TODO TODO TODO TODO TODO
-#ifdef HAVE_GUSI_H
-  GUSISetup(GUSIwithSIOUXSockets);
-  GUSISetup(GUSIwithInternetSockets);
-#endif
 
   /* make sure data dictionary is loaded */
   if (!dcmDataDict.isDictionaryLoaded())
