@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2016, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -197,6 +197,8 @@ int FGUSImageDescription::compare(const FGBase& rhs) const
     return result;
 
   const FGUSImageDescription* myRhs = OFstatic_cast(const FGUSImageDescription*, &rhs);
+  if (!myRhs)
+    return -1;
 
   // Compare all elements
   result = m_FrameType.compare(myRhs->m_FrameType);
