@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2011, OFFIS e.V.
+ *  Copyright (C) 1996-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -37,6 +37,9 @@
 #include "dcmtk/dcmimage/dilogger.h"
 #include "dcmtk/dcmimgle/diutils.h"
 
+#define INCLUDE_CINTTYPES
+#include "dcmtk/ofstd/ofstdinc.h"
+
 
 /*----------------*
  *  constructors  *
@@ -574,7 +577,9 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
                 /* set image resolution */
                 dataset.putAndInsertUint16(DCM_Columns, Columns);
                 dataset.putAndInsertUint16(DCM_Rows, Rows);
-#if SIZEOF_LONG == 8
+#ifdef PRId32
+                sprintf(numBuf, "%" PRId32, NumberOfFrames);
+#elif SIZEOF_LONG == 8
                 sprintf(numBuf, "%d", NumberOfFrames);
 #else
                 sprintf(numBuf, "%ld", NumberOfFrames);
@@ -680,8 +685,9 @@ int DiColorImage::writeRawPPM(FILE *stream,
             if ((OutputData != NULL) && (OutputData->getData() != NULL))
             {
                 fprintf(stream, "P6\n%u %u\n%lu\n", Columns, Rows, DicomImageClass::maxval(bits));
-                fwrite(OutputData->getData(), OFstatic_cast(size_t, OutputData->getCount()), OutputData->getItemSize(), stream);
-                return 1;
+                const size_t count = OFstatic_cast(size_t, OutputData->getCount());
+                if (fwrite(OutputData->getData(), OutputData->getItemSize(), count, stream) == count)
+                    return 1;
             }
         }
     }
