@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2016 OFFIS e.V.
+ *  Copyright (C) 1996-2018 OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -38,6 +38,7 @@
 #include "dcmtk/dcmimgle/diregbas.h"
 
 #define INCLUDE_CMATH
+#define INCLUDE_CINTTYPES
 #include "dcmtk/ofstd/ofstdinc.h"
 
 
@@ -2019,7 +2020,9 @@ int DiMonoImage::writeImageToDataset(DcmItem &dataset,
             /* set image resolution */
             dataset.putAndInsertUint16(DCM_Columns, Columns);
             dataset.putAndInsertUint16(DCM_Rows, Rows);
-#if SIZEOF_LONG == 8
+#ifdef PRId32
+            sprintf(numBuf, "%" PRId32, NumberOfFrames);
+#elif SIZEOF_LONG == 8
             sprintf(numBuf, "%d", NumberOfFrames);
 #else
             sprintf(numBuf, "%ld", NumberOfFrames);
@@ -2143,9 +2146,10 @@ int DiMonoImage::writeRawPPM(FILE *stream,
                 fprintf(stream, "P6\n%u %u\n255\n", Columns, Rows);
             else
                 fprintf(stream, "P5\n%u %u\n%lu\n", Columns, Rows, DicomImageClass::maxval(bits));
-            fwrite(OutputData->getData(), OFstatic_cast(size_t, OutputData->getCount()), OutputData->getItemSize(), stream);
+            const size_t count = OFstatic_cast(size_t, OutputData->getCount());
+            int ok = (fwrite(OutputData->getData(), OutputData->getItemSize(), count, stream) == count) ? 1 : 0;
             deleteOutputData();
-            return 1;
+            return ok;
         }
     }
     return 0;
