@@ -61,8 +61,7 @@ OFString IODFoRModule::getName() const
 
 IODFoRModule::~IODFoRModule()
 {
-  // clear rules from rule set
-  clearData();
+  // Nothing to do
 }
 
 
@@ -80,7 +79,6 @@ OFCondition IODFoRModule::getPositionReferenceIndicator(OFString& value,
 }
 
 
-
 OFCondition IODFoRModule::setFrameOfReferenceUID(const OFString &value,
                                                  const OFBool checkValue)
 {
@@ -100,3 +98,22 @@ OFCondition IODFoRModule::setPositionReferenceIndicator(const OFString &value,
   return result;
 }
 
+
+void IODFoRModule::ensureFrameOfReferenceUID(const OFBool correctInvalid)
+{
+  OFString uidstr;
+
+  // Create new Frame of Reference instance UID if required
+  if (getFrameOfReferenceUID(uidstr).bad() || uidstr.empty() )
+  {
+    setFrameOfReferenceUID(DcmIODUtil::createUID(1 /* Series Level */));
+  }
+  else if (!uidstr.empty() && correctInvalid)
+  {
+    if (DcmUniqueIdentifier::checkStringValue(uidstr, "1").bad())
+    {
+      setFrameOfReferenceUID(DcmIODUtil::createUID(1 /* Series Level */));
+    }
+  }
+}
+
