@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2016, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -47,7 +47,10 @@ IODGeneralStudyModule::IODGeneralStudyModule(OFshared_ptr<DcmItem> item,
 
 
 IODGeneralStudyModule::IODGeneralStudyModule()
-: IODModule()
+: IODModule(),
+  m_IssuerOfAccessionNumberSequence(),
+  m_ProcedureCodeSequence(),
+  m_ReasonForPerformedProcedureCodeSequence()
 {
   resetRules();
 }
