@@ -17,8 +17,8 @@
 #define JPEG_INTERNALS
 #include "jinclude12.h"
 #include "jpeglib12.h"
-#include "jlossls12.h"		/* Private declarations for lossless codec */
-#include "jchuff12.h"		/* Declarations shared with jc*huff.c */
+#include "jlossls12.h"      /* Private declarations for lossless codec */
+#include "jchuff12.h"       /* Declarations shared with jc*huff.c */
 
 
 /* Expanded entropy encoder object for Huffman encoding.
@@ -28,8 +28,8 @@
  */
 
 typedef struct {
-  IJG_INT32 put_buffer;		/* current bit-accumulation buffer */
-  int put_bits;			/* # of bits now in it */
+  IJG_INT32 put_buffer;     /* current bit-accumulation buffer */
+  int put_bits;         /* # of bits now in it */
 } savable_state;
 
 /* This macro is to work around compilers with missing or broken
@@ -41,8 +41,8 @@ typedef struct {
 #define ASSIGN_STATE(dest,src)  ((dest) = (src))
 #else
 #define ASSIGN_STATE(dest,src)  \
-	((dest).put_buffer = (src).put_buffer, \
-	 (dest).put_bits = (src).put_bits)
+    ((dest).put_buffer = (src).put_buffer, \
+     (dest).put_bits = (src).put_bits)
 #endif
 
 
@@ -52,11 +52,11 @@ typedef struct {
 
 
 typedef struct {
-  savable_state saved;		/* Bit buffer at start of MCU */
+  savable_state saved;      /* Bit buffer at start of MCU */
 
   /* These fields are NOT loaded into local working state. */
-  unsigned int restarts_to_go;	/* MCUs left in this restart interval */
-  int next_restart_num;		/* next restart number to write (0-7) */
+  unsigned int restarts_to_go;  /* MCUs left in this restart interval */
+  int next_restart_num;     /* next restart number to write (0-7) */
 
   /* Pointers to derived tables (these workspaces have image lifespan) */
   c_derived_tbl * derived_tbls[NUM_HUFF_TBLS];
@@ -64,7 +64,7 @@ typedef struct {
   /* Pointers to derived tables to be used for each data unit within an MCU */
   c_derived_tbl * cur_tbls[C_MAX_DATA_UNITS_IN_MCU];
 
-#ifdef ENTROPY_OPT_SUPPORTED	/* Statistics tables for optimization */
+#ifdef ENTROPY_OPT_SUPPORTED    /* Statistics tables for optimization */
   long * count_ptrs[NUM_HUFF_TBLS];
 
   /* Pointers to stats tables to be used for each data unit within an MCU */
@@ -98,26 +98,26 @@ typedef lhuff_entropy_encoder * lhuff_entropy_ptr;
  */
 
 typedef struct {
-  JOCTET * next_output_byte;	/* => next byte to write in buffer */
-  size_t free_in_buffer;	/* # of byte spaces remaining in buffer */
-  savable_state cur;		/* Current bit buffer & DC state */
-  j_compress_ptr cinfo;		/* dump_buffer needs access to this */
+  JOCTET * next_output_byte;    /* => next byte to write in buffer */
+  size_t free_in_buffer;    /* # of byte spaces remaining in buffer */
+  savable_state cur;        /* Current bit buffer & DC state */
+  j_compress_ptr cinfo;     /* dump_buffer needs access to this */
 } working_state;
 
 
 /* Forward declarations */
 METHODDEF(JDIMENSION) encode_mcus_huff (j_compress_ptr cinfo,
-					JDIFFIMAGE diff_buf,
-					JDIMENSION MCU_row_num,
-					JDIMENSION MCU_col_num,
-					JDIMENSION nMCU);
+                    JDIFFIMAGE diff_buf,
+                    JDIMENSION MCU_row_num,
+                    JDIMENSION MCU_col_num,
+                    JDIMENSION nMCU);
 METHODDEF(void) finish_pass_huff JPP((j_compress_ptr cinfo));
 #ifdef ENTROPY_OPT_SUPPORTED
 METHODDEF(JDIMENSION) encode_mcus_gather (j_compress_ptr cinfo,
-					  JDIFFIMAGE diff_buf,
-					  JDIMENSION MCU_row_num,
-					  JDIMENSION MCU_col_num,
-					  JDIMENSION nMCU);
+                      JDIFFIMAGE diff_buf,
+                      JDIMENSION MCU_row_num,
+                      JDIMENSION MCU_col_num,
+                      JDIMENSION nMCU);
 METHODDEF(void) finish_pass_gather JPP((j_compress_ptr cinfo));
 #endif
 
@@ -156,20 +156,20 @@ start_pass_huff (j_compress_ptr cinfo, boolean gather_statistics)
       /* Check for invalid table indexes */
       /* (make_c_derived_tbl does this in the other path) */
       if (dctbl < 0 || dctbl >= NUM_HUFF_TBLS)
-	ERREXIT1(cinfo, JERR_NO_HUFF_TABLE, dctbl);
+    ERREXIT1(cinfo, JERR_NO_HUFF_TABLE, dctbl);
       /* Allocate and zero the statistics tables */
       /* Note that jpeg_gen_optimal_table expects 257 entries in each table! */
       if (entropy->count_ptrs[dctbl] == NULL)
-	entropy->count_ptrs[dctbl] = (long *)
-	  (*cinfo->mem->alloc_small) ((j_common_ptr) cinfo, JPOOL_IMAGE,
-				      257 * SIZEOF(long));
+    entropy->count_ptrs[dctbl] = (long *)
+      (*cinfo->mem->alloc_small) ((j_common_ptr) cinfo, JPOOL_IMAGE,
+                      257 * SIZEOF(long));
       MEMZERO(entropy->count_ptrs[dctbl], 257 * SIZEOF(long));
 #endif
     } else {
       /* Compute derived values for Huffman tables */
       /* We may do this more than once for a table, but it's not expensive */
       jpeg_make_c_derived_tbl(cinfo, TRUE, dctbl,
-			      & entropy->derived_tbls[dctbl]);
+                  & entropy->derived_tbls[dctbl]);
     }
   }
 
@@ -185,11 +185,11 @@ start_pass_huff (j_compress_ptr cinfo, boolean gather_statistics)
       entropy->input_ptr_info[ptrn].yoffset = yoffset;
       entropy->input_ptr_info[ptrn].MCU_width = compptr->MCU_width;
       for (xoffset = 0; xoffset < compptr->MCU_width; xoffset++, sampn++) {
-	/* Precalculate the input pointer index for each sample */
-	entropy->input_ptr_index[sampn] = ptrn;
-	/* Precalculate which tables to use for each sample */
-	entropy->cur_tbls[sampn] = entropy->derived_tbls[compptr->dc_tbl_no];
-	entropy->cur_counts[sampn] = entropy->count_ptrs[compptr->dc_tbl_no];
+    /* Precalculate the input pointer index for each sample */
+    entropy->input_ptr_index[sampn] = ptrn;
+    /* Precalculate which tables to use for each sample */
+    entropy->cur_tbls[sampn] = entropy->derived_tbls[compptr->dc_tbl_no];
+    entropy->cur_counts[sampn] = entropy->count_ptrs[compptr->dc_tbl_no];
       }
     }
   }
@@ -209,10 +209,10 @@ start_pass_huff (j_compress_ptr cinfo, boolean gather_statistics)
 
 /* Emit a byte, taking 'action' if must suspend. */
 #define emit_byte(state,val,action)  \
-	{ *(state)->next_output_byte++ = (JOCTET) (val);  \
-	  if (--(state)->free_in_buffer == 0)  \
-	    if (! dump_buffer(state))  \
-	      { action; } }
+    { *(state)->next_output_byte++ = (JOCTET) (val);  \
+      if (--(state)->free_in_buffer == 0)  \
+        if (! dump_buffer(state))  \
+          { action; } }
 
 
 LOCAL(boolean)
@@ -253,7 +253,7 @@ emit_bits (working_state * state, unsigned int code, int size)
 
   put_buffer &= (((IJG_INT32) 1)<<size) - 1; /* mask off any extra bits in code */
   
-  put_bits += size;		/* new number of bits in buffer */
+  put_bits += size;     /* new number of bits in buffer */
   
   put_buffer <<= 24 - put_bits; /* align incoming bits */
 
@@ -263,7 +263,7 @@ emit_bits (working_state * state, unsigned int code, int size)
     int c = (int) ((put_buffer >> 16) & 0xFF);
     
     emit_byte(state, c, return FALSE);
-    if (c == 0xFF) {		/* need to stuff a zero byte? */
+    if (c == 0xFF) {        /* need to stuff a zero byte? */
       emit_byte(state, 0, return FALSE);
     }
     put_buffer <<= 8;
@@ -282,7 +282,7 @@ flush_bits (working_state * state)
 {
   if (! emit_bits(state, 0x7F, 7)) /* fill any partial byte with ones */
     return FALSE;
-  state->cur.put_buffer = 0;	/* and reset bit-buffer to empty */
+  state->cur.put_buffer = 0;    /* and reset bit-buffer to empty */
   state->cur.put_bits = 0;
   return TRUE;
 }
@@ -315,8 +315,8 @@ emit_restart (working_state * state, int restart_num)
 
 METHODDEF(JDIMENSION)
 encode_mcus_huff (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
-		  JDIMENSION MCU_row_num, JDIMENSION MCU_col_num,
-		  JDIMENSION nMCU)
+          JDIMENSION MCU_row_num, JDIMENSION MCU_col_num,
+          JDIMENSION nMCU)
 {
   j_lossless_c_ptr losslsc = (j_lossless_c_ptr) cinfo->codec;
   lhuff_entropy_ptr entropy = (lhuff_entropy_ptr) losslsc->entropy_private;
@@ -335,7 +335,7 @@ encode_mcus_huff (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
   if (cinfo->restart_interval) {
     if (entropy->restarts_to_go == 0)
       if (! emit_restart(&state, entropy->next_restart_num))
-	return 0;
+    return 0;
   }
 
   /* Set input pointer locations based on MCU_col_num */
@@ -344,7 +344,7 @@ encode_mcus_huff (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
     yoffset = entropy->input_ptr_info[ptrn].yoffset;
     MCU_width = entropy->input_ptr_info[ptrn].MCU_width;
     entropy->input_ptr[ptrn] =
-      diff_buf[ci][MCU_row_num + yoffset] + (MCU_col_num * MCU_width);
+      diff_buf[ci][MCU_row_num + (size_t)yoffset] + MCU_col_num * (size_t)MCU_width;
   }
 
   for (mcu_num = 0; mcu_num < nMCU; mcu_num++) {
@@ -360,37 +360,37 @@ encode_mcus_huff (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
       /* Input the sample difference */
       temp = *entropy->input_ptr[entropy->input_ptr_index[sampn]]++;
 
-      if (temp & 0x8000) {	/* instead of temp < 0 */
-	temp = (-temp) & 0x7FFF; /* absolute value, mod 2^16 */
-	if (temp == 0)		/* special case: magnitude = 32768 */
-	  temp2 = temp = 0x8000;
-	temp2 = ~ temp;		/* one's complement of magnitude */
+      if (temp & 0x8000) {  /* instead of temp < 0 */
+    temp = (-temp) & 0x7FFF; /* absolute value, mod 2^16 */
+    if (temp == 0)      /* special case: magnitude = 32768 */
+      temp2 = temp = 0x8000;
+    temp2 = ~ temp;     /* one's complement of magnitude */
       } else {
-	temp &= 0x7FFF;		/* abs value mod 2^16 */
-	temp2 = temp;		/* magnitude */
+    temp &= 0x7FFF;     /* abs value mod 2^16 */
+    temp2 = temp;       /* magnitude */
       }
 
       /* Find the number of bits needed for the magnitude of the difference */
       nbits = 0;
       while (temp) {
-	nbits++;
-	temp >>= 1;
+    nbits++;
+    temp >>= 1;
       }
       /* Check for out-of-range difference values.
        */
       if (nbits > MAX_DIFF_BITS)
-	ERREXIT(cinfo, JERR_BAD_DIFF);
+    ERREXIT(cinfo, JERR_BAD_DIFF);
   
       /* Emit the Huffman-coded symbol for the number of bits */
       if (! emit_bits(&state, dctbl->ehufco[nbits], dctbl->ehufsi[nbits]))
-	return mcu_num;
+    return mcu_num;
 
       /* Emit that number of bits of the value, if positive, */
       /* or the complement of its magnitude, if negative. */
-      if (nbits &&		/* emit_bits rejects calls with size 0 */
-	  nbits != 16)		/* special case: no bits should be emitted */
-	if (! emit_bits(&state, (unsigned int) temp2, nbits))
-	  return mcu_num;
+      if (nbits &&      /* emit_bits rejects calls with size 0 */
+      nbits != 16)      /* special case: no bits should be emitted */
+    if (! emit_bits(&state, (unsigned int) temp2, nbits))
+      return mcu_num;
     }
 
     /* Completed MCU, so update state */
@@ -401,9 +401,9 @@ encode_mcus_huff (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
     /* Update restart-interval state too */
     if (cinfo->restart_interval) {
       if (entropy->restarts_to_go == 0) {
-	entropy->restarts_to_go = cinfo->restart_interval;
-	entropy->next_restart_num++;
-	entropy->next_restart_num &= 7;
+    entropy->restarts_to_go = cinfo->restart_interval;
+    entropy->next_restart_num++;
+    entropy->next_restart_num &= 7;
       }
       entropy->restarts_to_go--;
     }
@@ -462,8 +462,8 @@ finish_pass_huff (j_compress_ptr cinfo)
 
 METHODDEF(JDIMENSION)
 encode_mcus_gather (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
-		    JDIMENSION MCU_row_num, JDIMENSION MCU_col_num,
-		    JDIMENSION nMCU)
+            JDIMENSION MCU_row_num, JDIMENSION MCU_col_num,
+            JDIMENSION nMCU)
 {
   j_lossless_c_ptr losslsc = (j_lossless_c_ptr) cinfo->codec;
   lhuff_entropy_ptr entropy = (lhuff_entropy_ptr) losslsc->entropy_private;
@@ -486,7 +486,7 @@ encode_mcus_gather (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
     yoffset = entropy->input_ptr_info[ptrn].yoffset;
     MCU_width = entropy->input_ptr_info[ptrn].MCU_width;
     entropy->input_ptr[ptrn] =
-      diff_buf[ci][MCU_row_num + yoffset] + (MCU_col_num * MCU_width);
+      diff_buf[ci][MCU_row_num + (size_t)yoffset] + MCU_col_num * (size_t)MCU_width;
   }
 
   for (mcu_num = 0; mcu_num < nMCU; mcu_num++) {
@@ -503,23 +503,23 @@ encode_mcus_gather (j_compress_ptr cinfo, JDIFFIMAGE diff_buf,
       /* Input the sample difference */
       temp = *entropy->input_ptr[entropy->input_ptr_index[sampn]]++;
 
-      if (temp & 0x8000) {	/* instead of temp < 0 */
-	temp = (-temp) & 0x7FFF; /* absolute value, mod 2^16 */
-	if (temp == 0)		/* special case: magnitude = 32768 */
-	  temp = 0x8000;
+      if (temp & 0x8000) {  /* instead of temp < 0 */
+    temp = (-temp) & 0x7FFF; /* absolute value, mod 2^16 */
+    if (temp == 0)      /* special case: magnitude = 32768 */
+      temp = 0x8000;
       } else
-	temp &= 0x7FFF;		/* abs value mod 2^16 */
+    temp &= 0x7FFF;     /* abs value mod 2^16 */
 
       /* Find the number of bits needed for the magnitude of the difference */
       nbits = 0;
       while (temp) {
-	nbits++;
-	temp >>= 1;
+    nbits++;
+    temp >>= 1;
       }
       /* Check for out-of-range difference values.
        */
       if (nbits > MAX_DIFF_BITS)
-	ERREXIT(cinfo, JERR_BAD_DIFF);
+    ERREXIT(cinfo, JERR_BAD_DIFF);
   
       /* Count the Huffman symbol for the number of bits */
       counts[nbits]++;
@@ -555,7 +555,7 @@ finish_pass_gather (j_compress_ptr cinfo)
     if (! did_dc[dctbl]) {
       htblptr = & cinfo->dc_huff_tbl_ptrs[dctbl];
       if (*htblptr == NULL)
-	*htblptr = jpeg_alloc_huff_table((j_common_ptr) cinfo);
+    *htblptr = jpeg_alloc_huff_table((j_common_ptr) cinfo);
       jpeg_gen_optimal_table(cinfo, *htblptr, entropy->count_ptrs[dctbl]);
       did_dc[dctbl] = TRUE;
     }
@@ -586,7 +586,7 @@ jinit_lhuff_encoder (j_compress_ptr cinfo)
 
   entropy = (lhuff_entropy_ptr)
     (*cinfo->mem->alloc_small) ((j_common_ptr) cinfo, JPOOL_IMAGE,
-				SIZEOF(lhuff_entropy_encoder));
+                SIZEOF(lhuff_entropy_encoder));
   losslsc->entropy_private = (struct jpeg_entropy_encoder *) entropy;
   losslsc->pub.entropy_start_pass = start_pass_huff;
   losslsc->pub.need_optimization_pass = need_optimization_pass;
