@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1997-2017, OFFIS e.V.
+ *  Copyright (C) 1997-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -46,6 +46,7 @@ void DJDecoderRegistration::registerCodecs(
     E_UIDCreation pCreateSOPInstanceUID,
     E_PlanarConfiguration pPlanarConfiguration,
     OFBool predictor6WorkaroundEnable,
+    OFBool cornellWorkaroundEnable,
     OFBool pForceSingleFragmentPerFrame)
 {
   if (! registered)
@@ -56,6 +57,7 @@ void DJDecoderRegistration::registerCodecs(
       pCreateSOPInstanceUID,
       pPlanarConfiguration,
       predictor6WorkaroundEnable,
+      cornellWorkaroundEnable,
       pForceSingleFragmentPerFrame);
 
     if (cp)
