@@ -27,6 +27,7 @@
 #include "dcmtk/ofstd/ofconapp.h"
 #include "dcmtk/dcmdata/dcdict.h"
 #include "dcmtk/dcmdata/dcostrmz.h"     /* for dcmZlibCompressionLevel */
+#include "dcmtk/dcmtls/tlsopt.h"        /* for DcmTLSOptions */
 
 #ifdef WITH_ZLIB
 #include <zlib.h>                       /* for zlibVersion() */
@@ -35,11 +36,6 @@
 #include "dcmtk/ofstd/ofchrenc.h"       /* for OFCharacterEncoding */
 #endif
 
-#ifdef WITH_OPENSSL
-#include "dcmtk/dcmtls/tlstrans.h"
-#include "dcmtk/dcmtls/tlslayer.h"
-#endif
-
 #define OFFIS_CONSOLE_APPLICATION "findscu"
 
 static OFLogger findscuLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
@@ -74,30 +70,13 @@ int main(int argc, char *argv[])
     const char *          opt_peerTitle = PEERAPPLICATIONTITLE;
     OFCmdUnsignedInt      opt_port = 104;
     OFCmdUnsignedInt      opt_repeatCount = 1;
-    OFBool                opt_secureConnection = OFFalse; /* default: no secure connection */
     OFList<OFString>      overrideKeys;
+    DcmTLSOptions         tlsOptions(NET_REQUESTOR);
 
 #ifdef WITH_ZLIB
     OFCmdUnsignedInt      opt_compressionLevel = 0;
 #endif
 
-#ifdef WITH_OPENSSL
-    const char *          opt_certificateFile = NULL;
-    OFBool                opt_doAuthenticate = OFFalse;
-    int                   opt_keyFileFormat = SSL_FILETYPE_PEM;
-    const char *          opt_passwd = NULL;
-    const char *          opt_privateKeyFile = NULL;
-#if OPENSSL_VERSION_NUMBER >= 0x0090700fL
-    OFString              opt_ciphersuites(TLS1_TXT_RSA_WITH_AES_128_SHA ":" SSL3_TXT_RSA_DES_192_CBC3_SHA);
-#else
-    OFString              opt_ciphersuites(SSL3_TXT_RSA_DES_192_CBC3_SHA);
-#endif
-    const char *          opt_dhparam = NULL;
-    const char *          opt_readSeedFile = NULL;
-    const char *          opt_writeSeedFile = NULL;
-    DcmCertificateVerification  opt_certVerification = DCV_requireCertificate;
-#endif
-
     /*
     ** By default. don't let "dcmdata" remove trailing padding or
     ** perform other manipulations. We want to see the real data.
@@ -105,6 +84,9 @@ int main(int argc, char *argv[])
     OFBool                opt_automaticDataCorrection = OFFalse;
 
   OFStandard::initializeNetwork();
+#ifdef WITH_OPENSSL
+  DcmTLSTransportLayer::initializeOpenSSL();
+#endif
 
   char tempstr[20];
   OFString temp_str;
@@ -177,42 +159,8 @@ int main(int argc, char *argv[])
       cmd.addOption("--cancel",                     1, "[n]umber: integer",
                                                        "cancel after n responses (default: never)");
 
-#ifdef WITH_OPENSSL
-  cmd.addGroup("transport layer security (TLS) options:");
-    cmd.addSubGroup("transport protocol stack:");
-      cmd.addOption("--disable-tls",        "-tls",    "use normal TCP/IP connection (default)");
-      cmd.addOption("--enable-tls",         "+tls", 2, "[p]rivate key file, [c]ertificate file: string",
-                                                       "use authenticated secure TLS connection");
-      cmd.addOption("--anonymous-tls",      "+tla",    "use secure TLS connection without certificate");
-    cmd.addSubGroup("private key password (only with --enable-tls):");
-      cmd.addOption("--std-passwd",         "+ps",     "prompt user to type password on stdin (default)");
-      cmd.addOption("--use-passwd",         "+pw",  1, "[p]assword: string ",
-                                                       "use specified password");
-      cmd.addOption("--null-passwd",        "-pw",     "use empty string as password");
-    cmd.addSubGroup("key and certificate file format:");
-      cmd.addOption("--pem-keys",           "-pem",    "read keys and certificates as PEM file (default)");
-      cmd.addOption("--der-keys",           "-der",    "read keys and certificates as DER file");
-    cmd.addSubGroup("certification authority:");
-      cmd.addOption("--add-cert-file",      "+cf",  1, "[c]ertificate filename: string",
-                                                       "add certificate file to list of certificates", OFCommandLine::AF_NoWarning);
-      cmd.addOption("--add-cert-dir",       "+cd",  1, "[c]ertificate directory: string",
-                                                       "add certificates in d to list of certificates", OFCommandLine::AF_NoWarning);
-    cmd.addSubGroup("ciphersuite:");
-      cmd.addOption("--cipher",             "+cs",  1, "[c]iphersuite name: string",
-                                                       "add ciphersuite to list of negotiated suites");
-      cmd.addOption("--dhparam",            "+dp",  1, "[f]ilename: string",
-                                                       "read DH parameters for DH/DSS ciphersuites");
-    cmd.addSubGroup("pseudo random generator:");
-      cmd.addOption("--seed",               "+rs",  1, "[f]ilename: string",
-                                                       "seed random generator with contents of f");
-      cmd.addOption("--write-seed",         "+ws",     "write back modified seed (only with --seed)");
-      cmd.addOption("--write-seed-file",    "+wf",  1, "[f]ilename: string (only with --seed)",
-                                                       "write modified seed to file f");
-    cmd.addSubGroup("peer authentication:");
-      cmd.addOption("--require-peer-cert",  "-rc",     "verify peer certificate, fail if absent (def.)");
-      cmd.addOption("--verify-peer-cert",   "-vc",     "verify peer certificate if present");
-      cmd.addOption("--ignore-peer-cert",   "-ic",     "don't verify peer certificate");
-#endif
+  // add TLS specific command line options if (and only if) we are compiling with OpenSSL
+  tlsOptions.addTLSCommandlineOptions(cmd);
 
   cmd.addGroup("output options:");
     cmd.addSubGroup("general:");
@@ -248,14 +196,20 @@ int main(int argc, char *argv[])
 #ifdef WITH_ZLIB
           COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
-#ifdef WITH_OPENSSL
-          COUT << "- " << OPENSSL_VERSION_TEXT << OFendl;
-#endif
+          // print OpenSSL version if (and only if) we are compiling with OpenSSL
+          tlsOptions.printLibraryVersion();
 #ifdef DCMTK_ENABLE_CHARSET_CONVERSION
           COUT << "- " << OFCharacterEncoding::getLibraryVersionString() << OFendl;
 #endif
           return 0;
         }
+
+        // check if the command line contains the --list-ciphers option
+        if (tlsOptions.listOfCiphersRequested(cmd))
+        {
+            tlsOptions.printSupportedCiphersuites(app, COUT);
+            return 0;
+        }
       }
 
       /* command line parameters */
@@ -379,101 +333,8 @@ int main(int argc, char *argv[])
         app.printError("either query file or override keys (or both) must be specified");
       }
 
-#ifdef WITH_OPENSSL
-
-      cmd.beginOptionBlock();
-      if (cmd.findOption("--disable-tls")) opt_secureConnection = OFFalse;
-      if (cmd.findOption("--enable-tls"))
-      {
-        opt_secureConnection = OFTrue;
-        opt_doAuthenticate = OFTrue;
-        app.checkValue(cmd.getValue(opt_privateKeyFile));
-        app.checkValue(cmd.getValue(opt_certificateFile));
-      }
-      if (cmd.findOption("--anonymous-tls"))
-      {
-        opt_secureConnection = OFTrue;
-      }
-      cmd.endOptionBlock();
-
-      cmd.beginOptionBlock();
-      if (cmd.findOption("--std-passwd"))
-      {
-        app.checkDependence("--std-passwd", "--enable-tls", opt_doAuthenticate);
-        opt_passwd = NULL;
-      }
-      if (cmd.findOption("--use-passwd"))
-      {
-        app.checkDependence("--use-passwd", "--enable-tls", opt_doAuthenticate);
-        app.checkValue(cmd.getValue(opt_passwd));
-      }
-      if (cmd.findOption("--null-passwd"))
-      {
-        app.checkDependence("--null-passwd", "--enable-tls", opt_doAuthenticate);
-        opt_passwd = "";
-      }
-      cmd.endOptionBlock();
-
-      cmd.beginOptionBlock();
-      if (cmd.findOption("--pem-keys")) opt_keyFileFormat = SSL_FILETYPE_PEM;
-      if (cmd.findOption("--der-keys")) opt_keyFileFormat = SSL_FILETYPE_ASN1;
-      cmd.endOptionBlock();
-
-      if (cmd.findOption("--dhparam"))
-      {
-        app.checkValue(cmd.getValue(opt_dhparam));
-      }
-
-      if (cmd.findOption("--seed"))
-      {
-        app.checkValue(cmd.getValue(opt_readSeedFile));
-      }
-
-      cmd.beginOptionBlock();
-      if (cmd.findOption("--write-seed"))
-      {
-        app.checkDependence("--write-seed", "--seed", opt_readSeedFile != NULL);
-        opt_writeSeedFile = opt_readSeedFile;
-      }
-      if (cmd.findOption("--write-seed-file"))
-      {
-        app.checkDependence("--write-seed-file", "--seed", opt_readSeedFile != NULL);
-        app.checkValue(cmd.getValue(opt_writeSeedFile));
-      }
-      cmd.endOptionBlock();
-
-      cmd.beginOptionBlock();
-      if (cmd.findOption("--require-peer-cert")) opt_certVerification = DCV_requireCertificate;
-      if (cmd.findOption("--verify-peer-cert"))  opt_certVerification = DCV_checkCertificate;
-      if (cmd.findOption("--ignore-peer-cert"))  opt_certVerification = DCV_ignoreCertificate;
-      cmd.endOptionBlock();
-
-      const char *current = NULL;
-      const char *currentOpenSSL;
-      if (cmd.findOption("--cipher", 0, OFCommandLine::FOM_First))
-      {
-        opt_ciphersuites.clear();
-        do
-        {
-          app.checkValue(cmd.getValue(current));
-          if (NULL == (currentOpenSSL = DcmTLSTransportLayer::findOpenSSLCipherSuiteName(current)))
-          {
-            OFLOG_FATAL(findscuLogger, "ciphersuite '" << current << "' is unknown. Known ciphersuites are:");
-            unsigned long numSuites = DcmTLSTransportLayer::getNumberOfCipherSuites();
-            for (unsigned long cs=0; cs < numSuites; cs++)
-            {
-              OFLOG_FATAL(findscuLogger, "    " << DcmTLSTransportLayer::getTLSCipherSuiteName(cs));
-            }
-            return 1;
-          } else {
-            if (!opt_ciphersuites.empty()) opt_ciphersuites += ":";
-            opt_ciphersuites += currentOpenSSL;
-          }
-        } while (cmd.findOption("--cipher", 0, OFCommandLine::FOM_Next));
-      }
-
-#endif
-
+      // evaluate (most of) the TLS command line options (if we are compiling with OpenSSL)
+      tlsOptions.parseArguments(app, cmd);
     }
 
     if (opt_outputResponsesToLogger == 0)
@@ -539,85 +400,24 @@ int main(int argc, char *argv[])
     }
 
 #ifdef WITH_OPENSSL
-
-    DcmTLSTransportLayer *tLayer = NULL;
-    if (opt_secureConnection)
+    if (tlsOptions.secureConnectionRequested())
     {
-      tLayer = new DcmTLSTransportLayer(DICOM_APPLICATION_REQUESTOR, opt_readSeedFile);
-      if (tLayer == NULL)
-      {
-        OFLOG_FATAL(findscuLogger, "unable to create TLS transport layer");
-        return 1;
-      }
+       /* create a secure transport layer */
+       cond = tlsOptions.createTransportLayer(NULL, NULL, app, cmd);
+       if (cond.bad())
+       {
+           OFLOG_FATAL(findscuLogger, DimseCondition::dump(temp_str, cond));
+           return 1;
+       }
 
-      if (cmd.findOption("--add-cert-file", 0, OFCommandLine::FOM_First))
-      {
-        const char *current = NULL;
-        do
-        {
-          app.checkValue(cmd.getValue(current));
-          if (TCS_ok != tLayer->addTrustedCertificateFile(current, opt_keyFileFormat))
-          {
-            OFLOG_WARN(findscuLogger, "unable to load certificate file '" << current << "', ignoring");
-          }
-        } while (cmd.findOption("--add-cert-file", 0, OFCommandLine::FOM_Next));
-      }
-
-      if (cmd.findOption("--add-cert-dir", 0, OFCommandLine::FOM_First))
-      {
-        const char *current = NULL;
-        do
-        {
-          app.checkValue(cmd.getValue(current));
-          if (TCS_ok != tLayer->addTrustedCertificateDir(current, opt_keyFileFormat))
-          {
-            OFLOG_WARN(findscuLogger, "unable to load certificates from directory '" << current << "', ignoring");
-          }
-        } while (cmd.findOption("--add-cert-dir", 0, OFCommandLine::FOM_Next));
-      }
-
-      if (opt_dhparam && ! (tLayer->setTempDHParameters(opt_dhparam)))
-      {
-        OFLOG_WARN(findscuLogger, "unable to load temporary DH parameter file '" << opt_dhparam << "', ignoring");
-      }
-
-      if (opt_doAuthenticate)
-      {
-        if (opt_passwd) tLayer->setPrivateKeyPasswd(opt_passwd);
-
-        if (TCS_ok != tLayer->setPrivateKeyFile(opt_privateKeyFile, opt_keyFileFormat))
-        {
-          OFLOG_FATAL(findscuLogger, "unable to load private TLS key from '" << opt_privateKeyFile << "'");
-          return 1;
-        }
-        if (TCS_ok != tLayer->setCertificateFile(opt_certificateFile, opt_keyFileFormat))
-        {
-          OFLOG_FATAL(findscuLogger, "unable to load certificate from '" << opt_certificateFile << "'");
-          return 1;
-        }
-        if (! tLayer->checkPrivateKeyMatchesCertificate())
-        {
-          OFLOG_FATAL(findscuLogger, "private key '" << opt_privateKeyFile << "' and certificate '" << opt_certificateFile << "' do not match");
-          return 1;
-        }
-      }
-
-      if (TCS_ok != tLayer->setCipherSuites(opt_ciphersuites.c_str()))
-      {
-        OFLOG_FATAL(findscuLogger, "unable to set selected cipher suites");
-        return 1;
-      }
-
-      tLayer->setCertificateVerification(opt_certVerification);
-
-      cond = findscu.setTransportLayer(tLayer);
-      if (cond.bad())
-      {
-          OFLOG_ERROR(findscuLogger, DimseCondition::dump(temp_str, cond));
-          return 1;
-      }
+       /* activate secure transport layer */
+       cond = findscu.setTransportLayer(tlsOptions.getTransportLayer());
+       if (cond.bad())
+       {
+           OFLOG_ERROR(findscuLogger, DimseCondition::dump(temp_str, cond));
+           return 1;
+       }
     }
-
 #endif
 
     // do the main work: negotiate network association, perform C-FIND transaction,
@@ -632,7 +432,7 @@ int main(int argc, char *argv[])
       opt_blockMode,
       opt_dimse_timeout,
       opt_maxReceivePDULength,
-      opt_secureConnection,
+      tlsOptions.secureConnectionRequested(),
       opt_abortAssociation,
       opt_repeatCount,
       opt_extractResponses,
@@ -649,22 +449,11 @@ int main(int argc, char *argv[])
 
     OFStandard::shutdownNetwork();
 
-#ifdef WITH_OPENSSL
-    if (tLayer && opt_writeSeedFile)
-    {
-      if (tLayer->canWriteRandomSeed())
-      {
-        if (!tLayer->writeRandomSeed(opt_writeSeedFile))
-        {
-          OFLOG_ERROR(findscuLogger, "cannot write random seed file '" << opt_writeSeedFile << "', ignoring");
-        }
-      } else {
-        OFLOG_ERROR(findscuLogger, "cannot write random seed, ignoring");
-      }
+    cond = tlsOptions.writeRandomSeed();
+    if (cond.bad()) {
+        // failure to write back the random seed is a warning, not an error
+        OFLOG_WARN(findscuLogger, DimseCondition::dump(temp_str, cond));
     }
-    delete tLayer;
-
-#endif
 
     return 0;
 }
