@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -77,6 +77,12 @@ class DcmTransportConnection;
 class DcmTransportLayer;
 class LST_HEAD;
 
+// include this file in doxygen documentation
+
+/** @file dul.h
+ *  @brief type definitions, constants, global variables and functions for the dcmnet/dul module
+ */
+
 /** Global flag to enable/disable reverse DNS lookup when accepting associations.
  *  If disabled, the numerical IP address instead of the symbolic hostname is
  *  stored in the callingPresentationAddress field of the association parameters
@@ -109,6 +115,18 @@ extern DCMTK_DCMNET_EXPORT OFGlobal<const char *> dcmTCPWrapperDaemonName;   /*
  */
 extern DCMTK_DCMNET_EXPORT OFGlobal<unsigned long> dcmEnableBackwardCompatibility;
 
+/** Maximum size (in bytes) of incoming A-ASSOCIATE-RQ or A-ASSOCIATE-AC PDUs
+ *  that we are willing to accept. Under normal conditions, valid A-ASSOCIATE PDUs
+ *  will never be larger than 64 kBytes, so the default of 1 MByte should be safe.
+ *  We should limit the maximum accepted PDU size to avoid denial of service
+ *  attacks through faulty PDUs that cause the network layer to allocate up
+ *  to 4 GByte of memory for one PDU.
+ *
+ *  Note: This limit can be disabled by setting a value of zero, which
+ *  causes the behaviour to revert to that of DCMTK releases up to 3.6.3.
+ */
+extern DCMTK_DCMNET_EXPORT OFGlobal<size_t> dcmAssociatePDUSizeLimit;   /* default: 1 MB */
+
 typedef void DUL_NETWORKKEY;
 typedef void DUL_ASSOCIATIONKEY;
 typedef unsigned char DUL_PRESENTATIONCONTEXTID;
@@ -384,7 +402,7 @@ typedef enum {
 */
 
 #define DUL_DULCOMPAT     2768240730UL
-#define DUL_DIMSECOMPAT   786432UL
+#define DUL_DIMSECOMPAT   917504UL
 #define DUL_MAXPDUCOMPAT  4278190335UL
 
 /* Define the function prototypes for this facility.
