@@ -88,10 +88,10 @@ DcmFindSCUDefaultCallback::DcmFindSCUDefaultCallback(
 
 void DcmFindSCUDefaultCallback::callback(
     T_DIMSE_C_FindRQ *request,
-    int responseCount,
+    int &responseCount,
     T_DIMSE_C_FindRSP *rsp,
     DcmDataset *responseIdentifiers)
- {
+{
     OFLogger rspLogger = OFLog::getLogger(DCMNET_LOGGER_NAME ".responses");
     /* check whether debug mode is enabled */
     if (DCM_dcmnetLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
@@ -117,7 +117,7 @@ void DcmFindSCUDefaultCallback::callback(
     if (extractResponses_ == FEM_dicomFile)
     {
         OFString outputFilename;
-        char rspIdsFileName[16];
+        char rspIdsFileName[32];
         sprintf(rspIdsFileName, "rsp%04d.dcm", responseCount);
         OFStandard::combineDirAndFilename(outputFilename, outputDirectory_, rspIdsFileName, OFTrue /*allowEmptyDirName*/);
         DCMNET_INFO("Writing response dataset to file: " << outputFilename);
@@ -127,7 +127,7 @@ void DcmFindSCUDefaultCallback::callback(
     else if (extractResponses_ == FEM_xmlFile)
     {
         OFString outputFilename;
-        char rspIdsFileName[16];
+        char rspIdsFileName[32];
         sprintf(rspIdsFileName, "rsp%04d.xml", responseCount);
         OFStandard::combineDirAndFilename(outputFilename, outputDirectory_, rspIdsFileName, OFTrue /*allowEmptyDirName*/);
         DCMNET_INFO("Writing response dataset to file: " << outputFilename);
@@ -235,6 +235,7 @@ OFCondition DcmFindSCU::performQuery(
     OFString temp_str;
     OFString outputFilename;
     STD_NAMESPACE ofstream outputStream;
+    int responseCount = 0;
 
     /* check input parameters first */
     if (extractResponses == FEM_singleXMLFile)
@@ -334,13 +335,13 @@ OFCondition DcmFindSCU::performQuery(
     if ((fileNameList == NULL) || fileNameList->empty())
     {
         /* no files provided on command line */
-        cond = findSCU(assoc, NULL, repeatCount, abstractSyntax, blockMode, dimse_timeout, extractResponses, cancelAfterNResponses, overrideKeys, callback, outputDirectory, &outputStream);
+        cond = findSCU(assoc, NULL, repeatCount, responseCount, abstractSyntax, blockMode, dimse_timeout, extractResponses, cancelAfterNResponses, overrideKeys, callback, outputDirectory, &outputStream);
     } else {
         OFListIterator(OFString) iter = fileNameList->begin();
         OFListIterator(OFString) enditer = fileNameList->end();
         while ((iter != enditer) && cond.good())
         {
-            cond = findSCU(assoc, (*iter).c_str(), repeatCount, abstractSyntax, blockMode, dimse_timeout, extractResponses, cancelAfterNResponses, overrideKeys, callback, outputDirectory, &outputStream);
+            cond = findSCU(assoc, (*iter).c_str(), repeatCount, responseCount, abstractSyntax, blockMode, dimse_timeout, extractResponses, cancelAfterNResponses, overrideKeys, callback, outputDirectory, &outputStream);
             ++iter;
         }
     }
@@ -585,6 +586,7 @@ OFCondition DcmFindSCU::findSCU(
     T_ASC_Association * assoc,
     const char *fname,
     int repeatCount,
+    int &responseCount,
     const char *abstractSyntax,
     T_DIMSE_BlockingMode blockMode,
     int dimse_timeout,
@@ -665,7 +667,7 @@ OFCondition DcmFindSCU::findSCU(
 
     /* prepare C-FIND-RQ message */
     bzero(OFreinterpret_cast(char*, &req), sizeof(req));
-    strcpy(req.AffectedSOPClassUID, abstractSyntax);
+    OFStandard::strlcpy(req.AffectedSOPClassUID, abstractSyntax, sizeof(req.AffectedSOPClassUID));
     req.DataSetType = DIMSE_DATASET_PRESENT;
     req.Priority = DIMSE_PRIORITY_MEDIUM;
 
@@ -695,7 +697,7 @@ OFCondition DcmFindSCU::findSCU(
         DCMNET_INFO("Request Identifiers:" << OFendl << DcmObject::PrintHelper(*dset));
 
         /* finally conduct transmission of data */
-        cond = DIMSE_findUser(assoc, presId, &req, dset,
+        cond = DIMSE_findUser(assoc, presId, &req, dset, responseCount,
             progressCallback, callback, blockMode, dimse_timeout,
             &rsp, &statusDetail);
 
