@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1993-2010, OFFIS e.V.
+ *  Copyright (C) 1993-2011, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -21,13 +21,6 @@
  *
  *    Module Prefix: DIMSE_
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2010-10-14 13:14:28 $
- *  CVS/RCS Revision: $Revision: 1.17 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
@@ -67,9 +60,8 @@ static void DIMSE_dumpMessage_end(OFString &str, DcmItem *dataset = NULL)
       str += "-----------------------------------------------------------------";
       OFOStringStream stream;
       stream << DcmObject::PrintHelper(*dataset, DCMTypes::PF_shortenLongTagValues) << OFStringStream_ends;
-      OFSTRINGSTREAM_GETSTR(stream, result)
+      OFSTRINGSTREAM_GETOFSTRING(stream, result);
       str += result;
-      OFSTRINGSTREAM_FREESTR(result)
     }
     str += "======================= END DIMSE MESSAGE =======================";
 }
@@ -105,6 +97,9 @@ static void DIMSE_printNStatusString(STD_NAMESPACE ostream& dumpStream, int stat
     case STATUS_N_InvalidAttributeValue:
       dumpStream << "0x0106: Invalid attribute value";
       break;
+    case STATUS_N_AttributeValueOutOfRange:
+      dumpStream << "0x0116: Attribute value out of range";
+      break;
     case STATUS_N_InvalidObjectInstance:
       dumpStream << "0x0117: Invalid object instance";
       break;
@@ -202,9 +197,9 @@ static void DIMSE_printCStoreStatusString(STD_NAMESPACE ostream& dumpStream, int
   {
     dumpStream << ": Error: Cannot understand";
   }
-  else if (status == STATUS_STORE_Warning_CoersionOfDataElements)
+  else if (status == STATUS_STORE_Warning_CoercionOfDataElements)
   {
-    dumpStream << ": Warning: Coersion of data elements";
+    dumpStream << ": Warning: Coercion of data elements";
   }
   else if (status == STATUS_STORE_Warning_DataSetDoesNotMatchSOPClass)
   {
@@ -1094,11 +1089,6 @@ OFString& DIMSE_dumpMessage(OFString &str, T_DIMSE_N_DeleteRSP &msg, enum DIMSE_
 OFString& DIMSE_dumpMessage(OFString &str, T_DIMSE_Message &msg, enum DIMSE_direction dir, DcmItem *dataset, T_ASC_PresentationContextID presID)
 {
     switch (msg.CommandField) {
-    case DIMSE_NOTHING:
-        DIMSE_dumpMessage_start(str, dir);
-        str += "Undefined Request/Response";
-        DIMSE_dumpMessage_end(str, dataset);
-        break;
     case DIMSE_C_STORE_RQ:
         DIMSE_dumpMessage(str, msg.msg.CStoreRQ, dir, dataset, presID);
         break;
@@ -1170,74 +1160,10 @@ OFString& DIMSE_dumpMessage(OFString &str, T_DIMSE_Message &msg, enum DIMSE_dire
         break;
     default:
         DIMSE_dumpMessage_start(str, dir);
-        str += "DIMSE_printCommand: Bad msg->CommandField";
+        str += "Message Type                  : UNKNOWN (DIMSE Protocol Error)";
         DIMSE_dumpMessage_end(str, dataset);
         break;
     }
 
     return str;
 }
-
-/*
- * CVS Log
- * $Log: dimdump.cc,v $
- * Revision 1.17  2010-10-14 13:14:28  joergr
- * Updated copyright header. Added reference to COPYRIGHT file.
- *
- * Revision 1.16  2010-10-13 08:08:15  joergr
- * Replaced copyright header since source code has been rewritten completely.
- * Previously: "Copyright (C) 1993/1994, OFFIS, Oldenburg University and CERIUM"
- *
- * Revision 1.15  2010-09-30 09:50:53  joergr
- * Added missing call to DIMSE_dumpMessage_start() for C-GET-RQ message.
- *
- * Revision 1.14  2010-06-14 16:00:21  joergr
- * Slightly modified output of DIMSE_dumpMessage_end().
- *
- * Revision 1.13  2009-12-08 16:44:25  joergr
- * Slightly modified some log messages.
- *
- * Revision 1.12  2009-11-18 11:53:59  uli
- * Switched to logging mechanism provided by the "new" oflog module.
- *
- * Revision 1.11  2009-08-04 10:05:58  joergr
- * Added optional parameter to printCStore() functions that allows for printing
- * the Presentation Context ID.
- *
- * Revision 1.10  2009-04-07 09:09:22  joergr
- * Fixed issue with unknown UID in uid2name().
- *
- * Revision 1.9  2006/08/15 16:04:29  meichel
- * Updated the code in module dcmnet to correctly compile when
- *   all standard C++ classes remain in namespace std.
- *
- * Revision 1.8  2005/12/08 15:44:40  meichel
- * Changed include path schema for all DCMTK header files
- *
- * Revision 1.7  2003/03/12 17:35:04  meichel
- * Updated DcmObject::print() flags
- *
- * Revision 1.6  2002/11/27 13:04:39  meichel
- * Adapted module dcmnet to use of new header file ofstdinc.h
- *
- * Revision 1.5  2000/06/07 08:57:54  meichel
- * dcmnet DIMSE routines now allow to retrieve raw command sets as DcmDataset
- *   objects, e.g. for logging purposes. Added enhanced message dump functions.
- *
- * Revision 1.4  2000/02/23 15:12:32  meichel
- * Corrected macro for Borland C++ Builder 4 workaround.
- *
- * Revision 1.3  2000/02/01 10:24:09  meichel
- * Avoiding to include <stdlib.h> as extern "C" on Borland C++ Builder 4,
- *   workaround for bug in compiler header files.
- *
- * Revision 1.2  1998/08/10 08:53:42  meichel
- * renamed member variable in DIMSE structures from "Status" to
- *   "DimseStatus". This is required if dcmnet is used together with
- *   <X11/Xlib.h> where Status is #define'd as int.
- *
- * Revision 1.1.1.1  1996/03/26 18:38:45  hewett
- * Initial Release.
- *
- *
- */
