@@ -74,6 +74,7 @@
 
 #ifdef HAVE_WINDOWS_H
 #include <winsock2.h>  /* for SO_EXCLUSIVEADDRUSE */
+#include <ws2tcpip.h>  /* for socklen_t */
 #endif
 
 #include "dcmtk/dcmnet/diutil.h"
@@ -141,6 +142,7 @@ END_EXTERN_C
 #include "dcmtk/dcmnet/cond.h"
 #include "dcmtk/dcmnet/lst.h"
 #include "dcmtk/ofstd/ofconsol.h"
+#include "dcmtk/ofstd/ofstd.h"
 
 #include "dcmtk/dcmnet/dul.h"
 #include "dulstruc.h"
@@ -155,6 +157,7 @@ OFGlobal<Sint32> dcmConnectionTimeout(-1);
 OFGlobal<DcmNativeSocketType> dcmExternalSocketHandle(DCMNET_INVALID_SOCKET);
 OFGlobal<const char *> dcmTCPWrapperDaemonName((const char *)NULL);
 OFGlobal<unsigned long> dcmEnableBackwardCompatibility(0);
+OFGlobal<size_t> dcmAssociatePDUSizeLimit(0x100000);
 
 static int networkInitialized = 0;
 
@@ -525,6 +528,9 @@ DUL_RequestAssociation(
     if (cond.bad())
         return cond;
 
+    if (block == DUL_NOBLOCK)
+        DCMNET_TRACE("setting association request timeout to " << timeout << " seconds");
+
     if (activatePDUStorage) DUL_activateAssociatePDUStorage(*association);
 
     /* send a request primitive */
@@ -547,8 +553,17 @@ DUL_RequestAssociation(
         destroyAssociationKey(association);
         return cond;
     }
+
+    /* if no timeout is passed, use the default one (do not wait forever) */
+    if ((block == DUL_BLOCK) && ((*association)->timeout > 0))
+    {
+        block = DUL_NOBLOCK;
+        timeout = (*association)->timeout;
+        DCMNET_TRACE("setting timeout for first PDU to be read to " << timeout << " seconds");
+    }
     /* Find the next event */
     cond = PRV_NextPDUType(association, block, timeout, &pduType);
+
     if (cond == DUL_NETWORKCLOSED)
         event = TRANS_CONN_CLOSED;
     else if (cond == DUL_READTIMEOUT)
@@ -657,6 +672,9 @@ DUL_ReceiveAssociationRQ(
     if (cond.bad())
         return cond;
 
+    if (block == DUL_NOBLOCK)
+        DCMNET_TRACE("setting association receive timeout to " << timeout << " seconds");
+
     if (activatePDUStorage) DUL_activateAssociatePDUStorage(*association);
     clearRequestorsParams(params);
 
@@ -677,7 +695,8 @@ DUL_ReceiveAssociationRQ(
     /* This is the first time we read from this new connection, so in case it
      * doesn't speak DICOM, we shouldn't wait forever (= DUL_NOBLOCK).
      */
-    cond = PRV_NextPDUType(association, DUL_NOBLOCK, PRV_DEFAULTTIMEOUT, &pduType);
+    DCMNET_TRACE("setting timeout for first PDU to be read to " << (*association)->timeout << " seconds");
+    cond = PRV_NextPDUType(association, DUL_NOBLOCK, (*association)->timeout, &pduType);
 
     if (cond == DUL_NETWORKCLOSED)
         event = TRANS_CONN_CLOSED;
@@ -2077,7 +2096,7 @@ createNetworkKey(const char *mode,
     }
     *key = (PRIVATE_NETWORKKEY *) malloc(sizeof(PRIVATE_NETWORKKEY));
     if (*key == NULL) return EC_MemoryExhausted;
-    (void) strcpy((*key)->keyType, KEY_NETWORK);
+    OFStandard::strlcpy((*key)->keyType, KEY_NETWORK, sizeof((*key)->keyType));
 
     (*key)->applicationFunction = 0;
 
@@ -2228,7 +2247,7 @@ initializeNetworkTCP(PRIVATE_NETWORKKEY ** key, void *parameter)
       }
     }
 
-    (*key)->networkSpecific.TCP.tLayer = new DcmTransportLayer((*key)->applicationFunction);
+    (*key)->networkSpecific.TCP.tLayer = new DcmTransportLayer();
     (*key)->networkSpecific.TCP.tLayerOwned = 1;
     if (NULL == (*key)->networkSpecific.TCP.tLayer)
     {
@@ -2272,10 +2291,10 @@ createAssociationKey(PRIVATE_NETWORKKEY ** networkKey,
     if (key == NULL) return EC_MemoryExhausted;
     key->receivePDUQueue = NULL;
 
-    (void) strcpy(key->keyType, KEY_ASSOCIATION);
+    OFStandard::strlcpy(key->keyType, KEY_ASSOCIATION, sizeof(key->keyType));
     key->applicationFunction = (*networkKey)->applicationFunction;
 
-    (void) strcpy(key->remoteNode, remoteNode);
+    OFStandard::strlcpy(key->remoteNode, remoteNode, sizeof(key->remoteNode));
     key->presentationContextID = 0;
     key->timeout = (*networkKey)->timeout;
     key->timerStart = 0;
@@ -2369,11 +2388,11 @@ get_association_parameter(void *paramAddress,
     if ((paramType == DUL_K_STRING) && (outputLength < strlen((char*)paramAddress))) return DUL_INSUFFICIENTBUFFERLENGTH;
 
     switch (paramType) {
-    case DUL_K_INTEGER:
+      case DUL_K_INTEGER:
         (void) memcpy(outputAddress, paramAddress, paramLength);
         break;
-    case DUL_K_STRING:
-        strcpy((char*)outputAddress, (char*)paramAddress);
+      case DUL_K_STRING:
+        OFStandard::strlcpy((char*)outputAddress, (char*)paramAddress, outputLength);
         break;
     }
     return EC_Normal;
