@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2009-2017, OFFIS e.V.
+ *  Copyright (C) 2009-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -395,7 +395,7 @@ OFCondition DcmSCP::processAssociationRQ()
   // Condition 2: determine the application context name. If an error occurred or if the
   // application context name is not supported we want to refuse the association request.
   char buf[BUFSIZ];
-  OFCondition cond = ASC_getApplicationContextName( m_assoc->params, buf );
+  OFCondition cond = ASC_getApplicationContextName( m_assoc->params, buf , sizeof(buf));
   if( cond.bad() || strcmp( buf, DICOM_STDAPPLICATIONCONTEXT ) != 0 )
   {
     refuseAssociation( DCMSCP_BAD_APPLICATION_CONTEXT_NAME );
