@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  Copyright (C) 1998-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -67,7 +67,7 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
 {
   OFCondition result = EC_Normal;
   DcmStack stack;
-  
+
   curveGroup = group;
   DcmElement *d_curveDimensions = NULL;
   DcmElement *d_numberOfPoints = NULL;
@@ -77,19 +77,19 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
   DcmElement *d_curveDescription = NULL;
   DcmElement *d_axisUnits = NULL;
   DcmElement *d_curveLabel = NULL;
-  
+
   /* first we look for the Curve Data */
   DcmTagKey key(0x5000 + group,0x3000);
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_curveData = (DcmElement *)(stack.top());  
+    d_curveData = (DcmElement *)(stack.top());
   } else return EC_IllegalCall;
-  
+
   key.setElement(0x0005); // Curve Dimensions
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_curveDimensions = (DcmElement *)(stack.top());  
+    d_curveDimensions = (DcmElement *)(stack.top());
   } else return EC_IllegalCall;
 
   key.setElement(0x0110); // Curve Data Descriptor
@@ -103,42 +103,42 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_numberOfPoints = (DcmElement *)(stack.top());  
+    d_numberOfPoints = (DcmElement *)(stack.top());
   } else return EC_IllegalCall;
 
   key.setElement(0x0020); // Type of Data
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_typeOfData = (DcmElement *)(stack.top());  
+    d_typeOfData = (DcmElement *)(stack.top());
   } else return EC_IllegalCall;
 
   key.setElement(0x0103); // Data Value Representation
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_dataVR = (DcmElement *)(stack.top());  
+    d_dataVR = (DcmElement *)(stack.top());
   } else return EC_IllegalCall;
 
   key.setElement(0x0022); // Curve Description
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_curveDescription = (DcmElement *)(stack.top());  
+    d_curveDescription = (DcmElement *)(stack.top());
   }
 
   key.setElement(0x0030); // Axis Units
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_axisUnits = (DcmElement *)(stack.top());  
+    d_axisUnits = (DcmElement *)(stack.top());
   }
 
   key.setElement(0x2500); // Curve Label
   stack.clear();
   if (EC_Normal == dset.search(key, stack, ESM_fromHere, OFFalse))
   {
-    d_curveLabel = (DcmElement *)(stack.top());  
+    d_curveLabel = (DcmElement *)(stack.top());
   }
 
   Uint16 u=0;
@@ -147,7 +147,7 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     // Curve Dimensions unreadable or != 2, bail out
     return EC_IllegalCall;
   }
-  
+
   u=0;
   if ((EC_Normal != d_numberOfPoints->getUint16(u,0))||(u == 0))
   {
@@ -168,36 +168,36 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
 
   if ((d_curveDescription) &&(EC_Normal == d_curveDescription->getOFString(aString,0)))
   {
-    curveDescription = aString; 
+    curveDescription = aString;
   }
-  
+
   if ((d_axisUnits) &&(EC_Normal == d_axisUnits->getOFString(aString,0)))
   {
-    axisUnitsX = aString; 
+    axisUnitsX = aString;
   }
   if ((d_axisUnits) &&(EC_Normal == d_axisUnits->getOFString(aString,1)))
   {
-    axisUnitsY = aString; 
+    axisUnitsY = aString;
   }
 
   if ((d_curveLabel) &&(EC_Normal == d_curveLabel->getOFString(aString,0)))
   {
-    curveLabel = aString; 
+    curveLabel = aString;
   }
-  
+
   Uint16 dataVR=0;
   if (EC_Normal != d_dataVR->getUint16(dataVR,0))
   {
     // cannot read curve data VR, bail out
     return EC_IllegalCall;
-  } 
+  }
 
   curveData = new double[numberOfPoints*2];
   if (curveData==NULL) return EC_MemoryExhausted;
 
   void *rawData=NULL;
   size_t align=0;
-  
+
   Uint8 *pui8=NULL;
   Uint16 *pui16=NULL;
   Sint16 *psi16=NULL;
@@ -210,15 +210,15 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     case EVR_OW:
     case EVR_ox:
     case EVR_US:
-      
+
       if (EC_Normal == d_curveData->getUint8Array(pui8))
       {
-      	rawData = pui8;
+        rawData = pui8;
         align = 1;
-      } 
+      }
       else if (EC_Normal == d_curveData->getUint16Array(pui16))
       {
-      	rawData = pui16;
+        rawData = pui16;
         align = sizeof(Uint16);
       }
       else result = EC_IllegalCall;
@@ -226,28 +226,28 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     case EVR_SS:
       if (EC_Normal == d_curveData->getSint16Array(psi16))
       {
-      	rawData = psi16;
+        rawData = psi16;
         align = sizeof(Sint16);
       } else result = EC_IllegalCall;
       break;
     case EVR_FL:
       if (EC_Normal == d_curveData->getFloat32Array(pfl32))
       {
-      	rawData = pfl32;
+        rawData = pfl32;
         align = sizeof(Float32);
       } else result = EC_IllegalCall;
       break;
     case EVR_FD:
       if (EC_Normal == d_curveData->getFloat64Array(pfl64))
       {
-      	rawData = pfl64;
+        rawData = pfl64;
         align = sizeof(Float64);
       } else result = EC_IllegalCall;
       break;
     case EVR_SL:
       if (EC_Normal == d_curveData->getSint32Array(psi32))
       {
-      	rawData = psi32;
+        rawData = psi32;
         align = sizeof(Sint32);
       } else result = EC_IllegalCall;
       break;
@@ -255,18 +255,18 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
       result = EC_IllegalCall;
       break;
   }
-  
+
   size_t byteLength = (size_t)(d_curveData->getLength());
   size_t maxidx = 2*numberOfPoints;
   size_t i;
-  
+
   switch (dataVR)
   {
     case 0: // VR=US. align can be 1 or 2
       if ((align==1)||(align==sizeof(Uint16)))
       {
-        if (align==1) swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, byteLength, sizeof(Uint16));
-        if (maxidx*sizeof(Uint16) <= byteLength) 
+        if (align==1) swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Uint16));
+        if (maxidx*sizeof(Uint16) <= byteLength)
         {
           for (i=0; i<maxidx; i++) curveData[i] = (double)(((Uint16 *)rawData)[i]);
         } else result=EC_IllegalCall;
@@ -275,8 +275,8 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     case 1: // VR=SS. align can be 1 or 2
       if ((align==1)||(align==sizeof(Sint16)))
       {
-        if (align==1) swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, byteLength, sizeof(Sint16));
-        if (maxidx*sizeof(Sint16) <= byteLength) 
+        if (align==1) swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Sint16));
+        if (maxidx*sizeof(Sint16) <= byteLength)
         {
           for (i=0; i<maxidx; i++) curveData[i] = (double)(((Sint16 *)rawData)[i]);
         } else result=EC_IllegalCall;
@@ -285,11 +285,11 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     case 2: // VR=FL. align can be 1, 2, 4
       if ((align==1)||(align==sizeof(Uint16))||(align==sizeof(Float32)))
       {
-      	// if data is word aligned, first swap back to little endian OB
-      	if (align==sizeof(Uint16)) swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, byteLength, sizeof(Uint16));
-        if ((align==1)||(align==sizeof(Uint16))) 
-          swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, byteLength, sizeof(Float32));
-        if (maxidx*sizeof(Float32) <= byteLength) 
+        // if data is word aligned, first swap back to little endian OB
+        if (align==sizeof(Uint16)) swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Uint16));
+        if ((align==1)||(align==sizeof(Uint16)))
+          swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Float32));
+        if (maxidx*sizeof(Float32) <= byteLength)
         {
           for (i=0; i<maxidx; i++) curveData[i] = (double)(((Float32 *)rawData)[i]);
         } else result=EC_IllegalCall;
@@ -298,11 +298,11 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     case 3: // VR=FD. align can be 1, 2, 8
       if ((align==1)||(align==sizeof(Uint16))||(align==sizeof(Float64)))
       {
-      	// if data is word aligned, first swap back to little endian OB
-      	if (align==sizeof(Uint16)) swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, byteLength, sizeof(Uint16));
+        // if data is word aligned, first swap back to little endian OB
+        if (align==sizeof(Uint16)) swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Uint16));
         if ((align==1)||(align==sizeof(Uint16)))
-          swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, byteLength, sizeof(Float64));
-        if (maxidx*sizeof(Float64) <= byteLength) 
+          swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Float64));
+        if (maxidx*sizeof(Float64) <= byteLength)
         {
           for (i=0; i<maxidx; i++) curveData[i] = (double)(((Float64 *)rawData)[i]);
         } else result=EC_IllegalCall;
@@ -311,11 +311,11 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     case 4: // VR=SL. align can be 1, 2, 4
       if ((align==1)||(align==sizeof(Uint16))||(align==sizeof(Sint32)))
       {
-      	// if data is word aligned, first swap back to little endian OB
-      	if (align==sizeof(Uint16)) swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, byteLength, sizeof(Uint16));
+        // if data is word aligned, first swap back to little endian OB
+        if (align==sizeof(Uint16)) swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Uint16));
         if ((align==1)||(align==sizeof(Uint16)))
-          swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, byteLength, sizeof(Sint32));
-        if (maxidx*sizeof(Sint32) <= byteLength) 
+          swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, OFstatic_cast(Uint32, byteLength), sizeof(Sint32));
+        if (maxidx*sizeof(Sint32) <= byteLength)
         {
           for (i=0; i<maxidx; i++) curveData[i] = (double)(((Sint32 *)rawData)[i]);
         } else result=EC_IllegalCall;
@@ -324,8 +324,8 @@ OFCondition DVPSCurve::read(DcmItem &dset, Uint8 group)
     default:
       result = EC_IllegalCall;
       break;
-  }  
-    
+  }
+
   return result;
 }
 
