@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  Copyright (C) 1998-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -56,11 +56,11 @@ OFCondition DVPSGraphicLayer::read(DcmItem &dset)
   OFCondition result = EC_Normal;
   DcmStack stack;
 
-  READ_FROM_DATASET(DcmCodeString, graphicLayer)
-  READ_FROM_DATASET(DcmIntegerString, graphicLayerOrder)
-  READ_FROM_DATASET(DcmUnsignedShort, graphicLayerRecommendedDisplayGrayscaleValue)
-  READ_FROM_DATASET(DcmUnsignedShort, graphicLayerRecommendedDisplayRGBValue)
-  READ_FROM_DATASET(DcmLongString, graphicLayerDescription)
+  READ_FROM_DATASET(DcmCodeString, EVR_CS, graphicLayer)
+  READ_FROM_DATASET(DcmIntegerString, EVR_IS, graphicLayerOrder)
+  READ_FROM_DATASET(DcmUnsignedShort, EVR_US, graphicLayerRecommendedDisplayGrayscaleValue)
+  READ_FROM_DATASET(DcmUnsignedShort, EVR_US, graphicLayerRecommendedDisplayRGBValue)
+  READ_FROM_DATASET(DcmLongString, EVR_LO, graphicLayerDescription)
   
   /* Now perform basic sanity checks */
 
