@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1993-2017, OFFIS e.V.
+ *  Copyright (C) 1993-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -138,8 +138,8 @@ main(int argc, char *argv[])
 
   cmd.setOptionColumns(LONGCOL, SHORTCOL);
   cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-    cmd.addOption("--help",                     "-h",        "print this help text and exit", OFCommandLine::AF_Exclusive);
-    cmd.addOption("--version",                               "print version information and exit", OFCommandLine::AF_Exclusive);
+    cmd.addOption("--help",                     "-h",      "print this help text and exit", OFCommandLine::AF_Exclusive);
+    cmd.addOption("--version",                             "print version information and exit", OFCommandLine::AF_Exclusive);
     OFLog::addOptions(cmd);
 
     if (strlen(opt_configFileName) > 16)
@@ -147,113 +147,117 @@ main(int argc, char *argv[])
         OFString opt5 = "use specific configuration file\n(default: ";
         opt5 += opt_configFileName;
         opt5 += ")";
-        cmd.addOption("--config",               "-c",     1, "[f]ilename: string", opt5.c_str());
+        cmd.addOption("--config",               "-c",   1, "[f]ilename: string",
+                                                           opt5.c_str());
     } else {
         OFString opt5 = "[f]ilename: string (default: ";
         opt5 += opt_configFileName;
         opt5 += ")";
-        cmd.addOption("--config",               "-c",     1, opt5.c_str(), "use specific configuration file");
+        cmd.addOption("--config",               "-c",   1, opt5.c_str(),
+                                                           "use specific configuration file");
     }
 #ifdef HAVE_FORK
   cmd.addGroup("multi-process options:", LONGCOL, SHORTCOL + 2);
-    cmd.addOption("--single-process",           "-s",        "single process mode");
-    cmd.addOption("--fork",                                  "fork child process for each assoc. (default)");
+    cmd.addOption("--single-process",           "-s",      "single process mode");
+    cmd.addOption("--fork",                                "fork child process for each assoc. (default)");
 #endif
 
   cmd.addGroup("database options:");
     cmd.addSubGroup("association negotiation:");
-      cmd.addOption("--require-find",                        "reject all MOVE/GET presentation contexts for\nwhich no correspond. FIND context is proposed");
-      cmd.addOption("--no-parallel-store",                   "reject multiple simultaneous STORE presentat.\ncontexts for one application entity title");
-      cmd.addOption("--disable-get",                         "disable C-GET support");
-      cmd.addOption("--allow-shutdown",                      "allow external shutdown via private SOP class");
+      cmd.addOption("--require-find",                      "reject all MOVE/GET presentation contexts for\nwhich no correspond. FIND context is proposed");
+      cmd.addOption("--no-parallel-store",                 "reject multiple simultaneous STORE presentat.\ncontexts for one application entity title");
+      cmd.addOption("--disable-get",                       "disable C-GET support");
+      cmd.addOption("--allow-shutdown",                    "allow external shutdown via private SOP class");
     cmd.addSubGroup("checking identifier validity:");
-      cmd.addOption("--check-find",             "-XF",       "check C-FIND identifier validity");
-      cmd.addOption("--no-check-find",                       "do not check C-FIND identifier validity (def.)");
-      cmd.addOption("--check-move",             "-XM",       "check C-MOVE identifier validity");
-      cmd.addOption("--no-check-move",                       "do not check C-MOVE identifier validity (def.)");
+      cmd.addOption("--check-find",             "-XF",     "check C-FIND identifier validity");
+      cmd.addOption("--no-check-find",                     "do not check C-FIND identifier validity (def.)");
+      cmd.addOption("--check-move",             "-XM",     "check C-MOVE identifier validity");
+      cmd.addOption("--no-check-move",                     "do not check C-MOVE identifier validity (def.)");
     cmd.addSubGroup("restriction of move targets:");
-      cmd.addOption("--move-unrestricted",                   "do not restrict move destination (default)");
-      cmd.addOption("--move-aetitle",           "-ZA",       "restrict move dest. to requesting AE title");
-      cmd.addOption("--move-host",              "-ZH",       "restrict move destination to requesting host");
-      cmd.addOption("--move-vendor",            "-ZV",       "restrict move destination to requesting vendor");
+      cmd.addOption("--move-unrestricted",                 "do not restrict move destination (default)");
+      cmd.addOption("--move-aetitle",           "-ZA",     "restrict move dest. to requesting AE title");
+      cmd.addOption("--move-host",              "-ZH",     "restrict move destination to requesting host");
+      cmd.addOption("--move-vendor",            "-ZV",     "restrict move destination to requesting vendor");
     cmd.addSubGroup("restriction of query/retrieve models:");
-      cmd.addOption("--no-patient-root",        "-QP",       "do not support Patient Root Q/R models");
-      cmd.addOption("--no-study-root",          "-QS",       "do not support Study Root Q/R models");
+      cmd.addOption("--no-patient-root",        "-QP",     "do not support Patient Root Q/R models");
+      cmd.addOption("--no-study-root",          "-QS",     "do not support Study Root Q/R models");
 #ifndef NO_PATIENTSTUDYONLY_SUPPORT
-      cmd.addOption("--no-patient-study",       "-QO",       "do not support Patient/Study Only Q/R models");
+      cmd.addOption("--no-patient-study",       "-QO",     "do not support Patient/Study Only Q/R models");
 #endif
 
   cmd.addGroup("network options:");
     cmd.addSubGroup("association negotiation profiles from configuration file:");
-      cmd.addOption("--assoc-config-file",      "-xf",  3,   "[f]ilename, [i]n-profile, [o]ut-profile: string",
-                                                             "use profile i from f for incoming associations\n"
-                                                             "use profile o from f for outgoing associations");
+      cmd.addOption("--assoc-config-file",      "-xf",  3, "[f]ilename, [i]n-profile, [o]ut-profile: string",
+                                                           "use profile i from f for incoming associations\nuse profile o from f for outgoing associations");
     cmd.addSubGroup("preferred network transfer syntaxes (incoming associations):");
-      cmd.addOption("--prefer-uncompr",         "+x=",       "prefer explicit VR local byte order (default)");
-      cmd.addOption("--prefer-little",          "+xe",       "prefer explicit VR little endian TS");
-      cmd.addOption("--prefer-big",             "+xb",       "prefer explicit VR big endian TS");
+      cmd.addOption("--prefer-uncompr",         "+x=",     "prefer explicit VR local byte order (default)");
+      cmd.addOption("--prefer-little",          "+xe",     "prefer explicit VR little endian TS");
+      cmd.addOption("--prefer-big",             "+xb",     "prefer explicit VR big endian TS");
 #ifndef DISABLE_COMPRESSION_EXTENSION
-      cmd.addOption("--prefer-lossless",        "+xs",       "prefer default JPEG lossless TS");
-      cmd.addOption("--prefer-jpeg8",           "+xy",       "prefer default JPEG lossy TS for 8 bit data");
-      cmd.addOption("--prefer-jpeg12",          "+xx",       "prefer default JPEG lossy TS for 12 bit data");
-      cmd.addOption("--prefer-j2k-lossless",    "+xv",       "prefer JPEG 2000 lossless TS");
-      cmd.addOption("--prefer-j2k-lossy",       "+xw",       "prefer JPEG 2000 lossy TS");
-      cmd.addOption("--prefer-jls-lossless",    "+xt",       "prefer JPEG-LS lossless TS");
-      cmd.addOption("--prefer-jls-lossy",       "+xu",       "prefer JPEG-LS lossy TS");
-      cmd.addOption("--prefer-mpeg2",           "+xm",       "prefer MPEG2 Main Profile @ Main Level TS");
-      cmd.addOption("--prefer-mpeg2-high",      "+xh",       "prefer MPEG2 Main Profile @ High Level TS");
-      cmd.addOption("--prefer-mpeg4",           "+xn",       "prefer MPEG4 AVC/H.264 HP / Level 4.1 TS");
-      cmd.addOption("--prefer-mpeg4-bd",        "+xl",       "prefer MPEG4 AVC/H.264 BD-compatible TS");
-      cmd.addOption("--prefer-mpeg4-2-2d",      "+x2",       "prefer MPEG4 AVC/H.264 HP / Level 4.2 TS (2D)");
-      cmd.addOption("--prefer-mpeg4-2-3d",      "+x3",       "prefer MPEG4 AVC/H.264 HP / Level 4.2 TS (3D)");
-      cmd.addOption("--prefer-mpeg4-2-st",      "+xo",       "prefer MPEG4 AVC/H.264 Stereo / Level 4.2 TS");
-      cmd.addOption("--prefer-hevc",            "+x4",       "prefer HEVC/H.265 Main Profile / Level 5.1 TS");
-      cmd.addOption("--prefer-hevc10",          "+x5",       "prefer HEVC/H.265 Main 10 Profile / Level 5.1 TS");
-      cmd.addOption("--prefer-rle",             "+xr",       "prefer RLE lossless TS");
+      cmd.addOption("--prefer-lossless",        "+xs",     "prefer default JPEG lossless TS");
+      cmd.addOption("--prefer-jpeg8",           "+xy",     "prefer default JPEG lossy TS for 8 bit data");
+      cmd.addOption("--prefer-jpeg12",          "+xx",     "prefer default JPEG lossy TS for 12 bit data");
+      cmd.addOption("--prefer-j2k-lossless",    "+xv",     "prefer JPEG 2000 lossless TS");
+      cmd.addOption("--prefer-j2k-lossy",       "+xw",     "prefer JPEG 2000 lossy TS");
+      cmd.addOption("--prefer-jls-lossless",    "+xt",     "prefer JPEG-LS lossless TS");
+      cmd.addOption("--prefer-jls-lossy",       "+xu",     "prefer JPEG-LS lossy TS");
+      cmd.addOption("--prefer-mpeg2",           "+xm",     "prefer MPEG2 Main Profile @ Main Level TS");
+      cmd.addOption("--prefer-mpeg2-high",      "+xh",     "prefer MPEG2 Main Profile @ High Level TS");
+      cmd.addOption("--prefer-mpeg4",           "+xn",     "prefer MPEG4 AVC/H.264 HP / Level 4.1 TS");
+      cmd.addOption("--prefer-mpeg4-bd",        "+xl",     "prefer MPEG4 AVC/H.264 BD-compatible TS");
+      cmd.addOption("--prefer-mpeg4-2-2d",      "+x2",     "prefer MPEG4 AVC/H.264 HP / Level 4.2 TS (2D)");
+      cmd.addOption("--prefer-mpeg4-2-3d",      "+x3",     "prefer MPEG4 AVC/H.264 HP / Level 4.2 TS (3D)");
+      cmd.addOption("--prefer-mpeg4-2-st",      "+xo",     "prefer MPEG4 AVC/H.264 Stereo / Level 4.2 TS");
+      cmd.addOption("--prefer-hevc",            "+x4",     "prefer HEVC/H.265 Main Profile / Level 5.1 TS");
+      cmd.addOption("--prefer-hevc10",          "+x5",     "prefer HEVC/H.265 Main 10 Profile / Level 5.1 TS");
+      cmd.addOption("--prefer-rle",             "+xr",     "prefer RLE lossless TS");
 #ifdef WITH_ZLIB
-      cmd.addOption("--prefer-deflated",        "+xd",       "prefer deflated expl. VR little endian TS");
+      cmd.addOption("--prefer-deflated",        "+xd",     "prefer deflated expl. VR little endian TS");
 #endif
 #endif
-      cmd.addOption("--implicit",               "+xi",       "accept implicit VR little endian TS only");
+      cmd.addOption("--implicit",               "+xi",     "accept implicit VR little endian TS only");
 
 #ifndef DISABLE_COMPRESSION_EXTENSION
     cmd.addSubGroup("proposed transmission transfer syntaxes (outgoing associations):");
-      cmd.addOption("--propose-uncompr",        "-x=",       "propose all uncompressed TS, explicit VR\nwith local byte ordering first (default)");
-      cmd.addOption("--propose-little",         "-xe",       "propose all uncompressed TS, explicit VR\nlittle endian first");
-      cmd.addOption("--propose-big",            "-xb",       "propose all uncompressed TS, explicit VR\nbig endian first");
-      cmd.addOption("--propose-implicit",       "-xi",       "propose implicit VR little endian TS only");
-      cmd.addOption("--propose-lossless",       "-xs",       "propose default JPEG lossless TS\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-jpeg8",          "-xy",       "propose default JPEG lossy TS for 8 bit data\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-jpeg12",         "-xx",       "propose default JPEG lossy TS for 12 bit data\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-j2k-lossless",   "-xv",       "propose JPEG 2000 lossless TS\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-j2k-lossy",      "-xw",       "propose JPEG 2000 lossy TS\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-jls-lossless",   "-xt",       "propose JPEG-LS lossless TS\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-jls-lossy",      "-xu",       "propose JPEG-LS lossy TS\nand all uncompressed transfer syntaxes");
-      cmd.addOption("--propose-mpeg2",          "-xm",       "propose MPEG2 Main Profile @ Main Level TS");
-      cmd.addOption("--propose-mpeg2-high",     "-xh",       "propose MPEG2 Main Profile @ High Level TS");
-      cmd.addOption("--propose-mpeg4",          "-xn",       "propose MPEG4 AVC/H.264 HP / Level 4.1 TS");
-      cmd.addOption("--propose-mpeg4-bd",       "-xl",       "propose MPEG4 AVC/H.264 BD-compatible TS");
-      cmd.addOption("--propose-mpeg4-2-2d",     "-x2",       "propose MPEG4 AVC/H.264 HP / Level 4.2 TS (2D)");
-      cmd.addOption("--propose-mpeg4-2-3d",     "-x3",       "propose MPEG4 AVC/H.264 HP / Level 4.2 TS (3D)");
-      cmd.addOption("--propose-mpeg4-2-st",     "-xo",       "propose MPEG4 AVC/H.264 Stereo / Level 4.2 TS");
-      cmd.addOption("--propose-hevc",           "-x4",       "propose HEVC/H.265 Main Profile / Level 5.1 TS");
-      cmd.addOption("--propose-hevc10",         "-x5",       "propose HEVC/H.265 Main 10 Profile / Level 5.1 TS");
-      cmd.addOption("--propose-rle",            "-xr",       "propose RLE lossless TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-uncompr",        "-x=",     "propose all uncompressed TS, explicit VR\nwith local byte ordering first (default)");
+      cmd.addOption("--propose-little",         "-xe",     "propose all uncompressed TS, explicit VR\nlittle endian first");
+      cmd.addOption("--propose-big",            "-xb",     "propose all uncompressed TS, explicit VR\nbig endian first");
+      cmd.addOption("--propose-implicit",       "-xi",     "propose implicit VR little endian TS only");
+      cmd.addOption("--propose-lossless",       "-xs",     "propose default JPEG lossless TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-jpeg8",          "-xy",     "propose default JPEG lossy TS for 8 bit data\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-jpeg12",         "-xx",     "propose default JPEG lossy TS for 12 bit data\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-j2k-lossless",   "-xv",     "propose JPEG 2000 lossless TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-j2k-lossy",      "-xw",     "propose JPEG 2000 lossy TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-jls-lossless",   "-xt",     "propose JPEG-LS lossless TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-jls-lossy",      "-xu",     "propose JPEG-LS lossy TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-mpeg2",          "-xm",     "propose MPEG2 Main Profile @ Main Level TS");
+      cmd.addOption("--propose-mpeg2-high",     "-xh",     "propose MPEG2 Main Profile @ High Level TS");
+      cmd.addOption("--propose-mpeg4",          "-xn",     "propose MPEG4 AVC/H.264 HP / Level 4.1 TS");
+      cmd.addOption("--propose-mpeg4-bd",       "-xl",     "propose MPEG4 AVC/H.264 BD-compatible TS");
+      cmd.addOption("--propose-mpeg4-2-2d",     "-x2",     "propose MPEG4 AVC/H.264 HP / Level 4.2 TS (2D)");
+      cmd.addOption("--propose-mpeg4-2-3d",     "-x3",     "propose MPEG4 AVC/H.264 HP / Level 4.2 TS (3D)");
+      cmd.addOption("--propose-mpeg4-2-st",     "-xo",     "propose MPEG4 AVC/H.264 Stereo / Level 4.2 TS");
+      cmd.addOption("--propose-hevc",           "-x4",     "propose HEVC/H.265 Main Profile / Level 5.1 TS");
+      cmd.addOption("--propose-hevc10",         "-x5",     "propose HEVC/H.265 Main 10 Profile / Level 5.1 TS");
+      cmd.addOption("--propose-rle",            "-xr",     "propose RLE lossless TS\nand all uncompressed transfer syntaxes");
 #ifdef WITH_ZLIB
-      cmd.addOption("--propose-deflated",       "-xd",       "propose deflated expl. VR little endian TS\nand all uncompressed transfer syntaxes");
+      cmd.addOption("--propose-deflated",       "-xd",     "propose deflated expl. VR little endian TS\nand all uncompressed transfer syntaxes");
 #endif
 #endif
 
 #ifdef WITH_TCPWRAPPER
     cmd.addSubGroup("network host access control (tcp wrapper):");
-      cmd.addOption("--access-full",            "-ac",       "accept connections from any host (default)");
-      cmd.addOption("--access-control",         "+ac",       "enforce host access control rules");
+      cmd.addOption("--access-full",            "-ac",     "accept connections from any host (default)");
+      cmd.addOption("--access-control",         "+ac",     "enforce host access control rules");
 #endif
 
     cmd.addSubGroup("other network options:");
-      cmd.addOption("--timeout",                "-to",    1, "[s]econds: integer (default: unlimited)", "timeout for connection requests");
-      cmd.addOption("--acse-timeout",           "-ta",    1, "[s]econds: integer (default: 30)", "timeout for ACSE messages");
-      cmd.addOption("--dimse-timeout",          "-td",    1, "[s]econds: integer (default: unlimited)", "timeout for DIMSE messages");
+      cmd.addOption("--timeout",                "-to",  1, "[s]econds: integer (default: unlimited)",
+                                                           "timeout for connection requests");
+      cmd.addOption("--acse-timeout",           "-ta",  1, "[s]econds: integer (default: 30)",
+                                                           "timeout for ACSE messages");
+      cmd.addOption("--dimse-timeout",          "-td",  1, "[s]econds: integer (default: unlimited)",
+                                                           "timeout for DIMSE messages");
       OFString opt4 = "[n]umber of bytes: integer (";
       sprintf(tempstr, "%ld", (long)ASC_MINIMUMPDUSIZE);
       opt4 += tempstr;
@@ -261,73 +265,68 @@ main(int argc, char *argv[])
       sprintf(tempstr, "%ld", (long)ASC_MAXIMUMPDUSIZE);
       opt4 += tempstr;
       opt4 += ")";
-      cmd.addOption("--max-pdu",                "-pdu",   1, opt4.c_str(), "set max receive pdu to n bytes\n(default: use value from configuration file)");
-      cmd.addOption("--disable-host-lookup",    "-dhl",      "disable hostname lookup");
-      cmd.addOption("--refuse",                              "refuse association");
-      cmd.addOption("--reject",                              "reject association if no implement. class UID");
-      cmd.addOption("--ignore",                              "ignore store data, receive but do not store");
-      cmd.addOption("--uid-padding",            "-up",       "silently correct space-padded UIDs");
+      cmd.addOption("--max-pdu",                "-pdu", 1, opt4.c_str(),
+                                                           "set max receive pdu to n bytes\n(default: use value from configuration file)");
+      cmd.addOption("--disable-host-lookup",    "-dhl",    "disable hostname lookup");
+      cmd.addOption("--refuse",                            "refuse association");
+      cmd.addOption("--reject",                            "reject association if no implement. class UID");
+      cmd.addOption("--ignore",                            "ignore store data, receive but do not store");
+      cmd.addOption("--uid-padding",            "-up",     "silently correct space-padded UIDs");
 
-  cmd.addGroup("encoding options:");
-    cmd.addSubGroup("post-1993 value representations:");
-      cmd.addOption("--enable-new-vr",          "+u",        "enable support for new VRs (UN/UT) (default)");
-      cmd.addOption("--disable-new-vr",         "-u",        "disable support for new VRs, convert to OB");
+#ifdef DCMTK_ENABLE_CHARSET_CONVERSION
+  cmd.addGroup("processing options:");
+    cmd.addSubGroup("specific character set:");
+      cmd.addOption("--use-request-charset",    "+Cr",     "try to convert all element values that are\naffected by Specific Character Set (0008,0005)\n"
+                                                           "to the one specified in the request data set,\nfall back to the one specified via\n"
+                                                           "--convert-to-xxx if that is not possible\n(default, unless overridden by config file)");
+      cmd.addOption("--override-charset",       "-Cr",     "convert affected element values to the\ncharacter set specified via --convert-to-xxx,\n"
+                                                           "ignoring the one specified in the request");
+      cmd.addOption("--convert-to-ascii",       "+A7",     "convert affected element values to 7-bit ASCII\n(default, unless overridden by config file)");
+      cmd.addOption("--convert-to-utf8",        "+U8",     "convert affected element values to UTF-8");
+      cmd.addOption("--convert-to-latin1",      "+L1",     "convert affected element values to ISO 8859-1");
+      cmd.addOption("--convert-to-charset",     "+C",   1, "[c]harset: string",
+                                                           "convert affected element values to the char.\nset specified by the DICOM defined term c");
+      cmd.addOption("--transliterate",          "-Ct",     "try to approximate characters that cannot be\nrepresented through similar looking characters");
+      cmd.addOption("--discard-illegal",        "-Cd",     "discard characters that cannot be represented\nin destination character set");
+#endif
 
   cmd.addGroup("output options:");
     cmd.addSubGroup("bit preserving mode:");
-      cmd.addOption("--normal",                 "-B",        "allow implicit format conversions (default)");
-      cmd.addOption("--bit-preserving",         "+B",        "write data exactly as read");
+      cmd.addOption("--normal",                 "-B",      "allow implicit format conversions (default)");
+      cmd.addOption("--bit-preserving",         "+B",      "write data exactly as read");
     cmd.addSubGroup("output file format:");
-      cmd.addOption("--write-file",             "+F",        "write file format (default)");
-      cmd.addOption("--write-dataset",          "-F",        "write data set without file meta information");
+      cmd.addOption("--write-file",             "+F",      "write file format (default)");
+      cmd.addOption("--write-dataset",          "-F",      "write data set without file meta information");
     cmd.addSubGroup("output transfer syntax (not with --bit-preserving or compressed transmission):");
-      cmd.addOption("--write-xfer-same",        "+t=",       "write with same TS as input (default)");
-      cmd.addOption("--write-xfer-little",      "+te",       "write with explicit VR little endian TS");
-      cmd.addOption("--write-xfer-big",         "+tb",       "write with explicit VR big endian TS");
-      cmd.addOption("--write-xfer-implicit",    "+ti",       "write with implicit VR little endian TS");
+      cmd.addOption("--write-xfer-same",        "+t=",     "write with same TS as input (default)");
+      cmd.addOption("--write-xfer-little",      "+te",     "write with explicit VR little endian TS");
+      cmd.addOption("--write-xfer-big",         "+tb",     "write with explicit VR big endian TS");
+      cmd.addOption("--write-xfer-implicit",    "+ti",     "write with implicit VR little endian TS");
 #ifdef WITH_ZLIB
-      cmd.addOption("--write-xfer-deflated",    "+td",       "write with deflated expl. VR little endian TS");
+      cmd.addOption("--write-xfer-deflated",    "+td",     "write with deflated expl. VR little endian TS");
 #endif
+    cmd.addSubGroup("post-1993 value representations:");
+      cmd.addOption("--enable-new-vr",          "+u",      "enable support for new VRs (UN/UT) (default)");
+      cmd.addOption("--disable-new-vr",         "-u",      "disable support for new VRs, convert to OB");
     cmd.addSubGroup("group length encoding (not with --bit-preserving):");
-      cmd.addOption("--group-length-recalc",    "+g=",       "recalculate group lengths if present (default)");
-      cmd.addOption("--group-length-create",    "+g",        "always write with group length elements");
-      cmd.addOption("--group-length-remove",    "-g",        "always write without group length elements");
+      cmd.addOption("--group-length-recalc",    "+g=",     "recalculate group lengths if present (default)");
+      cmd.addOption("--group-length-create",    "+g",      "always write with group length elements");
+      cmd.addOption("--group-length-remove",    "-g",      "always write without group length elements");
     cmd.addSubGroup("length encoding in sequences and items (not with --bit-preserving):");
-      cmd.addOption("--length-explicit",        "+e",        "write with explicit lengths (default)");
-      cmd.addOption("--length-undefined",       "-e",        "write with undefined lengths");
+      cmd.addOption("--length-explicit",        "+e",      "write with explicit lengths (default)");
+      cmd.addOption("--length-undefined",       "-e",      "write with undefined lengths");
     cmd.addSubGroup("data set trailing padding (not with --write-dataset or --bit-preserving):");
-      cmd.addOption("--padding-off",            "-p",        "no padding (default)");
-      cmd.addOption("--padding-create",         "+p",    2,  "[f]ile-pad [i]tem-pad: integer", "align file on multiple of f bytes\nand items on multiple of i bytes");
+      cmd.addOption("--padding-off",            "-p",      "no padding (default)");
+      cmd.addOption("--padding-create",         "+p",   2, "[f]ile-pad [i]tem-pad: integer",
+                                                           "align file on multiple of f bytes\nand items on multiple of i bytes");
 #ifdef WITH_ZLIB
 #ifdef DISABLE_COMPRESSION_EXTENSION
     cmd.addSubGroup("deflate compression level (only with --write-xfer-deflated/same):");
 #else
     cmd.addSubGroup("deflate compression level (only with -xd or --write-xfer-deflated/same):");
 #endif
-      cmd.addOption("--compression-level",      "+cl",   1, "[l]evel: integer (default: 6)",
-                                                            "0=uncompressed, 1=fastest, 9=best compression");
-#endif
-
-#ifdef DCMTK_ENABLE_CHARSET_CONVERSION
-    cmd.addSubGroup("specific character set:");
-      cmd.addOption("--use-request-charset",    "+Cr",    "try to convert all element values that are\n"
-                                                          "affected by Specific Character Set (0008,0005)\n"
-                                                          "to the one specified in the request data set,\n"
-                                                          "fall back to the one specified via\n"
-                                                          "--convert-to-xxx if that is not possible\n"
-                                                          "(default, unless overridden by config file)");
-      cmd.addOption("--override-charset",       "-Cr",    "convert affected element values to the character\n"
-                                                          "set specified via --convert-to-xxx, ignoring\n"
-                                                          "the one specified in the request");
-      cmd.addOption("--convert-to-ascii",       "+A7",    "convert affected element values to 7-bit ASCII\n"
-                                                          "(default, unless overridden by config file)");
-      cmd.addOption("--convert-to-utf8",        "+U8",    "convert affected element values to UTF-8");
-      cmd.addOption("--convert-to-latin1",      "+L1",    "convert affected element values to ISO 8859-1");
-      cmd.addOption("--convert-to-charset",     "+C",  1, "[c]harset: string",
-                                                          "convert affected element values to the character\n"
-                                                          "set specified by the DICOM defined term c");
-      cmd.addOption("--transliterate",          "-Ct",    "try to approximate characters that cannot be\nrepresented through similar looking characters");
-      cmd.addOption("--discard-illegal",        "-Cd",    "discard characters that cannot be represented\nin destination character set");
+      cmd.addOption("--compression-level",      "+cl",  1, "[l]evel: integer (default: 6)",
+                                                           "0=uncompressed, 1=fastest, 9=best compression");
 #endif
 
     /* evaluate command line */
@@ -589,11 +588,6 @@ main(int argc, char *argv[])
         }
       }
 
-      cmd.beginOptionBlock();
-      if (cmd.findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
-      if (cmd.findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
-      cmd.endOptionBlock();
-
       cmd.beginOptionBlock();
       if (cmd.findOption("--normal")) options.bitPreserving_ = OFFalse;
       if (cmd.findOption("--bit-preserving")) options.bitPreserving_ = OFTrue;
@@ -709,6 +703,11 @@ main(int argc, char *argv[])
 #endif
       cmd.endOptionBlock();
 
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
+      if (cmd.findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
+      cmd.endOptionBlock();
+
       cmd.beginOptionBlock();
       if (cmd.findOption("--group-length-recalc"))
       {
