@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1993-2011, OFFIS e.V.
+ *  Copyright (C) 1993-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -39,6 +39,76 @@ extern DCMTK_DCMQRDB_EXPORT OFLogger DCM_dcmqrdbLogger;
 #define DCMQRDB_ERROR(msg) OFLOG_ERROR(DCM_dcmqrdbLogger, msg)
 #define DCMQRDB_FATAL(msg) OFLOG_FATAL(DCM_dcmqrdbLogger, msg)
 
+/** this class describes configuration settings regarding character set handling
+ */
+struct DCMTK_DCMQRDB_EXPORT DcmQueryRetrieveCharacterSetOptions
+{
+    /** Flags for controlling the application behavior regarding character set
+     *  conversion. Might be used for global and for per peer configuration.
+     */
+    enum Flags
+    {
+        /** Activate options for Specific Character Set.
+         *  If this flag is not set, all other flags and the given string for
+         *  Specific Character Set will be ignored, e.g. using the global
+         *  settings instead of peer specific ones.
+         */
+        Configured = 0x01,
+
+        /** Always respond using the given character set, ignoring the
+         *  character set of the request.
+         *  If this flag is not set, the response will be created to the
+         *  character set of the request (if possible).
+         */
+        Override   = 0x02,
+
+        /** Fall back to another character set.
+         *  If this flag is set, the application will try to recover from a
+         *  conversion failure:
+         *    - If 'Override' is set, the application will try to convert
+         *      the response to the character set of the request if conversion
+         *      to the given character set failed.
+         *    - If 'Override' is not set, the application will try to convert
+         *      the response to the given character set if conversion to the
+         *      character set of the response failed.
+         *  If this flag is not set, the response will be left as-is, i.e.
+         *  like it is stored in the index file, if conversion to another
+         *  character set failed.
+         *  @note The fall back conversion might also fail, in which case
+         *    the response will still be left as-is, even if a fall back
+         *    option was given.
+         */
+        Fallback   = 0x04
+    };
+
+    /** Constructor, will construct an object that is marked as
+     *  "not configured".
+     */
+    DcmQueryRetrieveCharacterSetOptions();
+
+    /** extract arguments from the config file.
+     *  @param mnemonic the name of the current option
+     *  @param valueptr the argument(s)
+     *  @return OFTrue if the given name value pair referred to a character
+     *    set option and was 'consumed', OFFalse if it should be handled
+     *    elsewhere.
+     */
+    OFBool parseOptions(const char* mnemonic, char* valueptr);
+
+    /// the given character set
+    OFString characterSet;
+
+    /** determine semantics of the character set value
+     *  @see DcmQueryRetrieveCharacterSet::Flags
+     */
+    unsigned flags;
+
+    /** special character set conversion flags.
+     *  @see OFCharacterEncoding::ConversionFlags
+     */
+    unsigned conversionFlags;
+};
+
 /** this class describes configuration settings for the quota of a storage area
  */
 struct DCMTK_DCMQRDB_EXPORT DcmQueryRetrieveConfigQuota
@@ -314,8 +384,24 @@ public:
    */
   const char *getGroupName() const;
 
+  /*
+   *  get Character Set Options
+   *  Input :
+   *  Return : Character Set Options
+   */
+  const DcmQueryRetrieveCharacterSetOptions& getCharacterSetOptions() const;
+
+  /*
+   *  get Character Set Options
+   *  Input :
+   *  Return : Character Set Options
+   */
+  DcmQueryRetrieveCharacterSetOptions& getCharacterSetOptions();
+
 private:
 
+  friend class DcmQueryRetrieveCharacterSetOptions;
+
   const char* vendorForPeerAETitle(const char *peerAETitle) const;
 
   int countCtnTitles() const;
@@ -434,6 +520,7 @@ private:
   int networkTCPPort_;
   Uint32 maxPDUSize_;
   int maxAssociations_;
+  DcmQueryRetrieveCharacterSetOptions characterSetOptions_;
   DcmQueryRetrieveConfigConfiguration CNF_Config;   /* configuration file contents */
   DcmQueryRetrieveConfigHostTable CNF_HETable;      /* HostEntries Table */
   DcmQueryRetrieveConfigHostTable CNF_VendorTable;  /* Vendor Table */
