@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2017, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -679,6 +679,34 @@ OFCondition DcmSegmentation::getModality(OFString& value,
 }
 
 
+OFCondition DcmSegmentation::importFromSourceImage(const OFString& filename,
+                                                   const bool takeOverCharset)
+{
+  DcmFileFormat dcmff;
+  OFCondition result = dcmff.loadFile(filename);
+  if (result.good())
+  {
+    return importFromSourceImage(*(dcmff.getDataset()), takeOverCharset);
+  }
+  return result;
+}
+
+
+OFCondition DcmSegmentation::importFromSourceImage(DcmItem& dataset,
+                                                   const bool takeOverCharset)
+{
+  OFString FoR;
+  dataset.findAndGetOFStringArray(DCM_FrameOfReferenceUID, FoR);
+  return DcmIODCommon::importHierarchy(
+    dataset,
+    OFTrue,       // Patient
+    OFTrue,       // Study
+    !FoR.empty(), // Frame of Reference
+    OFFalse,      // Series
+    takeOverCharset);
+}
+
+
 /* protected functions */
 
 OFCondition DcmSegmentation::writeSegments(DcmItem& item)
@@ -725,18 +753,28 @@ OFCondition DcmSegmentation::readFrames(DcmItem& dataset)
   }
 
   /* Read all frames into dedicated data structure */
-  size_t pixelsPerFrame = rows * cols;
+  size_t pixelsPerFrame = OFstatic_cast(size_t, rows) * cols;
   if (m_SegmentationType == DcmSegTypes::ST_BINARY)
   {
-      extractFrames(pixels, numberOfFrames, pixelsPerFrame, m_Frames);
+      result = extractFrames(pixels, numberOfFrames, pixelsPerFrame, m_Frames);
+      if (result.bad())
+      {
+        return result;
+    }
   }
   else if (m_SegmentationType == DcmSegTypes::ST_FRACTIONAL)
   {
     for (size_t count = 0; count < numberOfFrames; count++)
     {
       DcmIODTypes::Frame *frame = new DcmIODTypes::Frame();
+      if (!frame) return EC_MemoryExhausted;
       frame->length = pixelsPerFrame;
       frame->pixData= new Uint8[pixelsPerFrame];
+      if (!frame->pixData)
+      {
+          delete frame;
+          return EC_MemoryExhausted;
+      }
       memcpy(frame->pixData, pixels + count* pixelsPerFrame, pixelsPerFrame);
       m_Frames.push_back(frame);
     }
@@ -859,7 +897,7 @@ OFCondition DcmSegmentation::writeDataset(DcmItem& dataset)
 
 OFCondition DcmSegmentation::writeMultiFrameFunctionalGroupsModule(DcmItem& dataset)
 {
-  Uint16 numFrames = DcmIODUtil::limitMaxFrames(m_Frames.size(), "More than 65535 frames provided, limiting Number of Frames to 65535");
+  Uint32 numFrames = DcmIODUtil::limitMaxFrames(m_Frames.size(), "More than 2147483647 frames provided, limiting Number of Frames to 2147483647");
   m_FG.setNumberOfFrames(numFrames);
   OFCondition result = m_FG.write(dataset);
   if (result.good())
@@ -881,13 +919,20 @@ OFCondition DcmSegmentation::writeMultiFrameDimensionModule(DcmItem& dataset)
 
 OFCondition DcmSegmentation::writeFractionalFrames(DcmItem& dataset)
 {
-  Uint16 numFrames = DcmIODUtil::limitMaxFrames(m_Frames.size(), "More than 65535 fractional frames provided, will only write 65535");
+  Uint32 numFrames = DcmIODUtil::limitMaxFrames(m_Frames.size(), "More than 2147483647 frames provided, will only write 2147483647");
   OFCondition result;
   Uint16 rows,cols;
   rows = cols = 0;
   getImagePixel().getRows(rows);
   getImagePixel().getColumns(cols);
-  size_t numBytes = getTotalBytesRequired(rows, cols, numFrames);
+  size_t numBytes = 0;
+  result = getTotalBytesRequired(rows, cols, numFrames, numBytes);
+  if (result.bad()) return result;
+  if (numBytes >= 4294967295UL)
+  {
+    DCMSEG_ERROR("Cannot store Segmentation objects with more than 4 GB pixel data (compression for writing not supported)");
+    return EC_TooManyBytesRequested;
+  }
   Uint8* pixdata = new Uint8[numBytes];
   OFVector<DcmIODTypes::Frame*>::iterator it = m_Frames.begin();
   // Just copy bytes for each frame as is
@@ -904,13 +949,21 @@ OFCondition DcmSegmentation::writeFractionalFrames(DcmItem& dataset)
 
 OFCondition DcmSegmentation::writeBinaryFrames(DcmItem& dataset)
 {
-  Uint16 numFrames, rows, cols;
+  Uint16 rows, cols;
   rows = cols = 0;
-  numFrames = DcmIODUtil::limitMaxFrames(m_Frames.size(), "More than 65535 binary frames provided, will only write 65535");
+  Uint32 numFrames = 0;
+  numFrames = DcmIODUtil::limitMaxFrames(m_Frames.size(), "More than 2147483647 frames provided, will only write 2147483647");
   OFCondition result;
   getImagePixel().getRows(rows);
   getImagePixel().getColumns(cols);
-  size_t numBytes = getTotalBytesRequired(rows, cols, numFrames);
+  size_t numBytes = 0;
+  result = getTotalBytesRequired(rows, cols, numFrames, numBytes);
+  if (result.bad()) return result;
+  if (numBytes >= 4294967295UL)
+  {
+    DCMSEG_ERROR("Cannot store Segmentation objects with more than 4 GB pixel data (compression for writing not supported)");
+    return EC_TooManyBytesRequested;
+  }
   // Holds the pixels for all frames. Each bit represents a pixel which is either
   // 1 (part of segment) or 0 (not part of segment. All frames are directly
   // concatenated, i.e. there are no unused bits between the frames.
@@ -1040,7 +1093,9 @@ OFBool DcmSegmentation::checkPixDataLength(DcmElement* pixelData,
   size_t length = pixelData->getLengthField();
 
   // Find out how many bytes are needed
-  size_t bytesRequired = getTotalBytesRequired(rows, cols, numberOfFrames);
+  size_t bytesRequired = 0;
+  OFCondition result = getTotalBytesRequired(rows, cols, numberOfFrames, bytesRequired);
+  if (result.bad()) return OFFalse;
   // Length found in Pixel Data element is always even
   if (bytesRequired % 2 == 1) bytesRequired++;
   /* Compare expected and actual length */
@@ -1062,31 +1117,25 @@ OFBool DcmSegmentation::checkPixDataLength(DcmElement* pixelData,
 }
 
 
-size_t DcmSegmentation::getBitsPerFrame(const Uint16& rows,
-                                        const Uint16& cols)
+OFCondition DcmSegmentation::getTotalBytesRequired(const Uint16& rows,
+                                                   const Uint16& cols,
+                                                   const Uint32& numberOfFrames,
+                                                   size_t& bytesRequired)
 {
-  size_t bitsRequired = 0;
-  bitsRequired = rows * cols;
-  /* For fractional segmentations we need 1 byte instead of 1 bit for a single pixel */
-  if (m_SegmentationType == DcmSegTypes::ST_FRACTIONAL)
+  OFBool ok = OFStandard::safeMult(OFstatic_cast(size_t, rows), OFstatic_cast(size_t, cols), bytesRequired);
+  if (ok) OFStandard::safeMult(bytesRequired, OFstatic_cast(size_t, numberOfFrames), bytesRequired);
+  if (!ok)
   {
-    bitsRequired *= 8;
+    DCMSEG_ERROR("Cannot compute number of bytes required for Pixel Data since size_t type is too small");
+    return EC_TooManyBytesRequested;
   }
-  return bitsRequired;
-}
 
-
-size_t DcmSegmentation::getTotalBytesRequired(const Uint16& rows,
-                                              const Uint16& cols,
-                                              const Uint16& numberOfFrames)
-{
-  size_t bytesRequired = rows * cols * numberOfFrames;
   /* for binary, we only need one bit per pixel */
   size_t remainder = 0;
   if (m_SegmentationType == DcmSegTypes::ST_BINARY)
   {
     // check whether the 1-bit pixels exactly fit into bytes
-    remainder = (rows * cols) % 8;
+    remainder = (OFstatic_cast(size_t, rows) * cols) % 8;
     // number of bytes that work on an exact fit
     bytesRequired = bytesRequired / 8;
     // add one byte if we have a remainder
@@ -1094,9 +1143,8 @@ size_t DcmSegmentation::getTotalBytesRequired(const Uint16& rows,
     {
       bytesRequired++;
     }
-
   }
-  return bytesRequired;
+  return EC_Normal;
 }
 
 
@@ -1204,22 +1252,62 @@ OFBool DcmSegmentation::check()
     return OFFalse;
   }
 
-  // Check whether we have a Frame Content Macro for each frame
-  for (size_t count = 0; count < m_Frames.size(); count++)
+  // Check rules around Frame of Reference
+
+  // 1. If Derivation Image FG is not present, Frame of Reference is required.
+  OFBool frameOfRefRequired = OFFalse;
+  FGBase* group = m_FGInterface.get(OFstatic_cast(Uint32, 0), DcmFGTypes::EFG_DERIVATIONIMAGE);
+  if (group == NULL)
   {
-    OFBool isPerFrame;
-    FGBase* group = m_FGInterface.get(OFstatic_cast(Uint32, count), DcmFGTypes::EFG_FRAMECONTENT, isPerFrame);
-    if (group == NULL)
+    // Derivation Image FG is not present, FoR is required
+    frameOfRefRequired = OFTrue;
+  }
+  else
+  {
+    // Derivation Image FG present, Frame of Reference is not required
+    frameOfRefRequired = OFFalse;
+  }
+  OFString frameOfRef;
+  getFrameOfReference().getFrameOfReferenceUID(frameOfRef);
+  if (frameOfRefRequired && frameOfRef.empty())
+  {
+    DCMSEG_ERROR("Frame of Reference UID is not set for Segmentation but is required");
+    return OFFalse;
+  }
+
+  // 2. When a Frame of Reference UID is present the segment shall be specified
+  // within that coordinate system, using the Pixel Measures, Plane Position
+  // (Patient) and Plane Orientation (Patient) Functional Groups.
+  if (!frameOfRef.empty())
+  {
+    // Check that each of above FGs is present. We do not check this for
+    // all frames since if it exists for one frame it must exist for all others.
+    // This is a general rule and applies for all FGs, so it is not checked here.
+    FGBase* group = m_FGInterface.get(OFstatic_cast(Uint32, 0), DcmFGTypes::EFG_PIXELMEASURES);
+    if (!group)
     {
-      DCMSEG_ERROR("Frame Content Functional Group not present for frame " << count);
+      DCMSEG_ERROR("Frame of Reference UID is present but Pixel Measures FG is missing");
       return OFFalse;
     }
-    else if (!isPerFrame)
+    group = m_FGInterface.get(OFstatic_cast(Uint32, 0), DcmFGTypes::EFG_PLANEPOSPATIENT);
+    if (!group)
     {
-      DCMSEG_ERROR("Frame Content Functional Group must be per-frame but is shared");
+      DCMSEG_ERROR("Frame of Reference UID is present but Plane Position (Patient) FG is missing");
+      return OFFalse;
+    }
+    group = m_FGInterface.get(OFstatic_cast(Uint32, 0), DcmFGTypes::EFG_PLANEORIENTPATIENT);
+    if (!group)
+    {
+      DCMSEG_ERROR("Frame of Reference UID is present but Plane Orientation (Patient) FG is missing");
       return OFFalse;
     }
   }
+  // Another condition cannot be checked since we do not have access to the
+  // datasets of the source images:
+  // 3. If FoR is present but not the same in images this segmentation applies to,
+  // (those in Derivation Image FG), each pixel of the segmentation shall
+  // correspond to a pixel in a referenced image (i.e. they must share the same
+  // size and resolution).
 
   return OFTrue;
 }
@@ -1256,10 +1344,10 @@ OFCondition DcmSegmentation::decompress(DcmDataset& dset)
 }
 
 
-void DcmSegmentation::extractFrames(Uint8* pixData,
-                                   const size_t numFrames,
-                                   const size_t bitsPerFrame,
-                                   OFVector< DcmIODTypes::Frame* >& results)
+OFCondition DcmSegmentation::extractFrames(Uint8* pixData,
+                                           const size_t numFrames,
+                                           const size_t bitsPerFrame,
+                                           OFVector< DcmIODTypes::Frame* >& results)
 {
   // Will hold the bit position (0-7) that the current frame starts from. The
   // first frame will always start at bit 0.
@@ -1281,23 +1369,28 @@ void DcmSegmentation::extractFrames(Uint8* pixData,
     DcmIODTypes::Frame* frame = new DcmIODTypes::Frame();
     frame->length = frameLengthBytes;
     frame->pixData = new Uint8[frameLengthBytes];
+    if (!frame->pixData)
+    {
+        return EC_MemoryExhausted;
+    }
     memcpy(frame->pixData, readPos, frame->length);
     // If we have been copying too much, i.e the first bits of the frame
     // actually belong to the former frame, shift the whole frame this amount
-    // of bits to the left in order to shift the superfluous bits out
+    // of bits to the left in order to shift the superfluous bits out, i.e.
+    // make frame start at byte boundary.
     if (bitShift > 0)
     {
-      DcmSegUtils::shiftLeft(frame->pixData, frame->length, 8-bitShift);
+      DcmSegUtils::alignFrameOnByteBoundary(frame->pixData, frame->length, 8-bitShift);
     }
     // Adapt last byte by masking out unused bits (i.e. those belonging to next frame).
     // A reader should ignore those unused bits anyway.
-    frame->pixData[frame->length-1] = (frame->pixData[frame->length-1] >> (overlapBits)) << (overlapBits);
+    frame->pixData[frame->length-1] = (frame->pixData[frame->length-1] << (overlapBits)) >> (overlapBits);
     // Store frame
     results.push_back(frame);
     // Compute the bitshift created by this frame
     bitShift = ( 8- ((f+1) * bitsPerFrame) % 8 ) % 8;
-    // If the last byte read has not been used completely, i.e. it contains
-    // also bytes of the next frame, rewind read position to the last byte
+    // If the previous byte read has not been used completely, i.e. it contains
+    // also bytes of the next frame, rewind read position to the previous byte
     // that was partially read. Otherwise skip to the next full byte.
     if (bitShift > 0)
     {
@@ -1308,6 +1401,7 @@ void DcmSegmentation::extractFrames(Uint8* pixData,
       readPos = readPos + frame->length;
     }
   }
+  return EC_Normal;
 }
 
 
@@ -1325,20 +1419,22 @@ void DcmSegmentation::concatFrames(OFVector< DcmIODTypes::Frame* > frames,
   {
     DCMSEG_DEBUG("Packing segmentation frame #" << f+1 << "/" << frames.size());
     // Backup first byte of the destination since it may contain bits of the
-    // last frame; mask out those bits not belonging to last frame.
-    firstByte = (writePos[0] >> freeBits) << freeBits;
+    // previous frame; mask out those bits not belonging to previous frame.
+    // This will potentially create some empty bits on the left of the byte,
+    // that the current frame can use to store the its own first bits.
+    firstByte = (writePos[0] << freeBits) >> freeBits;
     memcpy(writePos, (*frame)->pixData, (*frame)->length);
-    // If the last frame left over some unused bits, shift the current frame
-    // that number of bits to the right and restore the original bits of the
-    // last frame
+    // If the previous frame left over some unused bits, shift the current frame
+    // that number of bits to the left, and restore the original bits of the
+    // previous frame that are overwritten by the shifting operation.
     if (freeBits > 0)
     {
-      DcmSegUtils::shiftRight(writePos, (*frame)->length, 8-freeBits);
+      DcmSegUtils::alignFrameOnBitPosition(writePos, (*frame)->length, 8-freeBits);
       writePos[0] |= firstByte;
     }
-    // Compute free bits left over from this frame in the last byte written
+    // Compute free bits left over from this frame in the previous byte written
     freeBits = (8 - (( (f+1) * bitsPerFrame ) % 8)) % 8;
-    // If we have free bits, the last byte written to will be the first byte
+    // If we have free bits, the previous byte written to will be the first byte
     // we write to for the next frame. Otherwise start with a fresh destination
     // byte.
     if (freeBits > 0)
