@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  Copyright (C) 1998-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -65,6 +65,15 @@ OFCondition SiRSA::sign(
       case EMT_MD5:
         openSSLmac = NID_md5;
         break;
+      case EMT_SHA256:
+        openSSLmac = NID_sha256;
+        break;
+      case EMT_SHA384:
+        openSSLmac = NID_sha384;
+        break;
+      case EMT_SHA512:
+        openSSLmac = NID_sha512;
+        break;
     }
     unsigned int sigLen = 0;
     // we have to cast away const on inputHash yet because of OpenSSL limitations
@@ -98,6 +107,15 @@ OFCondition SiRSA::verify(
       case EMT_MD5:
         openSSLmac = NID_md5;
         break;
+      case EMT_SHA256:
+        openSSLmac = NID_sha256;
+        break;
+      case EMT_SHA384:
+        openSSLmac = NID_sha384;
+        break;
+      case EMT_SHA512:
+        openSSLmac = NID_sha512;
+        break;
     }
     // we have to cast away const on inputHash yet because of OpenSSL limitations
     // we have to cast away const on inputSignature yet because of OpenSSL limitations
