@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -28,8 +28,6 @@
 
 #include "dcmtk/dcmsr/dsrtypes.h"
 
-#include "dcmtk/ofstd/ofstring.h"
-
 
 /*---------------------*
  *  class declaration  *
@@ -76,6 +74,18 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
      */
     DSRCompositeReferenceValue &operator=(const DSRCompositeReferenceValue &referenceValue);
 
+    /** comparison operator "equal"
+     ** @param  referenceValue  reference value that should be compared to the current one
+     ** @return OFTrue if both composite reference values are equal, OFFalse otherwise
+     */
+    OFBool operator==(const DSRCompositeReferenceValue &referenceValue) const;
+
+    /** comparison operator "not equal"
+     ** @param  referenceValue  reference value that should be compared to the current one
+     ** @return OFTrue if both composite reference values are not equal, OFFalse otherwise
+     */
+    OFBool operator!=(const DSRCompositeReferenceValue &referenceValue) const;
+
     /** clear all internal variables.
      *  Since an empty reference value is invalid the reference becomes invalid afterwards.
      */
@@ -89,11 +99,19 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
     virtual OFBool isValid() const;
 
     /** check whether the current reference value is empty.
-     *  Checks whether both UIDs of the reference value are empty.
+     *  Checks whether both mandatory UIDs of the reference value are empty.
      ** @return OFTrue if value is empty, OFFalse otherwise
      */
     virtual OFBool isEmpty() const;
 
+    /** check whether the current reference value is complete, i.e.\ whether both
+     *  mandatory UIDs are non-empty.  This is just a basic check that might be useful
+     *  for "validating" input data.  See isValid() for a more sophisticated way of
+     *  checking the current reference value.
+     ** @return OFTrue if value is complete, OFFalse otherwise
+     */
+    virtual OFBool isComplete() const;
+
     /** print reference value.
      *  The output of a typical composite reference value looks like this: (BasicTextSR,"1.2.3").
      *  If the SOP class UID is unknown, the UID is printed instead of the related name.
@@ -127,7 +145,7 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
      *  enabled, a warning message is printed if the sequence is absent or contains more than
      *  one item.
      ** @param  dataset  DICOM dataset from which the sequence should be read
-     *  @param  tagKey   DICOM tag specifying the attribute (= sequence) which should be read
+     *  @param  tagKey   DICOM tag specifying the attribute (= sequence) that should be read
      *  @param  type     value type of the sequence (valid value: "1", "2", something else)
      *                   This parameter is used for checking purpose, any difference is reported.
      *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
@@ -141,7 +159,7 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
     /** write referenced SOP sequence to dataset.
      *  If the value is empty an empty sequence (without any items) is written.
      ** @param  dataset  DICOM dataset to which the sequence should be written
-     *  @param  tagKey   DICOM tag specifying the attribute (= sequence) which should be written
+     *  @param  tagKey   DICOM tag specifying the attribute (= sequence) that should be written
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition writeSequence(DcmItem &dataset,
@@ -168,6 +186,13 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
         return SOPClassUID;
     }
 
+    /** get name associated with the SOP class UID (if any)
+     ** @param  defaultName  string value that is returned if the SOP class UID is unknown
+     ** @return name associated with the current SOP class UID (might be empty, e.g. in case
+     *          the SOP class UID is empty or 'defaultName' is an empty string)
+     */
+    const OFString getSOPClassName(const OFString &defaultName = "unknown SOP Class UID") const;
+
     /** get SOP instance UID
      ** @return current SOP instance UID (might be invalid or an empty string)
      */
@@ -215,6 +240,18 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
                              const OFString &sopInstanceUID,
                              const OFBool check = OFTrue);
 
+    /** set SOP class UID and SOP instance UID value from dataset.
+     *  Internally, the methods setSOPClassUID() and setSOPInstanceUID() are called with the
+     *  given 'dataset' and the tags DCM_SOPClassUID and DCM_SOPInstanceUID, respectively.
+     *  I.e., the SOP class UID might be set even if the SOP instance UID value is invalid.
+     ** @param  dataset  DICOM dataset from which the UID values should be retrieved
+     *  @param  check    if enabled, check retrieved UID values for validity before setting
+     *                   them.  See checkXXX() for details. Empty values are never accepted.
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    OFCondition setReference(DcmItem &dataset,
+                             const OFBool check = OFTrue);
+
     /** set SOP class UID value.
      *  Before setting the value, it is usually checked.  If the value is invalid, the current
      *  value is not replaced and remains unchanged.
