@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2016, J. Riesmeier, Oldenburg, Germany
+ *  Copyright (C) 2015-2017, J. Riesmeier, Oldenburg, Germany
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  Source file for class TID1500_MeasurementReport
@@ -13,6 +13,7 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmsr/cmr/tid1500.h"
+#include "dcmtk/dcmsr/cmr/tid15def.h"
 #include "dcmtk/dcmsr/cmr/logger.h"
 #include "dcmtk/dcmsr/codes/dcm.h"
 #include "dcmtk/dcmsr/codes/umls.h"
@@ -33,31 +34,34 @@
 #define LAST_PROCEDURE_REPORTED          2
 #define IMAGING_MEASUREMENTS             3
 #define LAST_VOLUMETRIC_ROI_MEASUREMENTS 4
-#define QUALITATIVE_EVALUATIONS          5
+#define LAST_MEASUREMENT_GROUP           5
+#define QUALITATIVE_EVALUATIONS          6
+#define NUMBER_OF_LIST_ENTRIES           7
 
 // general information on TID 1500 (Measurement Report)
 #define TEMPLATE_NUMBER      "1500"
 #define MAPPING_RESOURCE     "DCMR"
 #define MAPPING_RESOURCE_UID UID_DICOMContentMappingResource
-#define TEMPLATE_TYPE        OFTrue  /* extensible */
-
-// conditions constants
-makeOFConditionConst(CMR_EC_NoMeasurementReport, OFM_dcmsr, 1500, OF_error, "No Measurement Report");
+#define TEMPLATE_TYPE        OFTrue   /* extensible */
+#define TEMPLATE_ORDER       OFFalse  /* non-significant */
 
 
-TID1500_MeasurementReport::TID1500_MeasurementReport(const CID7021_MeasurementReportDocumentTitles &title)
+TID1500_MeasurementReport::TID1500_MeasurementReport(const CID7021_MeasurementReportDocumentTitles &title,
+                                                     const OFBool check)
   : DSRRootTemplate(DT_EnhancedSR, TEMPLATE_NUMBER, MAPPING_RESOURCE, MAPPING_RESOURCE_UID),
     Language(new TID1204_LanguageOfContentItemAndDescendants()),
     ObservationContext(new TID1001_ObservationContext()),
     ImageLibrary(new TID1600_ImageLibrary()),
-    VolumetricROIMeasurements(new TID1411_Measurements())
+    VolumetricROIMeasurements(new TID1411_Measurements()),
+    MeasurementGroup(new TID1501_Measurements())
 {
     setExtensible(TEMPLATE_TYPE);
+    setOrderSignificant(TEMPLATE_ORDER);
     /* need to store position of various content items */
-    reserveEntriesInNodeList(6, OFTrue /*initialize*/);
+    reserveEntriesInNodeList(NUMBER_OF_LIST_ENTRIES, OFTrue /*initialize*/);
     /* if specified, create an initial report */
     if (title.hasSelectedValue())
-        createMeasurementReport(title);
+        createMeasurementReport(title, check);
 }
 
 
@@ -68,6 +72,7 @@ void TID1500_MeasurementReport::clear()
     ObservationContext->clear();
     ImageLibrary->clear();
     VolumetricROIMeasurements->clear();
+    MeasurementGroup->clear();
 }
 
 
@@ -76,7 +81,9 @@ OFBool TID1500_MeasurementReport::isValid() const
     /* check whether base class is valid and all required content items are present */
     return DSRRootTemplate::isValid() &&
         Language->isValid() && ObservationContext->isValid() && ImageLibrary->isValid() &&
-        hasProcedureReported() && (hasImagingMeasurements() || hasQualitativeEvaluations());
+        hasProcedureReported() && (hasImagingMeasurements() || hasQualitativeEvaluations()) &&
+        (VolumetricROIMeasurements->isEmpty() || VolumetricROIMeasurements->isValid()) &&
+        (MeasurementGroup->isEmpty() || MeasurementGroup->isValid());
 }
 
 
@@ -164,6 +171,46 @@ OFBool TID1500_MeasurementReport::hasVolumetricROIMeasurements(const OFBool chec
 }
 
 
+OFBool TID1500_MeasurementReport::hasIndividualMeasurements(const OFBool checkChildren) const
+{
+    OFBool result = OFFalse;
+    /* need to check for child nodes? */
+    if (checkChildren)
+    {
+        DSRDocumentTreeNodeCursor cursor(getRoot());
+        /* go to content item at TID 1500 (Measurement Report) Row 9 */
+        if (gotoEntryFromNodeList(cursor, LAST_MEASUREMENT_GROUP) > 0)
+        {
+            /* check whether any of the "included TID 1501 templates" is non-empty */
+            while (cursor.isValid() && (cursor.getNode()->getValueType() == VT_includedTemplate))
+            {
+                const DSRSubTemplate *subTempl = OFstatic_cast(const DSRIncludedTemplateTreeNode *, cursor.getNode())->getValue().get();
+                if (subTempl != NULL)
+                {
+                    if (subTempl->compareTemplateIdentication("1501", "DCMR"))
+                    {
+                        result = !subTempl->isEmpty();
+                        if (result) break;
+                    } else {
+                        /* exit loop */
+                        break;
+                    }
+                }
+                if (cursor.gotoPrevious() == 0)
+                {
+                    /* invalidate cursor */
+                    cursor.clear();
+                }
+            }
+        }
+    } else {
+        /* check for content item at TID 1500 (Measurement Report) Row 9 */
+        result = (getEntryFromNodeList(LAST_MEASUREMENT_GROUP) > 0);
+    }
+    return result;
+}
+
+
 OFBool TID1500_MeasurementReport::hasQualitativeEvaluations(const OFBool checkChildren) const
 {
     OFBool result = OFFalse;
@@ -198,11 +245,12 @@ OFCondition TID1500_MeasurementReport::getDocumentTitle(DSRCodedEntryValue &titl
 }
 
 
-OFCondition TID1500_MeasurementReport::createNewMeasurementReport(const CID7021_MeasurementReportDocumentTitles &title)
+OFCondition TID1500_MeasurementReport::createNewMeasurementReport(const CID7021_MeasurementReportDocumentTitles &title,
+                                                                  const OFBool check)
 {
     clear();
     /* TID 1500 (Measurement Report) Row 1 */
-    return createMeasurementReport(title);
+    return createMeasurementReport(title, check);
 }
 
 
@@ -238,26 +286,60 @@ OFCondition TID1500_MeasurementReport::addProcedureReported(const CID100_Quantit
 }
 
 
-OFCondition TID1500_MeasurementReport::addVolumetricROIMeasurements()
+OFCondition TID1500_MeasurementReport::addVolumetricROIMeasurements(const OFBool checkEmpty)
 {
-    OFCondition result = CMR_EC_NoMeasurementReport;
+    OFCondition result = EC_Normal;
     /* go to content item at TID 1500 (Measurement Report) Row 8 */
     if (gotoEntryFromNodeList(this, LAST_VOLUMETRIC_ROI_MEASUREMENTS) > 0)
     {
-        /* create new instance of TID 1411 (Volumetric ROI Measurements) */
-        TID1411_Measurements *subTempl = new TID1411_Measurements();
-        if (subTempl != NULL)
+        /* check whether the current instance of TID 1411 is non-empty (if needed) */
+        if (!checkEmpty || !VolumetricROIMeasurements->isEmpty())
         {
-            /* store (shared) reference to new instance */
-            VolumetricROIMeasurements.reset(subTempl);
-            /* and add it to the current template (TID 1500 - Row 8) */
-            STORE_RESULT(includeTemplate(VolumetricROIMeasurements, AM_afterCurrent, RT_contains));
-            CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 8"));
-            GOOD_RESULT(storeEntryInNodeList(LAST_VOLUMETRIC_ROI_MEASUREMENTS, getNodeID()));
-            /* tbc: what if the call of includeTemplate() fails? */
-        } else
-            result = EC_MemoryExhausted;
-    }
+            /* create new instance of TID 1411 (Volumetric ROI Measurements) */
+            TID1411_Measurements *subTempl = new TID1411_Measurements();
+            if (subTempl != NULL)
+            {
+                /* store (shared) reference to new instance */
+                VolumetricROIMeasurements.reset(subTempl);
+                /* and add it to the current template (TID 1500 - Row 8) */
+                STORE_RESULT(includeTemplate(VolumetricROIMeasurements, AM_afterCurrent, RT_contains));
+                CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 8"));
+                GOOD_RESULT(storeEntryInNodeList(LAST_VOLUMETRIC_ROI_MEASUREMENTS, getNodeID()));
+                /* tbc: what if the call of includeTemplate() fails? */
+            } else
+                result = EC_MemoryExhausted;
+        }
+    } else
+        result = CMR_EC_NoMeasurementReport;
+    return result;
+}
+
+
+OFCondition TID1500_MeasurementReport::addIndividualMeasurements(const OFBool checkEmpty)
+{
+    OFCondition result = EC_Normal;
+    /* go to content item at TID 1500 (Measurement Report) Row 9 */
+    if (gotoEntryFromNodeList(this, LAST_MEASUREMENT_GROUP) > 0)
+    {
+        /* check whether the current instance of TID 1501 is non-empty (if needed) */
+        if (!checkEmpty || !MeasurementGroup->isEmpty())
+        {
+            /* create new instance of TID 1501 (Measurement Group) */
+            TID1501_Measurements *subTempl = new TID1501_Measurements();
+            if (subTempl != NULL)
+            {
+                /* store (shared) reference to new instance */
+                MeasurementGroup.reset(subTempl);
+                /* and add it to the current template (TID 1500 - Row 9) */
+                STORE_RESULT(includeTemplate(MeasurementGroup, AM_afterCurrent, RT_contains));
+                CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 9"));
+                GOOD_RESULT(storeEntryInNodeList(LAST_MEASUREMENT_GROUP, getNodeID()));
+                /* tbc: what if the call of includeTemplate() fails? */
+            } else
+                result = EC_MemoryExhausted;
+        }
+    } else
+        result = CMR_EC_NoMeasurementReport;
     return result;
 }
 
@@ -312,7 +394,8 @@ OFCondition TID1500_MeasurementReport::addQualitativeEvaluation(const DSRCodedEn
 
 // protected methods
 
-OFCondition TID1500_MeasurementReport::createMeasurementReport(const CID7021_MeasurementReportDocumentTitles &title)
+OFCondition TID1500_MeasurementReport::createMeasurementReport(const CID7021_MeasurementReportDocumentTitles &title,
+                                                               const OFBool check)
 {
     OFCondition result = EC_IllegalParameter;
     /* make sure that there is a coded entry */
@@ -322,11 +405,10 @@ OFCondition TID1500_MeasurementReport::createMeasurementReport(const CID7021_Mea
         if (isEmpty())
         {
             /* TID 1500 (Measurement Report) Row 1 */
-            STORE_RESULT(addContentItem(RT_isRoot, VT_Container, title));
+            STORE_RESULT(addContentItem(RT_isRoot, VT_Container, title, check));
             CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 1"));
             /* store ID of root node for later use */
-            if (result.good())
-                storeEntryInNodeList(MEASUREMENT_REPORT, getNodeID());
+            GOOD_RESULT(storeEntryInNodeList(MEASUREMENT_REPORT, getNodeID()));
             /* TID 1500 (Measurement Report) Row 2 */
             CHECK_RESULT(includeTemplate(Language, AM_belowCurrent, RT_hasConceptMod));
             CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 2"));
@@ -345,6 +427,10 @@ OFCondition TID1500_MeasurementReport::createMeasurementReport(const CID7021_Mea
             CHECK_RESULT(includeTemplate(VolumetricROIMeasurements, AM_belowCurrent, RT_contains));
             CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 8"));
             GOOD_RESULT(storeEntryInNodeList(LAST_VOLUMETRIC_ROI_MEASUREMENTS, getNodeID()));
+            /* TID 1500 (Measurement Report) Row 9 */
+            CHECK_RESULT(includeTemplate(MeasurementGroup, AM_afterCurrent, RT_contains));
+            CHECK_RESULT(getCurrentContentItem().setAnnotationText("TID 1500 - Row 9"));
+            GOOD_RESULT(storeEntryInNodeList(LAST_MEASUREMENT_GROUP, getNodeID()));
             /* if anything went wrong, clear the report */
             BAD_RESULT(clear());
         } else
