@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2017, OFFIS e.V.
+ *  Copyright (C) 2000-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -56,7 +56,7 @@ OFBool DSRCodeTreeNode::operator==(const DSRDocumentTreeNode &node) const
     if (result)
     {
         /* it's safe to cast the type since the value type has already been checked */
-        result = DSRCodedEntryValue::operator==(*OFstatic_cast(const DSRCodedEntryValue *, OFstatic_cast(const DSRCodeTreeNode *, &node)));
+        result = DSRCodedEntryValue::operator==(OFstatic_cast(const DSRCodeTreeNode &, node).getValue());
     }
     return result;
 }
@@ -69,7 +69,7 @@ OFBool DSRCodeTreeNode::operator!=(const DSRDocumentTreeNode &node) const
     if (!result)
     {
         /* it's safe to cast the type since the value type has already been checked */
-        result = DSRCodedEntryValue::operator!=(*OFstatic_cast(const DSRCodedEntryValue *, OFstatic_cast(const DSRCodeTreeNode *, &node)));
+        result = DSRCodedEntryValue::operator!=(OFstatic_cast(const DSRCodeTreeNode &, node).getValue());
     }
     return result;
 }
