@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -72,6 +72,20 @@ DSRCompositeReferenceValue &DSRCompositeReferenceValue::operator=(const DSRCompo
 }
 
 
+OFBool DSRCompositeReferenceValue::operator==(const DSRCompositeReferenceValue &referenceValue) const
+{
+    return (SOPClassUID == referenceValue.SOPClassUID) &&
+           (SOPInstanceUID == referenceValue.SOPInstanceUID);
+}
+
+
+OFBool DSRCompositeReferenceValue::operator!=(const DSRCompositeReferenceValue &referenceValue) const
+{
+    return (SOPClassUID != referenceValue.SOPClassUID) ||
+           (SOPInstanceUID != referenceValue.SOPInstanceUID);
+}
+
+
 void DSRCompositeReferenceValue::clear()
 {
     SOPClassUID.clear();
