@@ -56,6 +56,7 @@
 #include "dcmtk/dcmsr/dsrrrdcc.h"
 #include "dcmtk/dcmsr/dsracqcc.h"
 #include "dcmtk/dcmsr/dsrsaecc.h"
+#include "dcmtk/dcmsr/dsrprdcc.h"
 
 #include "dcmtk/dcmdata/dcuid.h"
 #include "dcmtk/dcmdata/dcvrda.h"
@@ -907,7 +908,7 @@ DSRTypes::E_CharacterSet DSRTypes::definedTermToCharacterSet(const OFString &def
 
 OFBool DSRTypes::isDocumentTypeSupported(const E_DocumentType documentType)
 {
-    return (documentType != DT_invalid) && (documentType != DT_ExtensibleSR) && (documentType != DT_PatientRadiationDoseSR);
+    return (documentType != DT_invalid) && (documentType != DT_ExtensibleSR);
 }
 
 
@@ -1495,7 +1496,7 @@ DSRIODConstraintChecker *DSRTypes::createIODConstraintChecker(const E_DocumentTy
             checker = new DSRSimplifiedAdultEchoSRConstraintChecker();
             break;
         case DT_PatientRadiationDoseSR:
-            /* not yet supported */
+            checker = new DSRPatientRadiationDoseSRConstraintChecker();
             break;
         case DT_invalid:
             /* nothing to do */
