@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2005-2011, OFFIS e.V.
+ *  Copyright (C) 2005-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRXRayRadiationDoseSRConstraintChecker
@@ -49,9 +49,12 @@ OFBool DSRXRayRadiationDoseSRConstraintChecker::isTemplateSupportRequired() cons
 }
 
 
-const char *DSRXRayRadiationDoseSRConstraintChecker::getRootTemplateIdentifier() const
+OFCondition DSRXRayRadiationDoseSRConstraintChecker::getRootTemplateIdentification(OFString &templateIdentifier,
+                                                                                   OFString &mappingResource) const
 {
-    return NULL;
+    templateIdentifier.clear();
+    mappingResource.clear();
+    return EC_Normal;
 }
 
 
@@ -113,7 +116,7 @@ OFBool DSRXRayRadiationDoseSRConstraintChecker::checkContentRelationship(const E
                      (targetValueType == VT_DateTime) || (targetValueType == VT_UIDRef)    || (targetValueType == VT_PName) ||
                      (targetValueType == VT_Image)    || (targetValueType == VT_Composite) || (targetValueType == VT_Container);
         }
-        /* row 7 of the table - introduced with CP 1076 */
+        /* row 7 of the table - introduced with CP-1076 */
         else if ((relationshipType == RT_hasProperties) && (sourceValueType == VT_PName))
         {
             result = (targetValueType == VT_Text) || (targetValueType == VT_Code) || (targetValueType == VT_DateTime) ||
