@@ -40,11 +40,15 @@ OFTEST_REGISTER(dcmsr_assignTree);
 OFTEST_REGISTER(dcmsr_cloneSubTree_1);
 OFTEST_REGISTER(dcmsr_cloneSubTree_2);
 OFTEST_REGISTER(dcmsr_extractSubTree);
+OFTEST_REGISTER(dcmsr_gotoParentUntilRoot);
 OFTEST_REGISTER(dcmsr_gotoAnnotatedTreeNode);
 OFTEST_REGISTER(dcmsr_addContentItem_1);
 OFTEST_REGISTER(dcmsr_addContentItem_2);
 OFTEST_REGISTER(dcmsr_copyContentItem);
 OFTEST_REGISTER(dcmsr_getCurrentNode);
+OFTEST_REGISTER(dcmsr_compareNodes);
+OFTEST_REGISTER(dcmsr_gotoNodeByValue);
+OFTEST_REGISTER(dcmsr_gotoMatchingNode);
 OFTEST_REGISTER(dcmsr_gotoNamedNode);
 OFTEST_REGISTER(dcmsr_gotoNamedChildNode);
 OFTEST_REGISTER(dcmsr_gotoNamedNodeInSubTree);
@@ -67,6 +71,7 @@ OFTEST_REGISTER(dcmsr_setDocumentTree);
 OFTEST_REGISTER(dcmsr_rootTemplate);
 OFTEST_REGISTER(dcmsr_subTemplate_1);
 OFTEST_REGISTER(dcmsr_subTemplate_2);
+OFTEST_REGISTER(dcmsr_subTemplate_3);
 OFTEST_REGISTER(dcmsr_createExpandedTree);
 OFTEST_REGISTER(dcmsr_templateWithByReferenceRelationship_1);
 OFTEST_REGISTER(dcmsr_templateWithByReferenceRelationship_2);
@@ -86,7 +91,9 @@ OFTEST_REGISTER(dcmsr_CID10013e_CTAcquisitionType);
 OFTEST_REGISTER(dcmsr_CID10033e_CTReconstructionAlgorithm);
 OFTEST_REGISTER(dcmsr_TID1001_ObservationContext);
 OFTEST_REGISTER(dcmsr_TID1204_LanguageOfContentItemAndDescendants);
+OFTEST_REGISTER(dcmsr_TID1411_VolumetricROIMeasurements);
 OFTEST_REGISTER(dcmsr_TID1500_MeasurementReport);
+OFTEST_REGISTER(dcmsr_TID1501_MeasurementGroup);
 OFTEST_REGISTER(dcmsr_TID1600_ImageLibrary);
 OFTEST_REGISTER(dcmsr_CMR_SRNumericMeasurementValue);
 OFTEST_REGISTER(dcmsr_CMR_SRNumericMeasurementValueWithUnits_baselineGroup);
