@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2014-2017, J. Riesmeier, Oldenburg, Germany
+ *  Copyright (C) 2014-2018, J. Riesmeier, Oldenburg, Germany
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -29,6 +29,7 @@
 #include "dcmtk/dcmsr/dsrdoc.h"
 #include "dcmtk/dcmsr/dsrdncsr.h"
 #include "dcmtk/dcmsr/dsrtpltn.h"
+#include "dcmtk/dcmsr/dsrreftn.h"
 #include "dcmtk/dcmsr/dsrimgtn.h"
 #include "dcmtk/dcmsr/dsrnumtn.h"
 #include "dcmtk/dcmsr/dsrtextn.h"
@@ -160,6 +161,23 @@ OFTEST(dcmsr_compareNodes)
     /* and compare it to the initial node */
     OFCHECK(numNode != node);
     delete newNode;
+    /* try the same with an "included template" tree node */
+    DSRIncludedTemplateTreeNode templNode1(DSRSharedSubTemplate(NULL), DSRTypes::RT_contains);
+    DSRIncludedTemplateTreeNode templNode2(templNode1);
+    OFCHECK(templNode1 == templNode2);
+    /* and a "by-reference" tree node */
+    DSRByReferenceTreeNode byRefNode1(DSRTypes::RT_inferredFrom);
+    DSRByReferenceTreeNode byRefNode2(DSRTypes::RT_inferredFrom);
+    OFCHECK(!byRefNode1.isValid());
+    OFCHECK(!byRefNode2.isValid());
+    /* make the references valid */
+    OFCHECK(byRefNode1.updateReference(1, DSRTypes::VT_Num));
+    OFCHECK(byRefNode2.updateReference(2, DSRTypes::VT_Num));
+    OFCHECK(byRefNode1.isValid());
+    OFCHECK(byRefNode2.isValid());
+    OFCHECK(byRefNode1 != byRefNode2);
+    OFCHECK(byRefNode2.updateReference(1, DSRTypes::VT_Num));
+    OFCHECK(byRefNode1 == byRefNode2);
 }
 
 
@@ -237,6 +255,8 @@ OFTEST(dcmsr_gotoMatchingNode)
     OFCHECK(tree.addContentItem(DSRTypes::RT_hasConceptMod, DSRTypes::VT_Code, DSRTypes::AM_belowCurrent));
     const size_t nodeID5 = tree.getNodeID();
     OFCHECK(tree.getCurrentContentItem().setConceptName(DSRCodedEntryValue("111221", "DCM", "Unknown failure")).good());
+    OFCHECK(tree.addContentItem(DSRTypes::RT_hasProperties, DSRTypes::VT_Composite, DSRTypes::AM_afterCurrent));
+    const size_t nodeID6 = tree.getNodeID();
     /* and check the "search by filter" function */
     OFCHECK_EQUAL(tree.gotoMatchingNode(DSRDocumentTreeNodeConceptNameFilter(DSRCodedEntryValue("121206", "DCM", "Distance"))), nodeID2);
     OFCHECK_EQUAL(tree.gotoNextMatchingNode(DSRDocumentTreeNodeValueTypeFilter(DSRTypes::VT_Code)), nodeID3);
@@ -256,7 +276,19 @@ OFTEST(dcmsr_gotoMatchingNode)
     OFCHECK_EQUAL(tree.gotoMatchingNode(DSRDocumentTreeNodeObservationDateTimeFilter("201708081000", "201708081400")), nodeID2);
     OFCHECK_EQUAL(tree.gotoMatchingNode(DSRDocumentTreeNodeObservationDateTimeFilter("20170828", "" /*toDateTime*/)), nodeID3);
     OFCHECK_EQUAL(tree.gotoNextMatchingNode(DSRDocumentTreeNodeObservationDateTimeFilter("" /*fromDateTime*/, "201708280800")), nodeID4);
+    OFCHECK_EQUAL(tree.gotoNextMatchingNode(DSRDocumentTreeNodeHasConceptNameFilter(OFFalse /*hasConceptName*/)), nodeID6);
     OFCHECK_EQUAL(tree.gotoMatchingNode(DSRDocumentTreeNodeObservationDateTimeFilter("20170828080001", "" /*toDateTime*/)), 0 /* not found */);
+    /* change observation date/time for all content items */
+    OFCHECK(tree.setObservationDateTime("201803151800").good());
+    /* ... and check again */
+    const DSRDocumentTreeNodeObservationDateTimeFilter filter3("20180101", "20181231");
+    OFCHECK_EQUAL(tree.gotoNode(nodeID1), nodeID1);
+    OFCHECK_EQUAL(tree.gotoNextMatchingNode(filter3), nodeID2);
+    OFCHECK(tree.iterate() /* skip one node */);
+    OFCHECK_EQUAL(tree.gotoNextMatchingNode(filter3), nodeID3);
+    OFCHECK_EQUAL(tree.gotoNextMatchingNode(filter3), nodeID4);
+    OFCHECK_EQUAL(tree.gotoNextMatchingNode(filter3), nodeID5);
+    OFCHECK_EQUAL(tree.gotoNextMatchingNode(filter3), nodeID6);
 }
 
 
