@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2017, OFFIS e.V.
+ *  Copyright (C) 1998-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,14 +25,20 @@
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 #include "dcmtk/dcmnet/dcmlayer.h"    /* for DcmTransportLayer */
-#include "dcmtk/ofstd/ofstream.h"    /* for ostream */
+#include "dcmtk/dcmnet/assoc.h"       /* for T_ASC_NetworkRole */
+#include "dcmtk/ofstd/ofstream.h"     /* for ostream */
 #include "dcmtk/oflog/oflog.h"
 #include "dcmtk/dcmtls/tlsdefin.h"
+#include "dcmtk/dcmtls/tlsciphr.h"    /* for DcmTLSCiphersuiteHandler */
 
 #ifdef WITH_OPENSSL
-BEGIN_EXTERN_C
-#include <openssl/ssl.h>
-END_EXTERN_C
+
+// forward declarations of OpenSSL data structures
+struct ssl_ctx_st;
+typedef struct ssl_ctx_st SSL_CTX;
+
+struct x509_st;
+typedef struct x509_st X509;
 
 extern DCMTK_DCMTLS_EXPORT OFLogger DCM_dcmtlsLogger;
 
@@ -43,9 +49,18 @@ extern DCMTK_DCMTLS_EXPORT OFLogger DCM_dcmtlsLogger;
 #define DCMTLS_ERROR(msg) OFLOG_ERROR(DCM_dcmtlsLogger, msg)
 #define DCMTLS_FATAL(msg) OFLOG_FATAL(DCM_dcmtlsLogger, msg)
 
+// include this file in doxygen documentation
+
+/** @file tlslayer.h
+ *  @brief type definitions and classes for TLS transport connections
+ */
+
+
 /** this enum describes how to handle X.509 certificates on a TLS based
  *  secure transport connection. They can be ignored, validated if present
  *  or validated and demanded.
+ *  @remark this enum is only available if DCMTK is compiled with
+ *  OpenSSL support enabled.
  */
 enum DcmCertificateVerification
 {
@@ -63,11 +78,29 @@ enum DcmCertificateVerification
 };
 
 
+/** this enum describes the file format of a certificate or private key file.
+ *  @remark this enum is only available if DCMTK is compiled with
+ *  OpenSSL support enabled.
+ */
+enum DcmKeyFileFormat
+{
+ /** PEM (Privacy Enhanced Mail) format
+  */
+ DCF_Filetype_PEM,
+
+ /** ASN.1 (Abstract Syntax Notation One) format
+  */
+ DCF_Filetype_ASN1
+};
+
+
 /** factory class which creates secure TLS transport layer connections
  *  and maintains the parameters common to all TLS transport connections
  *  in one application (e.g. the pool of trusted certificates, the key
  *  and certificate to be used for authentication and the list of
  *  ciphersuite to be used for association negotiation.
+ *  @remark this class is only available if DCMTK is compiled with
+ *  OpenSSL support enabled.
  */
 
 class DCMTK_DCMTLS_EXPORT DcmTLSTransportLayer: public DcmTransportLayer
@@ -87,15 +120,14 @@ public:
   DcmTLSTransportLayer();
 
   /** constructor.
-   *  @param networkRole network role to be used by the application, influences
-   *    the choice of the secure transport layer code.
+   *  @param networkRole network role to be used by the application
    *  @param randFile path to file used to feed the random generator
    *  @param initializeOpenSSL Determines if OpenSSL library should be initialized.
    *    Some setups (e.g. multi-threaded environments) may be interested in using
    *    more than one TLS transport layer at a time and thus must make sure the
    *    library is only initialized once.
    */
-  DcmTLSTransportLayer(int networkRole, const char *randFile, OFBool initializeOpenSSL = OFTrue);
+  DcmTLSTransportLayer(T_ASC_NetworkRole networkRole, const char *randFile, OFBool initializeOpenSSL);
 
   /** move constructor.
    *  Transfer ownership from another DcmTLSTransportLayer object to the newly
@@ -138,7 +170,7 @@ public:
 
   /** Query whether this object has not been initialized, e.g. has been
    *  constructed using the default constructor or the initialization failed.
-   *  @return OFTrue if *this ist not initialized, OFFalse otherwise.
+   *  @return OFTrue if *this is not initialized, OFFalse otherwise.
    */
   OFBool operator!() const;
 
@@ -147,7 +179,7 @@ public:
    *  or a secure connection is established.  If the object cannot be created
    *  (e. g. because no secure layer is available), returns NULL.
    *  @param openSocket TCP/IP socket to be used for the transport connection.
-   *    the connection must already be establised on socket level. If a non-null
+   *    the connection must already be established on socket level. If a non-null
    *    pointer is returned, the new connection object takes over control of the socket.
    *  @param useSecureLayer if true, a secure layer is used. If false, a
    *    transparent layer is used.
@@ -160,14 +192,14 @@ public:
    *  @param fileType, must be SSL_FILETYPE_PEM or SSL_FILETYPE_ASN1
    *  @return TCS_ok if successful, an error code otherwise
    */
-  DcmTransportLayerStatus setPrivateKeyFile(const char *fileName, int fileType);
+  DcmTransportLayerStatus setPrivateKeyFile(const char *fileName, DcmKeyFileFormat fileType);
 
   /** loads the certificate (public key) used for authentication of this application from a file.
    *  @param fileName path to the certificate file
    *  @param fileType, must be SSL_FILETYPE_PEM or SSL_FILETYPE_ASN1
    *  @return TCS_ok if successful, an error code otherwise
    */
-  DcmTransportLayerStatus setCertificateFile(const char *fileName, int fileType);
+  DcmTransportLayerStatus setCertificateFile(const char *fileName, DcmKeyFileFormat fileType);
 
   /** checks if the private key and the certificate set using setPrivateKeyFile()
    *  and setCertificateFile() match, i.e. if they establish a private/public key pair.
@@ -180,7 +212,7 @@ public:
    *  @param fileType, must be SSL_FILETYPE_PEM or SSL_FILETYPE_ASN1
    *  @return TCS_ok if successful, an error code otherwise
    */
-  DcmTransportLayerStatus addTrustedCertificateFile(const char *fileName, int fileType);
+  DcmTransportLayerStatus addTrustedCertificateFile(const char *fileName, DcmKeyFileFormat fileType);
 
   /** loads all files as certificates from the specified directory and adds them
    *  to the pool of trusted certificates.
@@ -188,7 +220,7 @@ public:
    *  @param fileType, must be SSL_FILETYPE_PEM or SSL_FILETYPE_ASN1
    *  @return TCS_ok if successful, an error code otherwise
    */
-  DcmTransportLayerStatus addTrustedCertificateDir(const char *pathName, int fileType);
+  DcmTransportLayerStatus addTrustedCertificateDir(const char *pathName, DcmKeyFileFormat fileType);
 
   /** loads certificates from a file and adds them to the pool of trusted client
    *  certificates.
@@ -208,37 +240,32 @@ public:
    */
   DcmTransportLayerStatus addVerificationFlags(unsigned long flags);
 
-  /** sets the list of ciphersuites to negotiate.
-   *  @param suites string containing the list of ciphersuites.
-   *    The list must be in OpenSSL syntax (use findOpenSSLCipherSuiteName to convert
-   *    from RFC 2246 ciphersuite names to OpenSSL names), with ciphersuites separated
-   *    by ':' characters.
+  /** replace the current list of ciphersuites by the list of ciphersuites
+   *  for the given profile.
+   *  @param profile TLS Security Profile
    *  @return TCS_ok if successful, an error code otherwise
    */
-  DcmTransportLayerStatus setCipherSuites(const char *suites);
+  DcmTransportLayerStatus setTLSProfile(DcmTLSSecurityProfile profile);
 
-  /** returns the number of known ciphersuites.
-   *  @return number of known ciphersuites
+  /** clear the current list of ciphersuites. Equivalent to
+   *  calling setTLSProfile(TSP_Profile_None).
    */
-  static unsigned long getNumberOfCipherSuites();
+  void clearTLSProfile();
 
-  /** returns a ciphersuite name in RFC 2246 (TLS) form
-   *  @param idx index, must be < getNumberOfCipherSuites()
-   *  @return ciphersuite name
+  /** adds a ciphersuite to the list of ciphersuites for TLS negotiation.
+   *  It is the responsibility of the user to ensure that the added ciphersuite
+   *  does not break the rules of the selected profile. Use with care!
+   *  @param suite TLS ciphersuite name, in the official TLS name form.
+   *  @return TCS_ok if successful, an error code otherwise
    */
-  static const char *getTLSCipherSuiteName(unsigned long idx);
+  DcmTransportLayerStatus addCipherSuite(const char *suite);
 
-  /** returns a ciphersuite name in OpenSSL form
-   *  @param idx index, must be < getNumberOfCipherSuites()
-   *  @return ciphersuite name
+  /** activate the current list of ciphersuites by transferring to the OpenSSL layer
+   *  This method needs to be called once after the list of ciphersuites has been
+   *  defined used setTLSProfile() and addCipherSuite().
+   *  @return TCS_ok if successful, an error code otherwise
    */
-  static const char *getOpenSSLCipherSuiteName(unsigned long idx);
-
-  /** finds the OpenSSL ciphersuite name for a given RFC 2246 ciphersuite name.
-   *  @param tlsCipherSuiteName ciphersuite name in RFC 2246 form
-   *  @returns ciphersuite name in OpenSSL form, NULL if unknown.
-   */
-  static const char *findOpenSSLCipherSuiteName(const char *tlsCipherSuiteName);
+  DcmTransportLayerStatus activateCipherSuites();
 
   /** checks if enough entropy data is available to write back a modified
    *  random seed file.
@@ -295,12 +322,57 @@ public:
    */
   OFBool setTempDHParameters(const char *filename);
 
+  /** print a list of supported ciphersuites to the given output stream.
+   *  @param os output stream
+   */
+  void printSupportedCiphersuites(STD_NAMESPACE ostream& os) const;
+
+  /** Initialize OpenSSL Library. This function is THREAD UNSAFE
+   *  and should only be called once to initialize the OpenSSL library.
+   */
+  static void initializeOpenSSL();
+
   /** gets the most important attributes of the given X.509 certificate.
    *  @param peerCertificate X.509 certificate, may be NULL
    *  @return a string describing the certificate
    */
   static OFString dumpX509Certificate(X509 *peerCertificate);
 
+  /** gets the size of the public key of an RSA certificate.
+   *  @param certificate X.509 certificate
+   *  @return public key size (in bits) if RSA certificate, 0 otherwise.
+   */
+  static int getRSAKeySize(X509 *certificate);
+
+  /** checks the BCP 195 recommendations that RSA certificates
+   *  should use SHA-256 hash keys. We also accept better SHA-2
+   *  hash keys (SHA-384 and SHA-512).
+   *  @param certificate X.509 certificate
+   *  @return NULL if everything is OK (i.e. the certificate is
+   *    not RSA, or it is RSA and uses SHA-256 or better),
+   *    the name of the hash key algorithm used otherwise.
+   */
+  static const char *checkRSAHashKeyIsSHA2(X509 *certificate);
+
+  /** returns the version name of the OpenSSL version used.
+   *  @return OpenSSL version name, never NULL.
+   */
+  static const char *getOpenSSLVersionName();
+
+  /** load an X.509 certificate from file.
+   *  @param fileName path to the certificate file
+   *  @param fileType, must be SSL_FILETYPE_PEM or SSL_FILETYPE_ASN1
+   *  @return pointer to X509 object if successful, NULL otherwise.
+   *    The X509 object must be freed by the caller.
+   */
+  static X509 *loadCertificateFile(const char *fileName, DcmKeyFileFormat fileType);
+
+  /** returns a string in OpenSSL syntax that contains the currently defined
+   *  list of TLS ciphersuites.
+   *  @param cslist The list of ciphersuites in OpenSSL syntax is written to this string.
+   */
+  void getListOfCipherSuitesForOpenSSL(OFString& cslist) const;
+
   /** provides access to the underlying OpenSSL context handle for implementing
    *  custom functionality not accessible by the existing member functions of
    *  DcmTLSTransportLayer.
@@ -332,6 +404,12 @@ private:
   /// private undefined assignment operator
   DcmTLSTransportLayer& operator=(const DcmTLSTransportLayer&);
 
+  /** look up OpenSSL certificate format constant
+   *  @param fileType as DcmKeyFileFormat enum
+   *  @return fileType as OpenSSL integer constant
+   */
+  static int lookupOpenSSLCertificateFormat(DcmKeyFileFormat fileType);
+
   /// OpenSSL context data, needed only once per application
   SSL_CTX *transportLayerContext;
 
@@ -341,16 +419,11 @@ private:
   /// contains the password for the private key if set on command line
   OFString privateKeyPasswd;
 
-};
+  /// ciphersuite handler
+  DcmTLSCiphersuiteHandler ciphersuites;
 
-#else /* WITH_OPENSSL */
-
-// trivial declaration of DcmTLSTransportLayer as a placeholder
-class DCMTK_DCMTLS_EXPORT DcmTLSTransportLayer : public DcmTransportLayer
-{
-public:
-  inline DcmTLSTransportLayer(OFrvalue_ref(DcmTLSTransportLayer) /* rhs */) {}
-  inline DcmTLSTransportLayer& operator=(OFrvalue_ref(DcmTLSTransportLayer) /* rhs */) { return *this; }
+  /// network role for this TLS layer
+  T_ASC_NetworkRole role;
 };
 
 #endif /* WITH_OPENSSL */
