@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2010-2013, OFFIS e.V.
+ *  Copyright (C) 2010-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -20,11 +20,16 @@
  */
 
 #include "dcmtk/config/osconfig.h"  /* make sure OS specific configuration is included first */
+#include "dcmtk/dcmtls/tlsdefin.h"  /* for DCMTK_DCMTLS_EXPORT */
 
 #ifdef WITH_OPENSSL
 #include "dcmtk/dcmtls/tlsscu.h"
 #include "dcmtk/dcmnet/diutil.h"    /* for dcmnet logger */
 
+BEGIN_EXTERN_C
+#include <openssl/ssl.h>
+END_EXTERN_C
+
 
 DcmTLSSCU::DcmTLSSCU() :
   m_tLayer(NULL),
@@ -32,23 +37,15 @@ DcmTLSSCU::DcmTLSSCU() :
   m_trustedCertDirs(),
   m_trustedCertFiles(),
   m_privateKeyFile(""),
-  m_privateKeyFileFormat(SSL_FILETYPE_PEM),
+  m_privateKeyFileFormat(DCF_Filetype_PEM),
   m_certificateFile(""),
-  m_certKeyFileFormat(SSL_FILETYPE_PEM),
+  m_certKeyFileFormat(DCF_Filetype_PEM),
   m_passwd(NULL),
-  m_ciphersuites(""),
   m_readSeedFile(""),
   m_writeSeedFile(""),
   m_certVerification(DCV_requireCertificate),
   m_dhparam("")
 {
-#if OPENSSL_VERSION_NUMBER >= 0x0090700fL
-  m_ciphersuites = TLS1_TXT_RSA_WITH_AES_128_SHA;
-  m_ciphersuites += ":";
-  m_ciphersuites += SSL3_TXT_RSA_DES_192_CBC3_SHA;
-#else
-  m_ciphersuites = SSL3_TXT_RSA_DES_192_CBC3_SHA;
-#endif
 }
 
 
@@ -60,23 +57,15 @@ DcmTLSSCU::DcmTLSSCU(const OFString& peerHost,
   m_trustedCertDirs(),
   m_trustedCertFiles(),
   m_privateKeyFile(""),
-  m_privateKeyFileFormat(SSL_FILETYPE_PEM),
+  m_privateKeyFileFormat(DCF_Filetype_PEM),
   m_certificateFile(""),
-  m_certKeyFileFormat(SSL_FILETYPE_PEM),
+  m_certKeyFileFormat(DCF_Filetype_PEM),
   m_passwd(NULL),
-  m_ciphersuites(""),
   m_readSeedFile(""),
   m_writeSeedFile(""),
   m_certVerification(DCV_requireCertificate),
   m_dhparam("")
 {
-#if OPENSSL_VERSION_NUMBER >= 0x0090700fL
-  m_ciphersuites = TLS1_TXT_RSA_WITH_AES_128_SHA;
-  m_ciphersuites += ":";
-  m_ciphersuites += SSL3_TXT_RSA_DES_192_CBC3_SHA;
-#else
-  m_ciphersuites = SSL3_TXT_RSA_DES_192_CBC3_SHA;
-#endif
   setPeerHostName(peerHost);
   setPeerAETitle(peerAETitle);
   setPeerPort(portNum);
@@ -98,7 +87,7 @@ OFCondition DcmTLSSCU::initNetwork()
   OFCondition cond;
 
   /* First, create TLS layer */
-  m_tLayer = new DcmTLSTransportLayer(DICOM_APPLICATION_REQUESTOR, m_readSeedFile.c_str());
+  m_tLayer = new DcmTLSTransportLayer(NET_REQUESTOR, m_readSeedFile.c_str(), OFTrue /* initialize OpenSSL */);
   if (m_tLayer == NULL)
   {
     DCMTLS_ERROR("Unable to create TLS transport layer for SCP, maybe problem with seed file?");
@@ -133,13 +122,6 @@ OFCondition DcmTLSSCU::initNetwork()
     }
   }
 
-  /* Set cipher suites to be supported */
-  if ( cond.good() && (TCS_ok != m_tLayer->setCipherSuites(m_ciphersuites.c_str())) )
-  {
-    DCMTLS_ERROR("Unable to set selected cipher suites for SCP");
-    cond = EC_IllegalCall; // TODO: need to find better error code
-  }
-
   /* Initialize Diffie-Hellman parameters from file if given */
   if (!m_dhparam.empty() && cond.good())
   {
@@ -217,8 +199,8 @@ void DcmTLSSCU::closeAssociation(const DcmCloseAssociationType closeType)
 void DcmTLSSCU::enableAuthentication(const OFString& privateKey,
                                      const OFString& certFile,
                                      const char* passphrase,
-                                     const int privKeyFormat,
-                                     const int certFormat)
+                                     const DcmKeyFileFormat privKeyFormat,
+                                     const DcmKeyFileFormat certFormat)
 {
   m_doAuthenticate = OFTrue;
   m_privateKeyFile = privateKey;
@@ -236,7 +218,7 @@ void DcmTLSSCU::enableAuthentication(const OFString& privateKey,
     return;
   }
 
-  int passLength = strlen(passphrase) + 1;
+  size_t passLength = strlen(passphrase) + 1;
   m_passwd = new char[passLength];
   strncpy(m_passwd, passphrase, passLength);
   return;
@@ -260,18 +242,21 @@ void DcmTLSSCU::disableAuthentication()
   m_doAuthenticate = OFFalse;
 }
 
-
-void DcmTLSSCU::addCiphersuite(const OFString& cs)
+DcmTransportLayerStatus DcmTLSSCU::addCipherSuite(const OFString& suite)
 {
-  if (m_ciphersuites.empty())
-    m_ciphersuites = cs;
-  else
-  {
-    m_ciphersuites+= ":";
-    m_ciphersuites+= cs;
-  }
+  if (m_tLayer)
+     return m_tLayer->addCipherSuite(suite.c_str());
+     else return TCS_illegalCall;
 }
 
+DcmTransportLayerStatus DcmTLSSCU::setTLSProfile(DcmTLSSecurityProfile profile)
+{
+  if (m_tLayer)
+  {
+    m_tLayer->setTLSProfile(profile);
+    return TCS_ok;
+  } else return TCS_illegalCall;
+}
 
 void DcmTLSSCU::setReadSeedFile(const OFString& seedFile)
 {
@@ -337,12 +322,6 @@ void DcmTLSSCU::getTrustedCertDirs(OFList<OFString>& trustedDirs /*out*/) const
 }
 
 
-OFString DcmTLSSCU::getCiphersuites() const
-{
-  return m_ciphersuites;
-}
-
-
 OFString DcmTLSSCU::getReadSeedFile() const
 {
   return m_readSeedFile;
@@ -360,5 +339,14 @@ OFString DcmTLSSCU::getDHParam() const
   return m_dhparam;
 }
 
+#else
+
+/* make sure that the object file is not completely empty if compiled
+ * without OpenSSL because some linkers might fail otherwise.
+ */
+DCMTK_DCMTLS_EXPORT void tlsscu_dummy_function()
+{
+  return;
+}
 
 #endif // WITH_OPENSSL
