@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2012, OFFIS e.V.
+ *  Copyright (C) 1998-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,6 +25,7 @@
 
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/ofstd/oftypes.h"
+#include "dcmtk/ofstd/ofexbl.h"
 #include "dcmtk/ofstd/oflist.h"
 #include "dcmtk/ofstd/ofstring.h"
 #include "dcmtk/ofstd/ofconsol.h"
@@ -124,7 +125,7 @@ struct DCMTK_OFSTD_EXPORT OFCmdParam
 
 private:
 
-    /// private undefined copy assignment operator
+    /// private undefined assignment operator
     OFCmdParam& operator=(const OFCmdParam& arg);
 };
 
@@ -204,7 +205,7 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
         PVS_Overflow
     };
 
-    /** mode for findOption method
+    /** mode for findOption() method
      */
     enum E_FindOptionMode
     {
@@ -264,7 +265,7 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  optDescr    description of command line option (use '\\n' for line break)
      *  @param  flags       optional flags (see AF_xxx below)
      *
-     ** @return OFTrue if succesfully added
+     ** @return OFTrue if successfully added
      */
     OFBool addOption(const char *longOpt,
                      const char *shortOpt,
@@ -281,7 +282,7 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  optDescr  description of command line option (use '\\n' for line break)
      *  @param  flags     optional flags (see AF_xxx below)
      *
-     ** @return OFTrue if succesfully added
+     ** @return OFTrue if successfully added
      */
     OFBool addOption(const char *longOpt,
                      const char *shortOpt,
@@ -297,7 +298,7 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  optDescr    description of command line option (use '\\n' for line break)
      *  @param  flags       optional flags (see AF_xxx below)
      *
-     ** @return OFTrue if succesfully added
+     ** @return OFTrue if successfully added
      */
     OFBool addOption(const char *longOpt,
                      const int valueCount,
@@ -312,7 +313,7 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  optDescr  description of command line option (use '\\n' for line break)
      *  @param  flags     optional flags (see AF_xxx below)
      *
-     ** @return OFTrue if succesfully added
+     ** @return OFTrue if successfully added
      */
     OFBool addOption(const char *longOpt,
                      const char *optDescr,
@@ -485,7 +486,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParam(const int pos,
                                 OFCmdSignedInt &value);
@@ -497,21 +499,23 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  low    minimum boundary for value (used for range check)
      *  @param  incl   if OFTrue 'low' value is valid (included), otherwise invalid
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParamAndCheckMin(const int pos,
                                            OFCmdSignedInt &value,
                                            const OFCmdSignedInt low,
-                                           const OFBool incl = OFTrue);
+                                           const OFExplicitBool incl = OFTrue);
 
     /** gets value of specified parameter as signed integer and checks for given boundaries
      *
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *  @param  low    minimum boundary for value (used for range check, boundary included)
-     *  @param  high   maximum boundary for value (dito)
+     *  @param  high   maximum boundary for value (ditto)
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParamAndCheckMinMax(const int pos,
                                               OFCmdSignedInt &value,
@@ -525,7 +529,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParam(const int pos,
                                 OFCmdUnsignedInt &value);
@@ -539,12 +544,13 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  low    minimum boundary for value (used for range check)
      *  @param  incl   if OFTrue 'low' value is valid (included), otherwise invalid
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParamAndCheckMin(const int pos,
                                            OFCmdUnsignedInt &value,
                                            const OFCmdUnsignedInt low,
-                                           const OFBool incl = OFTrue);
+                                           const OFExplicitBool incl = OFTrue);
 
     /** gets value of specified parameter as unsigned integer and checks for given boundaries.
      *  NB: If command line argument specifies a negative value the result depends on the
@@ -553,9 +559,10 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *  @param  low    minimum boundary for value (used for range check, boundary included)
-     *  @param  high   maximum boundary for value (dito)
+     *  @param  high   maximum boundary for value (ditto)
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParamAndCheckMinMax(const int pos,
                                               OFCmdUnsignedInt &value,
@@ -567,7 +574,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParam(const int pos,
                                 OFCmdFloat &value);
@@ -579,21 +587,23 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  low    minimum boundary for value (used for range check)
      *  @param  incl   if OFTrue 'low' value is valid (included), otherwise invalid
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParamAndCheckMin(const int pos,
                                            OFCmdFloat &value,
                                            const OFCmdFloat low,
-                                           const OFBool incl = OFTrue);
+                                           const OFExplicitBool incl = OFTrue);
 
     /** gets value of specified parameter as floating point and checks for given boundaries
      *
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *  @param  low    minimum boundary for value (used for range check, boundary included)
-     *  @param  high   maximum boundary for value (dito)
+     *  @param  high   maximum boundary for value (ditto)
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParamAndCheckMinMax(const int pos,
                                               OFCmdFloat &value,
@@ -605,7 +615,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParam(const int pos,
                                 const char *&value);
@@ -615,19 +626,21 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      ** @param  pos    position of parameter (1..n)
      *  @param  value  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParam(const int pos,
                                 OFCmdString &value);
 
     /** gets value of specified parameter as an instance of OFFilename.
-     *  Please note that on Windows systems the returned filename might also contain a wide character
-     *  version (UTF-16) as an alternative representation.  See getWideCharMode().
+     *  Please note that on Windows systems the returned filename might also contain a wide
+     *  character version (UTF-16) as an alternative representation.  See getWideCharMode().
      *
-     ** @param  pos    position of parameter (1..n)
-     *  @param  value  reference to variable where the value should be stored
+     ** @param  pos       position of parameter (1..n)
+     *  @param  filename  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, PVS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, PVS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ParamValueStatus getParam(const int pos,
                                 OFFilename &filename);
@@ -640,14 +653,15 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  predecessor of the optional defined reference parameter 'pos') and goes to the
      *  first one.
      *
-     ** @param  longOpt    name of option (in long format) to be checked
-     *  @param  pos        position of reference parameter
-     *                     (default: all parameters; if value is negative option must be a direct
-     *                      predecessor of the specified reference parameter '-pos', no further
-     *                      search processes will be performed; if search direction is left to right
-     *                      this parameter is ignored, also option blocks are not supported in this
-     *                      case)
-     *  @param  mode       find option mode (used to support option blocks and reverse search direction)
+     ** @param  longOpt  name of option (in long format) to be checked
+     *  @param  pos      position of reference parameter
+     *                   (default: all parameters; if value is negative option must be a
+     *                    direct predecessor of the specified reference parameter '-pos',
+     *                    no further search processes will be performed; if search direction
+     *                    is left to right this parameter is ignored, also option blocks are
+     *                    not supported in this case)
+     *  @param  mode     find option mode (used to support option blocks and reverse search
+     *                   direction)
      *
      ** @return OFTrue if option exists, OFFalse otherwise
      */
@@ -704,7 +718,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *
      ** @param  value  reference to signed integer variable where the value should be stored
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValue(OFCmdSignedInt &value);
 
@@ -714,19 +729,21 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  low    minimum boundary for value (used for range check)
      *  @param  incl   if OFTrue 'low' value is valid (included), otherwise invalid
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValueAndCheckMin(OFCmdSignedInt &value,
                                       const OFCmdSignedInt low,
-                                      const OFBool incl = OFTrue);
+                                      const OFExplicitBool incl = OFTrue);
 
     /** returns next argument as a signed integer value and checks for given boundaries
      *
      ** @param  value  reference to signed integer variable where the value should be stored
      *  @param  low    minimum boundary for value (used for range check, boundary included)
-     *  @param  high   maximum boundary for value (dito)
+     *  @param  high   maximum boundary for value (ditto)
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValueAndCheckMinMax(OFCmdSignedInt &value,
                                          const OFCmdSignedInt low,
@@ -736,7 +753,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *
      ** @param  value  reference to unsigned integer variable where the value should be stored
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValue(OFCmdUnsignedInt &value);
 
@@ -746,19 +764,21 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  low    minimum boundary for value (used for range check)
      *  @param  incl   if OFTrue 'low' value is valid (included), otherwise invalid
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValueAndCheckMin(OFCmdUnsignedInt &value,
                                       const OFCmdUnsignedInt low,
-                                      const OFBool incl = OFTrue);
+                                      const OFExplicitBool incl = OFTrue);
 
     /** returns next argument as an unsigned integer value and checks for given boundaries
      *
      ** @param  value  reference to unsigned integer variable where the value should be stored
      *  @param  low    minimum boundary for value (used for range check, boundary included)
-     *  @param  high   maximum boundary for value (dito)
+     *  @param  high   maximum boundary for value (ditto)
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValueAndCheckMinMax(OFCmdUnsignedInt &value,
                                          const OFCmdUnsignedInt low,
@@ -768,7 +788,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *
      ** @param  value  reference to floating point variable where the value should be stored
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValue(OFCmdFloat &value);
 
@@ -778,19 +799,21 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *  @param  low    minimum boundary for value (used for range check)
      *  @param  incl   if OFTrue 'low' value is valid (included), otherwise invalid
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValueAndCheckMin(OFCmdFloat &value,
                                       const OFCmdFloat low,
-                                      const OFBool incl = OFTrue);
+                                      const OFExplicitBool incl = OFTrue);
 
     /** returns next argument as a floating point value and checks for given boundaries
      *
      ** @param  value  reference to floating point variable where the value should be stored
      *  @param  low    minimum boundary for value (used for range check, boundary included)
-     *  @param  high   maximum boundary for value (dito)
+     *  @param  high   maximum boundary for value (ditto)
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValueAndCheckMinMax(OFCmdFloat &value,
                                          const OFCmdFloat low,
@@ -800,7 +823,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *
      ** @param  value  reference to C string variable where the value should be stored
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValue(const char *&value);
 
@@ -808,17 +832,19 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      *
      ** @param  value  reference to C++ string variable where the value should be stored
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValue(OFCmdString &value);
 
     /** returns next argument as an instance of OFFilename.
-     *  Please note that on Windows systems the returned filename might also contain a wide character
-     *  version (UTF-16) as an alternative representation.  See getWideCharMode().
+     *  Please note that on Windows systems the returned filename might also contain a wide
+     *  character version (UTF-16) as an alternative representation.  See getWideCharMode().
      *
-     ** @param  value  reference to variable where the value should be stored
+     ** @param  filename  reference to variable where the value should be stored
      *
-     ** @return status of get/conversion, VS_Normal if successful (use getStatusString for error string)
+     ** @return status of get/conversion, VS_Normal if successful
+     *          (use getStatusString() for error string)
      */
     E_ValueStatus getValue(OFFilename &filename);
 
@@ -826,16 +852,18 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
  // --- parsing command line
 
     /** parses specified command line arguments (argc, argv).  Sets 'WideCharMode' to OFFalse.
-     *  Additionally, create internal structures for evaluation and return status indicating any errors
-     *  that occurred during the parse process.
+     *  Additionally, create internal structures for evaluation and return status indicating
+     *  any errors that occurred during the parse process.
      *
      ** @param  argCount  number of command line arguments stored in argValue
      *  @param  argValue  array where the command line arguments are stored
      *  @param  flags     optional flags affecting the parse process (see PF_xxx below)
-     *  @param  startPos  index of first argument which should be parsed (starting from 0, default: 1)
+     *  @param  startPos  index of first argument which should be parsed (starting from 0,
+     *                    default: 1)
      *
-     ** @return status of parse process, PS_Normal if successful (use getStatusString for error string).
-     *          If an exclusive option is used the status code PS_ExclusiveOption is returned.
+     ** @return status of parse process, PS_Normal if successful
+     *          (use getStatusString() for error string).  If an exclusive option is used,
+     *           the status code PS_ExclusiveOption is returned.
      */
     E_ParseStatus parseLine(int argCount,
                             char *argValue[],
@@ -845,20 +873,24 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
 #ifdef DCMTK_USE_WCHAR_T
 
     /** parses specified command line arguments (argc, argv).  Sets 'WideCharMode' to OFTrue.
-     *  This is a Windows-specific version supporting the wide character encoding (UTF-16).  Internally,
-     *  all character strings are stored in UTF-8, because this Unicode encoding is supported by DICOM.
-     *  However, there are getValue() and getParam() methods that allow for accessing filenames with
-     *  wide character encoding (UTF-16).
-     *  Additionally, create internal structures for evaluation and return status indicating any errors
-     *  that occurred during the parse process.
+     *  This is a Windows-specific version supporting the wide character encoding (UTF-16).
+     *  Internally, all character strings are stored in UTF-8, because this Unicode encoding is
+     *  supported by DICOM.  However, there are getValue() and getParam() methods that allow for
+     *  accessing filenames with wide character encoding (UTF-16).
+     *  Additionally, create internal structures for evaluation and return status indicating any
+     *  errors that occurred during the parse process.
+     *  @remarks this method is only available if OS is windows (not mingw) and
+     *  MSC6 is not used for building.
      *
      ** @param  argCount  number of command line arguments stored in argValue
      *  @param  argValue  array where the command line arguments are stored
      *  @param  flags     optional flags affecting the parse process (see PF_xxx below)
-     *  @param  startPos  index of first argument which should be parsed (starting from 0, default: 1)
+     *  @param  startPos  index of first argument which should be parsed (starting from 0,
+     *                    default: 1)
      *
-     ** @return status of parse process, PS_Normal if successful (use getStatusString for error string).
-     *          If an exclusive option is used the status code PS_ExclusiveOption is returned.
+     ** @return status of parse process, PS_Normal if successful
+     *          (use getStatusString() for error string).  If an exclusive option is used,
+     *           the status code PS_ExclusiveOption is returned.
      */
     E_ParseStatus parseLine(int argCount,
                             wchar_t *argValue[],
@@ -871,15 +903,16 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
  // --- get usage/status strings
 
     /** returns command line syntax as a C++ string (single text line).
-     *  Text consists of "[options]" (if defined by addOption) and all parameters defined by addParam.
+     *  Text consists of "[options]" (if defined by addOption()) and all parameters defined
+     *  by addParam().
      *
      ** @param  syntaxStr  reference to C++ string where the text should be stored
      */
     void getSyntaxString(OFString &syntaxStr) const;
 
     /** returns description of all options as a C++ string (multiple text lines).
-     *  Text consists of group headings, short and long option names, option descriptions and additional
-     *  option values.
+     *  Text consists of group headings, short and long option names, option descriptions and
+     *  additional option values.
      *
      ** @param  optionStr  reference to C++ string where the text should be stored
      */
@@ -892,32 +925,32 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      */
     void getParamString(OFString &paramStr) const;
 
-    /** returns status of parseLine as a C++ string
+    /** returns status of parseLine() as a C++ string
      *
-     ** @param  status     value returned by method parseLine
+     ** @param  status     value returned by method parseLine()
      *  @param  statusStr  reference to C++string where the text should be stored
      */
     void getStatusString(const E_ParseStatus status,
                          OFString &statusStr);
 
-    /** returns status of getParam as a C++ string
+    /** returns status of getParam() as a C++ string
      *
-     ** @param  status     value returned by method getParam
+     ** @param  status     value returned by method getParam()
      *  @param  statusStr  reference to C++string where the text should be stored
      */
     void getStatusString(const E_ParamValueStatus status,
                          OFString &statusStr);
 
-    /** returns status of getValue as a C++ string
+    /** returns status of getValue() as a C++ string
      *
-     ** @param  status     value returned by method getValue
+     ** @param  status     value returned by method getValue()
      *  @param  statusStr  reference to C++string where the text should be stored
      */
     void getStatusString(const E_ValueStatus status,
                          OFString &statusStr);
 
 
- // --- flags (used for method parseLine)
+ // --- flags (used for method parseLine())
 
     /// parsing flag to expand wildcard under Windows.
     /// (not used anymore, only available for reasons of backward compatibility;
@@ -926,9 +959,9 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
     /// disable support for command files ("@filename") containing additional arguments
     static const int PF_NoCommandFiles;
 
- // --- flags (used for method addOption)
+ // --- flags (used for method addOption())
 
-    /// exclusive option that overrides any other option (e.g. "--help")
+    /// exclusive option that overrides any other option (e.g.\ "--help")
     static const int AF_Exclusive;
     /// internal option that is not shown in the syntax usage output
     static const int AF_Internal;
@@ -939,7 +972,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
 
  protected:
 
-    /** checks whether given option is valid (starting with an option char and not followed by a number)
+    /** checks whether given option is valid (starting with an option char and not
+     *  followed by a number)
      */
     OFBool checkOption(const OFString &option,
                        const OFBool mode = OFTrue) const;
@@ -972,6 +1006,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
 
     /** check whether 'argValue' points to command file and parse content if so.
      *  This is a Windows-specific version supporting wide char encoding (UTF-16).
+     *  @remarks this method is only available if OS is windows (not mingw) and
+     *  MSC6 is not used for building.
      */
     E_ParseStatus parseCommandFile(const wchar_t *argValue,
                                    const OFString &strValue,
@@ -990,7 +1026,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
                             unsigned int &longCols,
                             unsigned int &shortCols) const;
 
-    /** checks whether number of parameters in parsed command line is within the range of min/max (see below)
+    /** checks whether number of parameters in parsed command line is within the range
+     *  of min/max (see below)
      */
     E_ParseStatus checkParamCount();
 
@@ -998,7 +1035,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
      */
     OFBool getLastArg(OFString &arg);
 
-    /** returns name of parameter which is missed in the parsed command line (used for error output)
+    /** returns name of parameter which is missed in the parsed command line
+     *  (used for error output)
      */
     OFBool getMissingParam(OFString &param);
 
@@ -1033,7 +1071,7 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
 
     /// OFTrue if option block is active, OFFalse otherwise
     OFBool OptionBlockMode;
-    /// C++ string conisting of all valid characters introducing an option
+    /// C++ string consisting of all valid characters introducing an option
     OFString OptionChars;
 
     /// OFTrue if an "exclusive" option is used in the command line, OFFalse otherwise
@@ -1059,6 +1097,8 @@ class DCMTK_OFSTD_EXPORT OFCommandLine
 
  private:
 
+    /// private undefined copy constructor
+    OFCommandLine(const OFCommandLine &obj);
     /// private undefined assignment operator
     OFCommandLine &operator=(const OFCommandLine &obj);
 };
