@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2006-2014, OFFIS e.V.
+ *  Copyright (C) 2006-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -43,6 +43,10 @@ BEGIN_EXTERN_C
 #endif
 END_EXTERN_C
 
+#ifdef HAVE_UNIX_H
+#include <unix.h>           /* needed for setlinebuf() on QNX */
+#endif
+
 /* HP-UX has clearerr both as macro and as a function definition. We have to
  * undef the macro so that we can define a function called "clearerr".
  */
@@ -59,42 +63,59 @@ END_EXTERN_C
  * Yes, this is ugly.
  */
 
-/* Find out whether current operating system needs explicit function calls
- * to handle large file support
+/* Find out whether to use explicit LFS function calls to handle
+ * large file support
  */
-#ifdef _LARGEFILE64_SOURCE
-  // Mac OS X defines _LARGEFILE64_SOURCE but anyhow expects implicit 64 bit calls.
-  // The same is true for current Cygwin versions (tested with version 1.7.7-1).
-  #if !(defined(__MACH__) && defined(__APPLE__)) && !defined(__CYGWIN__)
-    #define EXPLICIT_LFS_64
-  #endif
+#if defined(DCMTK_ENABLE_LFS) && DCMTK_ENABLE_LFS == DCMTK_LFS64
+#define EXPLICIT_LFS_64
+
+// Use POSIX 64 bit file position type when available
+#ifdef HAVE_FPOS64_T
+typedef fpos64_t offile_fpos_t;
+#else // Otherwise this should be sufficient
+typedef fpos_t offile_fpos_t;
 #endif
 
-#if defined(_WIN32) && !defined(__MINGW32__)
-  // On Win32 systems except MinGW (where Posix definitions are available)
-  // we use Win32 specific definitions
-  typedef __int64 offile_off_t;
-  typedef fpos_t offile_fpos_t;
-#else
-  #if defined(EXPLICIT_LFS_64) && !defined(__MINGW64__)
-    // Explicit LFS (LFS64)
-    typedef fpos64_t offile_fpos_t;
-    typedef off64_t offile_off_t;
-  #else
-    // Implicit LFS or no LFS
-    #ifdef HAVE_FSEEKO
-      typedef off_t offile_off_t;
-    #else
-      typedef long offile_off_t;
-    #endif
-    typedef fpos_t offile_fpos_t;
-  #endif
+// Use POSIX 64 bit file offset type when available
+#ifdef HAVE_OFF64_T
+typedef off64_t offile_off_t;
+#elif !defined(OF_NO_SINT64) // Otherwise use a 64 bit integer
+typedef Sint64 offile_off_t;
+#else // Cry when 64 LFS is required but no 64 bit integer exists
+#error \
+  Could not find a suitable offset-type for LFS64 support.
 #endif
 
+#else // Implicit LFS or no LFS
+
+#if defined(DCMTK_ENABLE_LFS) && DCMTK_ENABLE_LFS == DCMTK_LFS
+#if defined(SIZEOF_FPOS_T) && (!defined(SIZEOF_OFF_T) || SIZEOF_FPOS_T > SIZEOF_OFF_T)
+// strange Windows LFS where sizeof(fpos_t) == 8 but sizeof(off_t) == 4
+#ifndef OF_NO_SINT64 // Use a 64 bit integer
+typedef Sint64 offile_off_t;
+#else // Cry when LFS is required but no 64 bit integer exists
+#error \
+  Could not find a suitable offset-type for LFS support.
+#endif
+#else
+typedef off_t offile_off_t;
+#endif
+#elif defined(HAVE_FSEEKO)
+typedef off_t offile_off_t;
+#else
+typedef long offile_off_t;
+#endif
+typedef fpos_t offile_fpos_t;
+
+#endif // basic type definitions
+
 // the type we use to store the last error.
 typedef int offile_errno_t;
 
 
+// forward declarations
+class OFpath;
+
 /** class for managing filenames consisting either of conventional (8-bit) or
  *  wide (e.g.\ 16-bit) characters.  The wide character support is currently
  *  Windows-specific because most other operating systems use UTF-8, which is
@@ -123,14 +144,24 @@ public:
   OFFilename(const OFString &filename,
              const OFBool convert = OFFalse);
 
+  /** construct an OFFilename from an OFpath.
+   *  @param path the OFpath object referring to a file.
+   *  Effectively OFFilename(path.native(), OFTrue), but potentially more
+   *  efficient.
+   */
+  OFFilename(const OFpath& path);
+
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /** constructor expecting a wide character string
+   *  @remark This constructor is only available if DCMTK is compiled on Windows
+   *  Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *  WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
    *  @param filename filename to be stored (e.g. 16-bit characters)
    *  @param convert  convert given filename to UTF-8 encoding as an
    *    alternative representation.  Only works on Windows systems.
    */
   OFFilename(const wchar_t *filename,
-             const OFBool convert = OFFalse);
+             const OFBool convert = OFTrue);
 #endif
 
   /** copy constructor
@@ -185,6 +216,9 @@ public:
 
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /** get stored filename consisting of wide characters
+   *  @remark This method is only available if DCMTK is compiled on Windows
+   *  Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *  WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
    *  @return wide char filename (might be NULL if none is stored)
    */
   inline const wchar_t *getWideCharPointer() const
@@ -211,16 +245,22 @@ public:
 
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /** replace currently stored filename by given value
+   *  @remark This method is only available if DCMTK is compiled on Windows
+   *  Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *  WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
    *  @param filename filename to be stored (e.g. 16-bit characters)
    *  @param convert  convert given filename to UTF-8 encoding as an alternative
    *    representation.  Only works on Windows systems.
    */
   void set(const wchar_t *filename,
-           const OFBool convert = OFFalse);
+           const OFBool convert = OFTrue);
 #endif
 
 private:
-  /// filename consisting of conventional characters (8-bit, e.g. UTF-8)
+  /// filename consisting of conventional characters (8-bit, e.g.\ UTF-8)
+  /// @remark This member is only available if DCMTK is compiled on Windows
+  /// Operating Systems with wide chars enabled (defining _WIN32 as well as
+  /// WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
   char *filename_;
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /// filename consisting of wide characters (e.g. 16-bit on Windows)
@@ -299,8 +339,10 @@ public:
 
 #if defined(WIDE_CHAR_FILE_IO_FUNCTIONS) && defined(_WIN32)
   /** opens the file whose name is the wide character string pointed to by path and
-   *  associates a stream with it. This function is Win32 specific and only exists on
-   *  WinNT and newer.
+   *  associates a stream with it.
+   *  @remark This member is only available if DCMTK is compiled on Windows
+   *  Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *  WIDE_CHAR_FILE_IO_FUNCTIONS).
    *  @param filename Unicode filename path to file
    *  @param modes "r", "w" or "a" with possible modifiers "+", "b", as a wide
    *    character string
@@ -381,10 +423,10 @@ public:
   OFBool popen(const char *command, const char *modes)
   {
     if (file_) fclose();
-#if defined(_WIN32) && !defined(__MINGW64__)
-    file_ = _popen(command, modes);
-#else
+#ifdef HAVE_POPEN
     file_ = :: popen(command, modes);
+#else
+    file_ = _popen(command, modes);
 #endif
     if (file_) popened_ = OFTrue; else storeLastError();
     return (file_ != NULL);
@@ -445,10 +487,10 @@ public:
     {
       if (popened_)
       {
-#if defined(_WIN32) && !defined(__MINGW64__)
-        result = _pclose(file_);
-#else
+#ifdef HAVE_PCLOSE
         result = :: pclose(file_);
+#else
+        result = _pclose(file_);
 #endif
       }
       else
@@ -544,7 +586,17 @@ public:
    *  the beginning of the file. This is equivalent to fseek(0, SEEK_SET)
    *  except that the error indicator for the stream is also cleared.
    */
-  void rewind() { STDIO_NAMESPACE rewind(file_); }
+  void rewind()
+  {
+#if defined(_WIN32) || defined(__CYGWIN__)
+    /* On these platforms rewind() fails after reading to the end of file
+     * if the file is read-only. Using fseek() instead.
+     */
+    (void) this->fseek(0L, SEEK_SET);
+#else
+    STDIO_NAMESPACE rewind(file_);
+#endif
+  }
 
   /** clears the end-of-file and error indicators for the stream
    */
@@ -814,8 +866,8 @@ public:
   int fgetpos(offile_fpos_t *pos)
   {
     int result;
-#if defined(EXPLICIT_LFS_64) && ! defined(__MINGW32__)
-    // MinGW has EXPLICIT_LFS_64 but no fgetpos64()
+#if defined(EXPLICIT_LFS_64) && ! defined(__MINGW32__) && ! defined(__QNX__)
+    // MinGW and QNX have EXPLICIT_LFS_64 but no fgetpos64()
     result = :: fgetpos64(file_, pos);
 #else
     result = STDIO_NAMESPACE fgetpos(file_, pos);
@@ -834,8 +886,8 @@ public:
   int fsetpos(offile_fpos_t *pos)
   {
     int result;
-#if defined(EXPLICIT_LFS_64) && ! defined(__MINGW32__)
-    // MinGW has EXPLICIT_LFS_64 but no fsetpos64()
+#if defined(EXPLICIT_LFS_64) && ! defined(__MINGW32__) && ! defined(__QNX__)
+    // MinGW and QNX have EXPLICIT_LFS_64 but no fsetpos64()
     result = :: fsetpos64(file_, pos);
 #else
     result = STDIO_NAMESPACE fsetpos(file_, pos);
