@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -31,11 +31,13 @@
 #include "dcmtk/ofstd/oftraits.h"   /* for OFenable_if, ... */
 #include "dcmtk/ofstd/ofcond.h"     /* for OFCondition */
 #include "dcmtk/ofstd/oflimits.h"   /* for OFnumeric_limits<T>::max() */
+#include "dcmtk/ofstd/oferror.h"
 
 #define INCLUDE_CASSERT
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSTRING
+#define INCLUDE_CSTDARG
 #define INCLUDE_UNISTD
 #include "dcmtk/ofstd/ofstdinc.h"
 
@@ -45,11 +47,19 @@ BEGIN_EXTERN_C
 #endif
 END_EXTERN_C
 
+/* Check if we are using glibc in a version where readdir() is known to be
+ * thread-safe and where readdir_r() is deprecated.
+ */
+#if defined(__GLIBC__) && (((__GLIBC__ == 2) && (__GLIBC_MINOR__ >= 24)) || (__GLIBC__ >= 3))
+#define READDIR_IS_THREADSAFE
+#endif
+
 /*------------------------*
  *  forward declarations  *
  *------------------------*/
 
 class OFFilename;
+class OFSockAddr;
 
 /*---------------------*
  *  class declaration  *
@@ -79,7 +89,6 @@ class DCMTK_OFSTD_EXPORT OFStandard
         MM_XML
     };
 
-    class OFHostent;
     class OFGroup;
     class OFPasswd;
 
@@ -135,6 +144,42 @@ class DCMTK_OFSTD_EXPORT OFStandard
 #endif
     }
 
+    /* Standard C99 formatted string output function.
+     * This is an implementation of the snprintf(3) function as defined in the
+     * C99 standard. Like all functions of the  printf() family, it produces
+     * output according to a format string. Output is written to the character
+     * array passed as parameter str. The function never writes more than size
+     * bytes and guarantees that the result will be NUL terminated, although
+     * it may be truncated if the buffer provided is too small.
+     * @param str string buffer to write to
+     * @param size size of string buffer, in bytes
+     * @param format printf() format string
+     * @param ... parameters to be formatted
+     * @return number of characters that have been written (if the buffer is
+     *   large enough) or the number of characters that would have been
+     *   written (if the buffer is too small), in both cases not including
+     *   the final NUL character.
+     */
+    static int snprintf(char *str, size_t size, const char *format, ...);
+
+    /* Standard C99 formatted string output function.
+     * This is an implementation of the snprintf(3) function as defined in the
+     * C99 standard. Like all functions of the  printf() family, it produces
+     * output according to a format string. Output is written to the character
+     * array passed as parameter str. The function never writes more than size
+     * bytes and guarantees that the result will be NUL terminated, although
+     * it may be truncated if the buffer provided is too small.
+     * @param str string buffer to write to
+     * @param size size of string buffer, in bytes
+     * @param format printf() format string
+     * @param ap parameters to be formatted
+     * @return number of characters that have been written (if the buffer is
+     *   large enough) or the number of characters that would have been
+     *   written (if the buffer is too small), in both cases not including
+     *   the final NUL character.
+     */
+    static int vsnprintf(char *str, size_t size, const char *format, va_list ap);
+
     /** convert a given error code to a string. This function wraps the various
      *  approaches found on different systems. Internally, the standard function
      *  strerror() or strerror_r() is used.
@@ -715,8 +760,9 @@ class DCMTK_OFSTD_EXPORT OFStandard
      *  is not affected by a locale setting, the radix character is always
      *  assumed to be '.'
      *  This implementation does not set errno if the input cannot be parsed
-     *  and it does not implement special handling for overflow/underflow
-     *  or NaN values.  However, a return code indicates whether or not
+     *  and it does not implement special handling for overflow/underflow.
+     *  It does handle "NaN" and "Inf" (case insensitive; following
+     *  characters are ignore). A return code indicates whether or not
      *  a successful conversion could be performed.
      *  The precision of this implementation is limited to approx. 9
      *  decimal digits.
@@ -853,13 +899,13 @@ class DCMTK_OFSTD_EXPORT OFStandard
     static OFBool
     safeSubtract(T minuend, T subtrahend, T& difference)
     {
-      assert(!OFnumeric_limits<T>::is_signed);
-      if (minuend < subtrahend) {
-        return OFFalse;
-      } else {
-        difference = minuend - subtrahend;
-        return OFTrue;
-      }
+        assert(!OFnumeric_limits<T>::is_signed);
+        if (minuend < subtrahend) {
+            return OFFalse;
+        } else {
+            difference = minuend - subtrahend;
+            return OFTrue;
+        }
     }
 
     /** check whether addition is safe (i.e.\ no overflow occurs) and if so,
@@ -875,28 +921,150 @@ class DCMTK_OFSTD_EXPORT OFStandard
     static OFBool
     safeAdd(T a, T b, T& sum)
     {
-      assert(!OFnumeric_limits<T>::is_signed);
-      if ((OFnumeric_limits<T>::max)() - a < b) {
-        return OFFalse;
-      } else {
-        sum = a + b;
-        return OFTrue;
-      }
+        assert(!OFnumeric_limits<T>::is_signed);
+        if ((OFnumeric_limits<T>::max)() - a < b) {
+            return OFFalse;
+        } else {
+            sum = a + b;
+            return OFTrue;
+        }
     }
 
-    /** Thread-safe version of gethostbyname.
-     *  @param name the host name.
-     *  @return a OFStandard::OFHostent object.
+    /** check whether multiplication is safe (i.e.\ no overflow occurs) and if so,
+     *  perform it (i.e.\ compute a*b=product). Only works for unsigned types.
+     *  @param a first number to multiply
+     *  @param b second number to multiply
+     *  @param product resulting product of both numbers, if multiplication is
+     *    safe, otherwise parameter value is not touched by the function
+     *  @return OFTrue if multiplication is safe and could be performed, OFFalse
+     *    otherwise
      */
-    static OFHostent getHostByName( const char* name );
+    template <typename T>
+    static OFBool safeMult(T a, T b, T& product)
+    {
+        assert(!OFnumeric_limits<T>::is_signed);
+        T x = a * b;
+        if (a != 0 && x / a != b) {
+            return OFFalse;
+        }
+        product = x;
+        return OFTrue;
+    }
 
-    /** Thread-safe version of gethostbyaddr.
-     *  @param addr see manpage.
-     *  @param len see manpage.
-     *  @param type see manpage.
-     *  @return a OFStandard::OFHostent object.
+#ifdef DOXYGEN
+    /** checks if a string only contains valid decimal digits, i.e.\ 0-9.
+     *  @tparam Count the number of characters (bytes) to check.
+     *  @param string a pointer to a character array to check.
+     *  @return OFTrue if all characters are valid decimal digits, OFFalse
+     *    if at least one non-digit character is encountered.
      */
-    static OFHostent getHostByAddr( const char* addr, int len, int type );
+    template<size_t Count>
+    static OFBool checkDigits(const char* string);
+
+    /** extracts digits from a string and converts them to the given integer
+     *  number type.
+     *  The result is similar to calling atoi, but extractDigits does not
+     *  verify all characters are digits and does not require zero terminated
+     *  strings. It is meant to be used in conjunction with
+     *  OFStandard::checkDigits(). extractDigits does not handle sign
+     *  characters ('+' and '-').
+     *  @tparam T the type of the resulting value, e.g.\ unsigned int. Must
+     *    be a valid integer type, i.e.\ OFnumeric_limits<T>::is_integer must
+     *    be OFTrue.
+     *  @tparam Count the number of digits to extract. Must be greater zero
+     *    and less or equal to OFnumeric_limits<T>::digits10
+     *  @param string a pointer to a character array to extract digits from.
+     *  @return a value of type T that is equivalent to the number represented
+     *    by the digits.
+     *  @details
+     *  @warning The results are unspecified if the given string contains
+     *    non-digit characters.
+     */
+    template<typename T,size_t Count>
+    static T extractDigits(const char*);
+#else
+    template<size_t Count>
+    static OFTypename OFenable_if<!Count,OFBool>::type
+    checkDigits(const char* /*string*/)
+    {
+        return OFTrue;
+    }
+
+    template<size_t Count>
+    static OFTypename OFenable_if<!!Count,OFBool>::type
+    checkDigits(const char* string)
+    {
+        return *string >= '0' && *string <= '9' &&
+            checkDigits<Count-1>( string + 1 );
+    }
+
+    template<typename T,size_t Count>
+    static OFTypename OFenable_if
+    <
+        OFnumeric_limits<T>::is_integer && Count == 1,
+        T
+    >::type extractDigits(const char* string)
+    {
+        return *string - '0';
+    }
+
+    template<typename T,size_t Count>
+    static OFTypename OFenable_if
+    <
+        OFnumeric_limits<T>::is_integer && ( Count > 1 ) &&
+             OFnumeric_limits<T>::digits10 >= Count,
+        T
+    >::type extractDigits(const char* string)
+    {
+        return extractDigits<T,Count-1>( string ) * 10
+            + extractDigits<T,1>( string + Count - 1 );
+    }
+#endif
+
+    /** An utility function that finds a substring within a string that does
+     *  not contain leading and trailing spaces and null bytes, effectively
+     *  trimming the string without unnecessary copies.
+     *  @param pBegin a reference to a pointer to the beginning of the string.
+     *  @param pEnd a reference to a pointer to the end of the string (the
+     *    first byte behind the string).
+     *  @details
+     *  @pre pBegin <= pEnd
+     *  @details
+     *  trimString() increments pBegin and decrements pEnd until either both
+     *  point to a non-null and non-space character (the position after it in
+     *  case of pEnd) or both become equal (in case the string only contains
+     *  spaces and null bytes).
+     */
+    static void trimString( const char*& pBegin, const char*& pEnd );
+
+    /** An utility function that finds a substring within a string that does
+     *  not contain leading and trailing spaces and null bytes, effectively
+     *  trimming the string without unnecessary copies.
+     *  @param str a reference to a pointer to the beginning of the string.
+     *  @param size a reference to a size_t variable containing the number of
+     *    bytes in the string referenced by str.
+     *  @details
+     *  This overload is implemented using the other overload of the function
+     *  operating on two character pointers.
+     */
+    static void trimString( const char*& str, size_t& size );
+
+    /** This function performs a reverse DNS lookup of a hostname.
+     *  The parameters are identical to those passed to gethostbyaddr().
+     *  If the lookup fails, an empty string is returned.
+     *  @param addr IP address, actually a pointer to a struct in_addr or a struct in6_addr object
+     *  @param len length of the struct pointed to by addr
+     *  @param type address type, either AF_INET or AF_INET6
+     *  @return hostname for the IP address
+     */
+    static OFString getHostnameByAddress(const char* addr, int len, int type);
+
+    /** This function performs a DNS lookup of an IP address based on a hostname.
+     *  If a DNS lookup yields multiple IP addresses, only the first one is returned.
+     *  @param name hostname
+     *  @param result a OFSockAddr instance in which the result is stored
+     */
+    static void getAddressByHostname(const char *name, OFSockAddr& result);
 
     /** Thread-safe version of getgrnam.
      *  @param name the group name.
@@ -940,6 +1108,41 @@ class DCMTK_OFSTD_EXPORT OFStandard
      */
     static OFString getHostName();
 
+    /** Initialize the network API (if necessary), e.g.\ Winsock.
+     *  Calls the appropriate network initialization routines for the current
+     *  platform, e.g.\ WSAStartup().
+     *  @note This function must be called by an application before any
+     *    network related functions are used, be it listening on a socket or
+     *    just retrieving the current host name. Not all platforms require
+     *    calling a network initialization routine, therefore testing if it
+     *    works to determine if this method must be called is not an option
+     *    -- just always ensure to call it at program startup if the
+     *    application does something network related!
+     */
+    static void initializeNetwork();
+
+    /** Shutdown the network API (if necessary), e.g.\ Winsock.
+     *  Calls the appropriate network shutdown routines to free used resources
+     *  (e.g.\ WSACleanup()).
+     */
+    static void shutdownNetwork();
+
+    /** Retrieve the last operating system error code that was emitted in the
+     *  calling thread.
+     *  The current implementation uses errno on POSIX-like platforms and
+     *  GetLastError() on Windows.
+     *  @return the last error code as OFerror_code object.
+     */
+    static OFerror_code getLastSystemErrorCode();
+
+    /** Retrieve the last network specific error code that was emitted in the
+     *  calling thread.
+     *  The current implementation uses errno on POSIX-like platforms and
+     *  WSAGetLastError() on Windows.
+     *  @return the last error code as OFerror_code object.
+     */
+    static OFerror_code getLastNetworkErrorCode();
+
  private:
 
     /** private implementation of strlcpy. Called when strlcpy
