@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2014-2017, OFFIS e.V.
+ *  Copyright (C) 2014-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -50,6 +50,7 @@ using OFrvalue = T;
 
 #define OFrvalue_ref(T) T&&
 #define OFrvalue_access(RV) RV
+#define OFrvalue_ref_upcast(T, RV) static_cast<T&&>(RV)
 
 #else // fallback implementations
 
@@ -114,7 +115,7 @@ public:
 /** A helper class to 'tag' objects as <i>rvalues</i> to help
  *  DCMTK's move emulation employed on pre C++11 compilers.
  *  @tparam T the base type an rvalue should be create of.
- *  @details OFrvalue wrapps the type T inside a zero-overhead
+ *  @details OFrvalue wraps the type T inside a zero-overhead
  *    object employing T's move constructor when possible.
  *  @note When C++11 support is available, OFrvalue<T> will
  *    simply be a type alias for <i>T</i>, since a C++11 compiler
@@ -204,8 +205,19 @@ struct OFrvalue : OFrvalue_base<T>::type
  *  @endcode
  */
 #define OFrvalue_ref(T) unspecified
+
+/** Upcast an rvalue reference to an rvalue reference of one of its bases.
+ *  This is a helper macro for being used with DCMTK's fallback implementation
+ *  of move semantics. C++11 rvalue references should normally allow implicit
+ *  upcasts, therefore, this macro typically has no effect if C++11 is enabled
+ *  (it may be used to work around the behavior of older GCC versions).
+ *  @param T the base class to upcast to
+ *  @param RV the rvalue reference to upcast
+ */
+#define OFrvalue_ref_upcast(T, RV) unspecified
 #else // NOT DOXYGEN
 #define OFrvalue_ref(T) const OFrvalue<T >&
+#define OFrvalue_ref_upcast(T, RV) OFmove<T >(RV)
 #endif
 
 /** Obtain an lvalue reference from an rvalue reference.
