@@ -360,20 +360,15 @@ class OFCharacterEncoding::Implementation
             || flags == TransliterateIllegalSequences
             || flags == (DiscardIllegalSequences | TransliterateIllegalSequences)
         ;
-#else
-        // the iconvctl function is implemented only in GNU libiconv and not in other
-        // iconv implementations. The iconv implementation in the C standard library
-        // therefore does not support different encoding flags.
-#ifdef __FreeBSD__
-        // FreeBSD has a custom mode where illegal sequences are replaced by '?', so
-        // none of the normal modes are supported.
+#elif defined DCMTK_FIXED_ICONV_CONVERSION_FLAGS
+        // the iconvctl function is implemented only in newer versions of the
+        // GNU libiconv and not in other iconv implementations. For instance,
+        // the iconv implementation in the C standard library does not support
+        // different encoding flags and only has a (varying) fixed functionality
+        // that we detect with a configuration test.
+        return flags == DCMTK_FIXED_ICONV_CONVERSION_FLAGS;
+#endif
         return OFFalse;
-#else
-        // All other implementations seem to return an error when encountering
-        // illegal sequences by default, so 'abort' is the only supported mode.
-        return flags == AbortTranscodingOnIllegalSequence;
-#endif
-#endif
     }
 
     unsigned getConversionFlags() const
@@ -391,15 +386,17 @@ class OFCharacterEncoding::Implementation
             result |= DiscardIllegalSequences;
         if (result)
             return result;
-#endif
-#ifdef __FreeBSD__
-        // FreeBSD has a custom mode where illegal sequences are replaced by '?',
-        // which is none of the normal modes and can only be described as
-        // 'unknown' = 0
-        return 0;
-#else
+        // no flags set, so return libiconv default (=abort)
         return AbortTranscodingOnIllegalSequence;
+#elif defined DCMTK_FIXED_ICONV_CONVERSION_FLAGS
+        // the iconvctl function is implemented only in newer versions of the
+        // GNU libiconv and not in other iconv implementations. For instance,
+        // the iconv implementation in the C standard library does not support
+        // different encoding flags and only has a (varying) fixed functionality
+        // that we detect with a configuration test.
+        return DCMTK_FIXED_ICONV_CONVERSION_FLAGS;
 #endif
+        return 0;
     }
 
     OFBool setConversionFlags(const unsigned flags)
@@ -438,18 +435,15 @@ class OFCharacterEncoding::Implementation
             default:
                 return OFFalse;
         }
-#else
-        // the iconvctl function is implemented only in GNU libiconv and not in other
-        // iconv implementations. The iconv implementation in the C standard library
-        // therefore does not support different encoding flags.
-#ifdef __FreeBSD__
-        // FreeBSD has a custom mode where illegal sequences are replaced by '?', so
-        // none of the normal modes are supported.
+#elif defined DCMTK_FIXED_ICONV_CONVERSION_FLAGS
+        // the iconvctl function is implemented only in newer versions of the
+        // GNU libiconv and not in other iconv implementations. For instance,
+        // the iconv implementation in the C standard library does not support
+        // different encoding flags and only has a (varying) fixed functionality
+        // that we detect with a configuration test.
+        return flags == DCMTK_FIXED_ICONV_CONVERSION_FLAGS;
+#endif
         return OFFalse;
-#else
-        return flags == AbortTranscodingOnIllegalSequence;
-#endif
-#endif
     }
 
 
@@ -574,6 +568,19 @@ size_t OFCharacterEncoding::countCharactersInUTF8String(const OFString &utf8Stri
     return count;
 }
 
+OFBool OFCharacterEncoding::hasDefaultEncoding()
+{
+#if defined(DCMTK_ENABLE_CHARSET_CONVERSION) &&\
+    (\
+        DCMTK_ENABLE_CHARSET_CONVERSION != DCMTK_CHARSET_CONVERSION_STDLIBC_ICONV\
+     || DCMTK_STDLIBC_ICONV_HAS_DEFAULT_ENCODING\
+    )
+    return OFTrue;
+#else
+    return OFFalse;
+#endif
+}
+
 OFString OFCharacterEncoding::getLocaleEncoding()
 {
 #ifdef DCMTK_ENABLE_CHARSET_CONVERSION
