@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2017, OFFIS e.V.
+ *  Copyright (C) 2002-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -606,8 +606,8 @@ OFBool OFTime::getISOFormattedTime(OFString &formattedTime,
                   OFStandard::ftoa_format_f | OFStandard::ftoa_zeropad, 9, 6);
                 /* format: HH:MM:SS.FFFFFF */
                 if (showDelimiter)
-                    strcat(buf, ":");
-                strcat(buf, buf2);
+                    OFStandard::strlcat(buf, ":", sizeof(buf));
+                OFStandard::strlcat(buf, buf2, sizeof(buf));
             } else {
                 /* format: HH:MM:SS*/
                 if (showDelimiter)
